      BLOCK DATA BD01
C
C  BLOCK DATA Subprogram 01: /DFSBLK/
C
C  BLOCK DATA 01 initializes
C     1) the discretionary fuel switching rates
C     2) the fraction of lead burned that is exhausted
C
C  Common block array subscripts:
C
C  DFS(4,5) - DFS (IYPT, IV)
C  MYLEAD(4,5) - MYLEAD (IYPT, IV)
C
C  Common block dictionary:
C
C   Name   Type                Description
C  ------  ----  ----------------------------------------------
C  /DFSBLK/:
C
C  DFS      R    Fraction of vehicles designed to run on leaded
C                gasoline that use unleaded gasoline, i.e.
C                discretionary fuel switching rates, 1-DFS is the
C                fraction of vehicles designed to run on leaded
C                gasoline that use leaded gasoline
C  MYLEAD   I    Model year groups for discretionary fuel switching
C  ABURN    R    Fraction of lead burned that is exhausted
C                (denoted as a in particulate document)
C  MAXLED   I    Number of model year groups for base lead factors
C
C
C  Notes:
C  Nov-29-93 @ ARC-bsg Subtask 340
C  Changed DFS rates and lead start years for LDGT2
C  this fixes errors in SAI code delivered 10-22-93 that was not
C  using what the comments said they were using
C  Jul-1-94 @ CSC-bsg Request 447 Investigate graphical trends in the
C  particulate model by comparing IMFLAG=1 to IMFLAG=2 for various 
C  calendar years.  Discovered a mistake with HDGV DFS rate.
C
      INCLUDE 'DFSBLK.INC'
C
      DATA ABURN/0.75,0.40,0.44/
      DATA MAXLED/4/
C
C  last year by vehicle type for base lead fueling percents.
C
      DATA MYLEAD/
C        ---- LDGV ----       ---- LDGT1 ---       --- LDGT2 ----
     1 1970,1974,1989,2020,   1970,1974,1989,2020,1970,1978,1989,2020,
C        ---- HDGV ----       ---- MC ----
     2 1989,2020,   0,   0,   1977,1989,2020,   0/
C
      DATA DFS/
C  LDGV
     * 0.113,0.084,0.276,1.000,
C  LDGT1
     * 0.113,0.084,0.276,1.000,
C  LDGT2
     * 0.113,0.084,0.276,1.000,
C  HDGV
     * 0.000,1.000,1.000,1.000,
C  MC
     * 0.802,0.954,1.000,1.000/
C
      END
      BLOCK DATA BD02
C
C  BLOCK DATA Subprogram 02: /PSBLK/,/LEDCOM/,/TAMBLK/,/RLCOM2/
C
C  BLOCK DATA 02 initializes:
C     1) The fraction of particles less than or equal to the
C        particle size cutoff, PSZCUT, that is input by the user.
C        This fraction depends on the source category.
C     2) Tampering rates for misfueling and and catalyst removal
C     3) The lead content of gasoline (in grams/gallon) by calendar year
C
C  Common block array subscripts:
C
C  PB(22,2)            - PB(IYPTR,LNL)
C  IYRPB(22)           - IYRPB(IYPTR)
C  PSDIST(5,2,6)       - PSDIST(IPTS,I,ISRCE)
C  TAMRAT(2,3,3,2,2)   - TAMRAT(IMFLAG,ZML/DET1/2,IG,CAR/TRUCK,CAT/RMIS)
C
C  Common block dictionary:
C
C   Name    Type             Description
C  ------   ----   -------------------------------------------------------
C  /LEDCOM/:       LEAD COMMON BLOCK
C
C  PB        R     Lead content of gasoline (in grams/gallon) by calendar year
C                  PB = PB(IYPTR,LNL)
C                        LNL=1: leaded gasoline
C                        LNL=2: unleaded gasoline
C                  Note: Under 40 CFR 80, CY1992+ lead content of leaded
C                        fuel shall be from 0.5 to 0.1 g/gal.
C  IYRPB     I     Model year groups for PB
C                  IYRPB = IYRPB(IYPTR)
C
C
C  /PSBLK/:
C
C  PSDIST    R     The fraction of particles less than or equal to the
C                  particle size cutoff input by the user, PSZCUT.
C                  PSDIST=PSDIST(ipts,I, ISRCE)
C                  There are six categories of sources:
C
C                  ISRCE = 1 fraction for leaded gasoline
C                  ISRCE = 2 fraction for unleaded gasoline, Catalyst
C                  ISRCE = 3 fraction for unleaded gasoline, no Catalyst
C                  ISRCE = 4 fraction for diesel fuel
C                  ISRCE = 5 fraction for break wear
C                  ISRCE = 6 fraction for tire wear
C                  ISRCE = 7 fraction for unpaved road dust
C                  ISRCE = 8 Paved Base emission factor (g/VMT)
C
C                  ipts = the number of particle sizes for which there is
C                         data about the fraction of total particles less
C                         than or equal to those sizes (MXDATA=5)
C                  I = 1  corresponds to the particle size
C                  I = 2  corresponds to the fraction of particles less
C                         than or equal to that size
C
C  /TAMBLK/:       Tampering common block
C                  TAMRAT = TAMRAT(IMFLAG,ZML/DET1/2,IG,CAR/TRUCK,CAT/RMIS)
C                  where:
C                           IMFLAG = 1 for no IM program
C                           IMFLAG = 2 for IM program
C                           1=ZML 2=DET1 PRE 50,000 MILES 3=DET2 50-130K
C                           IG=1 PRE 81 IG=2 1981-1983 IG=3 1984+
C                           1=CAR 2=TRUCK
C                           1=CAT (Catalyst tampering) vs 2=RMIS (misfueling)
C                  TAMRAT is the fraction of vehicles that have
C                         their catalysts removed if fifth dimension=1 and
C                  TAMRAT is the fraction of vehicles that have
C                         misfueled their vehicles if fifth dimension=2.
C
C  Notes: Modified Sept'93 to conform to new ap42.
C  4-11-94 @ CSC-bsg Request 419 Change tampering rates to be like MOBILE5a
C  5-12-94 @ CSC-bsg Request 428 Change Lead content of fuel to updated #'s
C  Jun-29-94 @ CSC-bsg Request 447 Investigate graphical trends in the
C  particulate model by comparing IMFLAG=1 to IMFLAG=2 for various 
C  calendar years.  Discovered a mistake with the tampering rates block data.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'LEAD.INC'
C
C     Common Block PSBLK -- particle size distirbutions
C
      DATA PSDIST/
C     ISRCE = LEADED
     *     0.20,2.00,10.00,0.00,0.00,
     *     0.23,0.43,0.64,0.00,0.00,
C     ISRCE = NONLEADED, CATALYST
     *     0.20,2.00,10.00,0.00,0.00,
     *     0.87,0.89,0.97,0.00,0.00,
C     ISRCE = NONLEADED, NO CATALYST
     *     0.20,2.00,10.0,0.00,0.00,
     *     0.42,0.66,0.90,0.00,0.00,
C     ISRCE = DIESEL
     *     0.20,1.00,2.00,2.50,10.00,
     *     0.73,0.86,0.90,0.92,1.00,
C     ISRCE = BREAK
     *     0.43,1.10,4.70,7.00,10.00,
     *     0.09,0.16,0.82,0.90,0.98,
C     ISRCE = TIRE
     *     0.10,10.00,0.00,0.00,0.00,
     *     0.01,1.00,0.00,0.00,0.00,
C     ISRCE = UNPAVED ROAD DUST
     *     2.50,05.00,10.0,0.00,0.00,
     *     0.095,0.20,0.36,0.00,0.00,
C     ISRCE = PAVED ROAD DUST
     *     2.50,10.00,00.0,0.00,0.00,
     *     3.3,7.3,0.00,0.00,0.00/
C 
C  Apr-8-1994 @ CSC-bsg Request 419 made PART5 like MOBILE5a with respect
C  to the tampering rates of catalyst removal and misfueling.
C  Jun-29-94 @ CSC-bsg Request 447 Investigate graphical trends in the
C  particulate model by comparing IMFLAG=1 to IMFLAG=2 for various 
C  calendar years.  Discovered a mistake with the tampering rates block data.
C
C    TAMBLK -- Tampering common block

      DATA TAMRAT/
C CATS CARS
     1  0.0084,  0.0067, 0.0193, 0.0084, 0.9731, 1.0,
     2 -0.0019, -0.0152, 0.0038, 0.0060, 3.6154, 1.0,
     3 -0.0008,  0.0,    0.0014, 0.0003, 1.04,   1.0,
C CATS TRUCKS
     1  0.0785,  0.1037, 0.0444, 0.0203, 0.981,  1.0,
     2 -0.0018, -0.0062, 0.0258, 0.0109, 0.5767, 1.0,
     3  0.0024,  0.0006, 0.0035, 0.0043, 4.0011, 5.3523,
C RMIS CARS
     1 -0.0259,  0.0907, 0.0342, 0.0051, 0.7653, 1.0,
     2  0.0110,  0.0108, 0.0034, 0.0017, 2.6554, 0.08,
     3  0.0,     0.0,    0.0025, 0.0036, 1.0,    1.0,
C RMIS TRUCKS
     1  0.1519,  0.0491, 0.0297, 0.0388, 1.6721, 1.0,
     2  0.0113, -0.0379, 0.0203, 0.0229, 0.7318, 0.7812,
     3  0.0,     0.0075, 0.0057, 0.0086, 1.0,    1.0/
C
C  Lead content of gasoline (in grams/gallon) by calendar year
C  Note: Under 40 CFR 80, CY1992+ lead content of leaded fuel shall be
C        from 0.5 to 0.1 g/gal.
C  1: leaded gasoline    2: unleaded gasoline
C
      DATA PB/
     1 2.07,1.82,2.02,2.03,1.76,1.76,1.33,1.01,1.02,0.83,0.84,
     1 0.59,0.31,0.15,0.15,0.002, 0.0004, 0.0002, 0.0002,3*0.0,
     2 .014,.014,.014,.014,.010,.016,.028,.009,.005,.003,.006,
     2 .002,.002,.001,.001,.002,.0004,.0003,.0002, 0.0, 0.0, 0.0/
C
      DATA IYRPB/
     *1974,1975,1976,1977,1978,1979,1980,1981,1982,1983,1984,
     *1985,1986,1987,1988,1989,1990,1991,2020,   0,   0,   0/
C
      END
      BLOCK DATA BD04
C
C   BLOCK DATA Subprogram 04:  /CARBON/,DIEFE,/DIESEL/,/SULFR/
C
C   Block Data 04 initializes
C      1) the fraction of total carbon that is the soluable organic
C         fraction (SOF)
C      2) The diesel fueled vehicle fuel economies based on model year
C      3) The total exhaust PM10 emission factors for diesel vehicles
C         in grams/BHP-hr
C      4) The weight percent of sulfur in gasoline and diesel fuel, the
C         density of gasoline and diesel fuel (lbs/gallon), the fraction
C         of the sulfur in the fuel that gets converted directly into
C         sulfate matter (sulfuric acid), the exstimated weight ratio of
C         water molecules in sulfuric acid to SO4, the fraction of SO2
C         exhausted that is estimated converts to sulfate material in the
C         atmosphere (either ammonium sulfate or ammonium bisulfate), the
C         weight ratio of the combination of ammonium sulfate and ammonium
C         bisulfate to SO2.
C      5) The technology fractions for LDGV, LDGT1, LDGT2, HDGV, and MC for
C         use in the direct sulfate equations. 
C
C  Common Block Array Subscripts:
C
C         SOFPNT(MAXVEH)     --  SOFPNT (IV)
C         DIESFE(32,10)   --  DIESFE (IYEAR,IV)
C         IYRFE(32)      --  IYRFE (IYEAR)
C         IDIEYR(9,10)    --  IDIEYR (IYEAR,IV)
C         EFDPM(9,10)     --  EFDPM (IYEAR,IV)
C         FRACA(22,6,5)  -- FRACA(IFRAC,1-6,IV)
C
C  Common Block Dictionary:
C
C
C   Name   Type                Description
C  ------  ----  ----------------------------------------------
C  /CARBON/:
C
C   SOFPNT  R    The fraction of the carbon particulate that is
C                considered the soluable organic fraction (SOF)
C
C  /DIESEL/:
C
C   DIESFE  R    Fuel economy (miles/gal) for diesel fueled vehicles:
C   IYRFE   I    The years corresponding to the fuel economy array DIESFE
C                for the diesel fueled vehicles
C
C  /DIEFE/ :
C
C   IDIEYR  I    The model years corresponding to the exhaust PM10 emission
C                factors for diesel vehicles, EFDPM.
C   EFDPM    R   The exhaust PM10 emissions in grams/BHP-hr for heavy-duty
C                diesel vehicles, and in grams/mile for light duty diesels.
C
C  /SULFR/ :
C
C   GSWGTR  R    The sulfur weight percent of gasoline fuel
C
C   DSWGTR  R    The sulfur weight percent of diesel fuel where 1=1990 and
C                earlier, 2=1991-1992 and 3=1993+.
C
C   DCNVRT  R    The fraction of primary sulfate, i.e. the fraction of
C                sulfur that is directly converted into SO4 + bound water
C
C   EXPECV  R    The correction factor for RFG for exhaust particulate 
C                emissions for catalyst vehicles.
C
C   ICNVRT  R    The fraction of primary sulfate, i.e. the fraction of
C                sulfur that is directly converted into SO4 + bound water
C                (sulfuric acid)
C
C   GDENS   R    The density of gasoline fuel in pounds/gallon
C
C   DDENS   R    The density of diesel fuel in pounds/gallon
C
C   WATER   R    weight ratio of seven water molecules to sulfate
C                (see p. 6-25 of "Regulatory Impact Analysis,
C                Control of Sulfur and Aromatics Contents of On-
C                Highway Diesel Fuel")
C
C   AMNWGT  R    The extimated weight ratio of the combination of ammonium
C                bisulfate and ammonium sulfate in the atmosphere to SO4
C                (see p 6-25).
C
C  /FRCNTS/:
C
C   FRACA   R    The fractions for 1st dimension are: (IFRAC) 
C                1=Pre-1968, 2=1968-1971, 3=1972, ..., 21=1990, 22=1991+.
C                2nd dimension are: 1=ox-noair, 2=ox-air, 3=3-way-noair, 
C                4=3-way-air.  3rd dimension are: (IV) 1=LDGV, 2=LDGT1,
C                3=LDGT2, 4=HDGV, 5=MC. 
C                
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'FRACT.INC'
C
      DIMENSION DLDV(32),DLDT(32),DBHD(32),DLHD(32),DMHD(32),
     *                   DHHD(32),DBUS(32),
     *                   DBUS1(32),DBUS2(32),DBUS3(32)
C
C
C  Notes:
C  Oct-19-1993 @ ARC-bsg Subtask 325  Making the other busses EF by
C  creating FE for use in Direct SO4, Exhaust SO2 an Indirect SO4
C  the same FE number is used for all model years.
C  Feb-7-1994 @ CSC-bsg Request 390 New Sulfate equations
C  Mar-9-1994 @ CSC-bsg Request 401  Add user input variables for
C  sulfur weight percent for gasoline and diesel fuel or default values
C  Mar-15-1994 @ CSC-bsg Request 407 Change the fuel density for both
C  gasoline and diesel fuels.
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG         
C  removed user input of sulfur weight percent
C  The correction factor for exhaust particulate emission factors for
C  catalyst vehicles
C  Jun-7-1994 @ CSC-bsg Request 443 changed bus category exhaust particulate
C  default no trap rates for model years 1992 and later due to standard
C  changes.  Changed other heavy duty rates for 1994 and later due to a better
C  prediction of new technology
C  Jun-22-1994 @ CSC-bsg Request 429 Changed block data LDDV/T emission values
C  increased array size of IDIEYR and EFDPM to include new LDDV/T standards.
C  Jul-21-1994 @ CSC-bsg Changed block data LDDV/T emission values and IDIEYR
C  values to take pre-control standards into account
C
C
      EQUIVALENCE (DIESFE(1,1),DLDV(1)),
     *            (DIESFE(1,2),DLDT(1)),
     *            (DIESFE(1,3),DBHD(1)),
     *            (DIESFE(1,4),DLHD(1)),
     *            (DIESFE(1,5),DMHD(1)),
     *            (DIESFE(1,6),DHHD(1)),
     *            (DIESFE(1,7),DBUS(1)),
     *            (DIESFE(1,8),DBUS1(1)),
     *            (DIESFE(1,9),DBUS2(1)),
     *            (DIESFE(1,10),DBUS3(1))
C
      DATA EXPECV/1.0/
C
C     The sulfur weight percent of diesel fuel:
      DATA DSWGTR/0.25,0.05/
C
C     The sulfur weight percent of gasoline fuel:
      DATA GSWGTR/0.034/
C
C  Mar-15-1994 @ CSC-bsg Request 407 Change the fuel density for both
C  gasoline and diesel fuels.
C     The density of gasoline fuel in pounds/gallon:
      DATA GDENS/6.09/
C
C     The density of diesel fuel in pounds/gallon:
      DATA DDENS/7.11/
C
C     The fraction of primary sulfate from diesel vehicles, i.e. the
C     fraction of sulfur that is directly converted into SO4 + bound water:
      DATA DCNVRT/0.02/
C
C     The fraction of SO2 emissions that are indirectly converted to SO4:
      DATA ICNVRT/0.12/
C
C     The weight ratio of seven water molecules to sulfate (see p. 6-25
C     of "Regulatory Impact Analysis, Control of Sulfur and Aromatics
C     Contents of On-Highway Diesel Fuel") -- used to calculate sulfuric
C     acid weight in grams.
C
      DATA WATER/1.2857/
C
C     The extimated weight ratio of the combination of ammonium bisulfate
C     and ammonium sulfate in the atmosphere to SO4 (see p 6-25).
C
      DATA AMNWGT/1.6/
C
C     The fraction of the non-sulfate particulate that is considered
C     the soluable organic fraction (SOF):
C
C     NOTE:  The data for the vehicle classes LHDDE, MHDDE, and HHDDE was
C            taken from "Regulatory Impact Analysis, Control of Sulfur
C            and Aromatics Contents of On-Highway Diesel Fuel", EPA,
C            June 1990, page 3-9.  The fraction for buses was assumed to
C            be the same as MHDDV.  For LDDV and LDDT, the data came
C            from Table 3-9.  The emission factors for LDDT was calculated
C            as the average of LDDT1 and LDDT2, as well as the SOF percent
C            of (total PM10 - SO4).
C
      DATA SOFPNT/0.,0.,0.,0.,0.,0.22,0.59,0.51,0.51,0.44,0.24,0.44/
C
C  Jun-7-1994 @ CSC-bsg Request 443 changed bus category exhaust particulate
C  default no trap rates for model years 1992 and later due to standard
C  changes.  Changed other heavy duty rates for 1994 and later due to a better
C  prediction of new technology
C  Jun-22-1994 @ CSC-bsg Request 429 Changed block data LDDV/T emission values
C  increased array size of IDIEYR and EFDPM to include new LDDV/T standards.
C  Jul-21-1994 @ CSC-bsg Changed block data LDDV/T emission values and IDIEYR
C  values to take pre-control standards into account
C
      DATA IDIEYR/
C    LDDVs
     * 1900, 1981, 1982, 1985, 1987, 1988, 1991, 1994, 1996,
C    LDDT
     * 1900, 1981, 1982, 1985, 1987, 1988, 1991, 1994, 1997,
C    2BHDDV
     * 1900, 1987, 1988, 1991, 1994, 2020, 2020, 2020, 2020,
C    LHDDV
     * 1900, 1987, 1988, 1991, 1994, 2020, 2020, 2020, 2020,
C    MHDDV
     * 1900, 1987, 1988, 1991, 1994, 2020, 2020, 2020, 2020,
C    HHDDV
     * 1900, 1987, 1988, 1991, 1994, 2020, 2020, 2020, 2020,
C    HBUS
     * 1900, 1987, 1988, 1991, 1992, 1993, 1994, 2020, 2020,
C    HBUST1
     * 1900, 1987, 1988, 1991, 1992, 1993, 1994, 2020, 2020,
C    HBUST2
     * 1900, 1987, 1988, 1991, 1992, 1993, 1994, 2020, 2020,
C    HBUST3
     * 1900, 1987, 1988, 1991, 1992, 1993, 1994, 2020, 2020/
C
C  Jun-7-1994 @ CSC-bsg Request 443 changed bus category exhaust particulate
C  default no trap rates for model years 1992 and later due to standard
C  changes.  Changed other heavy duty rates for 1994 and later due to a better
C  prediction of new technology
C  Jun-22-1994 @ CSC-bsg Request 429 Changed block data LDDV/T emission values
C  increased array size of IDIEYR and EFDPM to include new LDDV/T standards.
C  Jul-21-1994 @ CSC-bsg Changed block data LDDV/T emission values and IDIEYR
C  values to take pre-control standards into account
C
      DATA EFDPM/
C    LDDV
     * .7,.259,.256,.255,.134,.132,.131,.128,.1,
C    LDDT
     * .7,.309,.354,.358,.334,.291,.294,.13,.109,
C    2BHDDV
     * .5156,.5156,.5140,.2873,.1011,0.,0.,0.,0.,
C    LHDDV
     * .5156,.5156,.5140,.2873,.1011,0.,0.,0.,0.,
C    MHDDV
     * .6946,.6946,.4790,.2747,.0948,0.,0.,0.,0.,
C    HHDDV
     * .6444,.6444,.4360,.2709,.0836,0.,0.,0.,0.,
C    HBUS
     * .6931,.6931,.4790,.2772,.1716,.1457,.0591,0.,0.,
C    HBUST1
     * .6931,.6931,.4790,.2772,.1716,.1457,.0591,0.,0.,
C    HBUST2
     * .6931,.6931,.4790,.2772,.1716,.1457,.0591,0.,0.,
C    HBUST3
     * .6931,.6931,.4790,.2772,.1716,.1457,.0591,0.,0./
C
C    The years corresponding to the fuel economy array DIESFE for
C    the diesel fueled vehicles:
C
      DATA IYRFE/
     *  1975, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998,
     *  1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
     *  2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018,
     *  2019, 2020/
C
C
C   Fuel economy (miles/gal) for diesel fueled vehicles:
C
C   NOTE 1:  This data comes from Table 6-A-1 of "Regulatory Impact
C            Analysis, Control of Sulfur and Aromatics Contents of On-
C            Highway Diesel Fuel", EPA, June 1990
C
C   NOTE 2:  The fuel economy of the vehicle class 2BHDDV was assumed
C            to be the same as LHDDV since this data was not provided
C            in Table 6-A-1 of the reference used.
C
C   LDDV
      DATA DLDV/
     * 21.85,28.26,28.76,29.32,29.87,30.40,30.92,31.41,31.86,32.29,
     * 32.71,33.11,33.44,33.72,33.95,34.15,34.31,34.44,34.57,34.66,
     * 34.74,34.80,34.84,34.88,34.91,34.92,34.94,34.95,34.95,34.96,
     * 34.96,34.96/
C   LDDT
      DATA DLDT/
     * 20.00,23.57,23.76,23.96,24.13,24.28,24.44,24.64,24.84,25.08,
     * 25.31,25.54,25.74,25.90,26.04,26.15,26.25,26.33,26.40,26.46,
     * 26.52,26.56,26.60,26.63,26.65,26.67,26.69,26.70,26.71,26.72,
     * 26.72,26.72/
C   2BHDDV
      DATA DBHD/
     *  8.23,14.04,14.19,14.35,14.51,14.67,14.85,15.01,15.19,15.38,
     * 15.56,15.75,15.92,16.08,16.20,16.37,16.47,16.56,16.63,16.69,
     * 16.75,16.79,16.82,16.84,16.87,16.89,16.90,16.90,16.91,16.92,
     * 16.92,16.92/
C   LHDDV
      DATA DLHD/
     *  8.23,14.04,14.19,14.35,14.51,14.67,14.85,15.01,15.19,15.38,
     * 15.56,15.75,15.92,16.08,16.20,16.37,16.47,16.56,16.63,16.69,
     * 16.75,16.79,16.82,16.84,16.87,16.89,16.90,16.90,16.91,16.92,
     * 16.92,16.92/
C   MHDDV
      DATA DMHD/
     *  6.07, 7.28, 7.37, 7.46, 7.54, 7.63, 7.71, 7.78, 7.86, 7.93,
     *  8.00, 8.07, 8.13, 8.17, 8.20, 8.22, 8.24, 8.25, 8.26, 8.27,
     *  8.28, 8.29, 8.29, 8.29, 8.30, 8.30, 8.30, 8.30, 8.31, 8.31,
     *  8.31, 8.31/
C   HHDDV
      DATA DHHD/
     *  4.35, 5.93, 6.02, 6.12, 6.21, 6.31, 6.41, 6.51, 6.61, 6.69,
     *  6.76, 6.82, 6.90, 6.96, 7.01, 7.05, 7.08, 7.10, 7.11, 7.12,
     *  7.13, 7.14, 7.15, 7.15, 7.15, 7.16, 7.16, 7.16, 7.16, 7.16,
     *  7.16, 7.16/
C   BUSES
      DATA DBUS/
     *  4.78, 6.06, 6.16, 6.26, 6.39, 6.51, 6.62, 6.73, 6.84, 6.97,
     *  7.08, 7.20, 7.25, 7.29, 7.34, 7.40, 7.44, 7.49, 7.54, 7.59,
     *  7.63, 7.67, 7.72, 7.76, 7.81, 7.85, 7.89, 7.94, 7.97, 8.02,
     *  8.06, 8.06/
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Making the other busses EF by
C  creating FE for use in Direct SO4, Exhaust SO2 an Indirect SO4
C  the same FE number is used for all model years.
C
C   Transit buses
      DATA DBUS1/32*4.04/
C
C   CBD buses
      DATA DBUS2/32*3.33/
C
C   Heavy Urban Buses
      DATA DBUS3/32*1.65/
C
C  Feb-7-1994 @ CSC-bsg Request 390 New Sulfate equations
C
      DATA FRACA /
     1       5*0.,.5,.55,3*.65,.23,0.,.01,.12,8*0.,                     OX NOAIR
     1       5*0.,2*.3,.2,2*.25,.65,.15,.13,9*0.,                       OX AIR
     1       10*0.,.07,.25,.29,.28,2*.4,.6,5*.7,                        3W NOAIR
     1       11*0.,.6,.57,3*.6,.4,5*.3,                                 3W AIR  
     2       5*0.,.4,.5,2*.55,2*.4,.47,.3,.29,.18,.05,.08,5*0.,         OX NOAIR
     2       5*0.,2*.3,2*.2,2*.4,.48,.6,.51,.52,.55,.42,5*.05,          OX AIR
     2       11*0.,.03,.1,.11,.07,.2,.37,.45,4*.5,                      3W NOAIR
     2       11*0.,.02,0.,.09,.23,.2,.13,.5,4*.45,                      3W AIR
     3       9*0.,2*.5,.52,.4,.39,.18,.05,.08,5*0.,                     OX NOAIR 
     3       9*0.,2*.5,.48,.6,.51,.52,.55,.42,5*.15,                    OX AIR
     3       13*0.,.01,.07,.2,.37,.45,4*.5,                             3W NOAIR
     3       13*0,.09,.23,.2,.13,.4,4*.35,                              3W AIR
     4       12*0.,5*.05,5*0.,                                          OX NOAIR
     4       17*0.,.15,2*.25,2*.3,                                      OX AIR
     4       18*0.,2*.1,2*.25,                                          3W NOAIR 
     4       17*0.,.15,2*.05,2*0.,                                      3W AIR 
     5       88*0./
      END
      BLOCK DATA BD06
C
C   BLOCK DATA Subprogram 06:  /EFPMC/
C
C   Block Data 06 initializes
C      1) the fraction of total carbon that is the soluable organic
C         fraction (SOF) in gasoline fueled vehicles
C      2) the carbon emission factor in gasoline vehicles
C      3) the model year array for the carbon emission factors in
C         gasoline vehicles
C
C  Common Block Array Subscripts:
C
C         SOFFRC(2,5)     --  SOFFRC (ICAT,IV)
C         GSCRBN(10,4,5)  --  GSCRBN (MYPTRC,ICAT,IV)
C         MYPTRC(10,4,5)   --  MYPTRC (IMYPTR,ICAT,IV)
C
C  Common Block Dictionary:
C
C   Name   Type                Description
C  ------  ----  ----------------------------------------------
C  /EFPMC/:
C
C   SOFFRC  R    The fraction of the carbon particulate that is
C                considered the soluable organic fraction (SOF)
C
C   GSCRBN  R    The total carbon emission factor for gasoline
C                vehicles referenced by model year, vehicle type
C                and ICAT 1=LEADED, UNLEADED
C                2=CAT NO AIR, 3=CAT AIR, 4=NO CAT. 
C                IV=1/2/3/4
C                ICAT 1=2-stroke 4=4-stroke.
C                IV=5
C
C   MYPTRC  I    The model year pointer for the GSCRBN array
C
      INCLUDE 'EFGAS.INC'
C
C 
C  Notes:
C  Mar-24-1994 @ CSC-bsg  Request 408,415 Exhaust Particulate Base numbers 
C  May-10-1994 @ CSC-bsg  Request 430 Exhaust Particulate emission factors
C  using carbon for gasoline vehicles
C  May-17-1994 @ CSC-bsg  Request 434 Integration and regression testing
C  Jun-17-94 @ CSC-bsg Request 430 MC use lead instead of gas carbon
C
C
      DATA MYPTRC/
C  LDGV
     1 1969,1974,1980,7*2020,
     2 1969,1980,8*2020,
     3 1969,1980,8*2020,
     4 1980,9*2020,
C  LDGT1
     1 1969,1974,1980,7*2020,
     2 1969,1986,8*2020,
     3 1969,1986,8*2020,
     4 1986,9*2020,
C  LDGT2
     1 1978,1986,8*2020,
     2 1978,1986,8*2020, 
     3 1978,1986,8*2020, 
     4 1978,1986,8*2020,
C  HDGV
     1 1986,9*2020,
     2 10*2020,
     3 10*2020,
     4 10*2020/
C
      DATA GSCRBN/
C  LGDV
     1 0.193, 0.068, 0.03, 7*0.017,
     2 0.03, 0.006, 8*0.0043,
     3 0.03, 0.025, 8*0.0043,
     4 0.03, 9*0.017,
C  LDGT1
     1 0.193, 0.068, 0.03, 7*0.017,
     2 0.03, 0.006, 8*0.0043,
     3 0.03, 0.025, 8*0.0043,
     4 0.03, 9*0.017,
C  LDGT2
     1 0.37, 0.068, 8*0.03,
     2 0.054, 0.006, 8*0.0043,
     3 0.054, 0.025, 8*0.0043,
     4 0.054, 0.03, 8*0.017,
C  HDGV
     1 0.37, 9*0.163,
     2 10*0.054, 
     3 10*0.054,
     4 10*0.054/
C
      END
      BLOCK DATA BD07
C
C  BLOCK DATA Subprogram 07: /BASEFD/
C
C  BLOCK DATA 07 initializes the base fugitive dust particulate factors.
C  BLOCK DATA 07 also initializes other constant values related to
C  the fugitive dust particulate model
C
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting
C
C  Common block array subscripts:
C
C
C  Common block dictionary:
C
C   Name   Type                Description
C  ------  ----  ----------------------------------------------
C  /BASEFD/:
C
C  VEHWT    I    Fleet Average Vehicle Weight in pounds
C  IVEHWL   I    Average Number of Vehicle Wheels for 12 Vehicle Classes
C  IFAVWL   I    Fleet Average Number of Vehicle Wheels
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'BASEFD.INC'
C
C
      DATA VEHWT/6000/
C
      DATA IVEHWL/4, 4, 4, 6, 2, 4, 4, 4, 6, 6, 18, 4/
C
      DATA IFAVWL/4/
      END
      BLOCK DATA BD08
C
C  BLOCK DATA Subprogram 08: /IDLCOM/,/BSIDL/
C
C  BLOCK DATA 08 initializes the base idle emission factors
C  BLOCK DATA 08 also initializes deterioration factors for the idle
C                emission facotrs.
C
C  Oct-19-1993 @ ARC-bsg Subtask 322 must make the same on all platforms
C  during the standardization caught this initialization error that was
C  not identical on all platfoms.
C
C
C  Common block array subscripts:
C
C  BASIDL(MAXYRS,MAXVEH)  - BASIDL(JDX,IV)
C  EMSIDL(MAXVP1)      - EMSIDL(IV+1)
C
C  Common block dictionary:
C
C   Name   Type                Description
C  ------  ----  ----------------------------------------------
C  /BSIDL/:
C  /IDLCOM/:
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IDLE.INC'
C
C  Oct-19-1993 @ ARC-bsg Subtask 322 must make the same on all platforms
C  during the standardization caught this initialization error that was
C  not identical on all platfoms.
C
      DATA IDLYRS /1987, 1990, 1993, 2021/
C
      DATA BASIDL /
C     2BHDDV
     *  5.37, 3.174, 1.86, 1.004,
C
C     LHDDV
     *  5.37, 3.174, 1.86, 1.004,
C
C     MHDDV
     *  5.37, 3.174, 1.86, 1.004,
C
C     HHDDV
     *  5.37, 3.174, 1.86, 1.004,
C
C     BUSES
     *  5.37, 3.174, 1.86, 1.004/
C
      DATA EMSIDL /MAXVP1*0./
C
      END
      BLOCK DATA BD16
C
C  BLOCK DATA Subprogram 16: /IOUCOM/,/MAXIMA/,/YEARS4/
C
C  BLOCK DATA 16 initializes miscellaneous integer-valued parameters.
C
C  Common block array subscripts:
C
C
C  Common block dictionary:
C
C  /IOUCOM/: a special format is utilized for the i/o unit number (#)
C            common block:
C
C  Unit#   Usage                     Description
C  ------  ------  ----------------------------------------------------------
C  IOUIMD  input   user supplied I/M credits (when IMFLAG=2)
C  IOUGEN  input   user supplied general input data
C  IOUERR  output  error MESSAGs
C  IOUREP  output  formatted report file
C  IOUASK  output  prompting MESSAGs file
C
C   Name   Type               Description
C  ------  ----  --------------------------------------------
C  /MAXIMA/:
C
C  MAXVEH   I    maximum number of vehicle types - additional categories
C                may be created by combining 2 or more of the base 12 types
C                (LDGT = LDGT1 + LDGT2)
C                and trailer towing ( = 3 = LDGV, LDGT1 & LDGT2 )
C  MAXPOL   I    maximum number of pollutants covered
C                ( = 11 )
C  MAXYRS   I    maximum number of model years in ICY's fleet (1 thru 20+)
C
C  /YEARS4/:
C
C  IY1941   I    4-digit representation of year 1941
C  IY1960   I    4-digit representation of year 1960
C  IY2020   I    4-digit representation of year 2020
C
C  Notes:
C
C  BD 16 was modified to conform to new ap42 fugative
C        dust calc.  MAXPOL is now = 11
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
C
C  Note: change IOUASK to 9 for Macintosh computers
      DATA IOUIMD,IOUGEN,IOUREP,IOUERR,IOUASK/5,4,8,2,6/
C
C     This data statement was changed to a series of parameter
C     statements in the param.inc file
C
CC    DATA MAXVEH,MAXPOL,MAXYRS/12,11,25/
C
      DATA IY1941,IY1960,IY2020/1941,1960,2020/
C
      END
      BLOCK DATA BD20
C
C  BLOCK DATA Subprogram 20: /MYRSAV/,/VMXCOM/,/JULREG/
C
C  BLOCK DATA 20 initializes fleet characterization data:
C  (1) annual mileage accumulation rates by relative (to evaluation year)
C      model year (JDX) and vehicle type (IV)
C  (2) July 1 registration distributions, also by JDX and IV
C  (3) vehicle miles travelled (vmt) mix, by IV
C  (4) registration (reg) mix, by IV
C
C  Common block array subscripts:
C
C  AMAR(MAXYRS,MAXVEH)    -  AMAR   ( JDX, IV )
C  JULORG(MAXYRS,MAXVEH)  -  JULORG ( JDX, IV )
C  REGMIX(MAXVEH)     -  REGMIX ( IV )
C  TFNORM(MAXVEH)     -  TFNORM ( IV )
C  VMTMIX(MAXVEH)     -  VMTMIX ( IV )
C
C  Common block dictionary:
C
C   Name   Type              Description
C  ------  ----  ------------------------------------------------
C  /MYRSAV/:
C
C  NEWCUM   I    cumulative model year mileage recalculation flag
C  AMAR     R    annual mileage accumulation rates
C  JULORG   R    Adjusted July 1 registration distributions
C                to account for zero 2BHDDV's before 1981 and zero LHDDV's
C                after 1976 (see GETMRN)
C
C  /VMXCOM/:
C
C  REGMIX   R    normalized registration mix (registration percentage by IV)
C  TFNORM   R    for each IV, the sum across its 25 model year window of
C                registrations times mileage accrual rate
C  VMTMIX   R    normalized vehicle miles traveled mix (vmt percentage by IV)
C
C /JULREG/:
C
C  JULORG   R    July 1 original registration distributions
C
C
C  Local array subscripts:
C
C  V12MAR(MAXYRS,2)  -  V12MAR (JDX, IV )
C  V34MAR(MAXYRS,2)  -  V34MAR (JDX, IV )
C  V56MAR(MAXYRS,2)  -  V56MAR (JDX, IV )
C  V78MAR(MAXYRS,2)  -  V78MAR (JDX, IV )
C  V90MAR(MAXYRS,2)  -  V90MAR (JDX, IV )
C  V11MAR(MAXYRS,2)  -  V11MAR (JDX, IV )
C
C  Local array dictionary:
C
C   Name   Type                Descriptions
C  ------  ----  ------------------------------------------------------
C  V12MAR   R    annual mileage accumulation rates for LDGVs and LDGT1s
C  V34MAR   R    annual mileage accumulation rates for LDGT2s and HDGVs
C  V56MAR   R    annual mileage accumulation rates for MCs and LDDVs
C  V78MAR   R    annual mileage accumulation rates for LDDTs and 2BHDs
C  V90MAR   R    annual mileage accumulation rates for LHDVs and MHDVs
C  V11MAR   R    annual mileage accumulation rates for HHDVs and BUSES
C
C  Notes:
C
C  The model year mileage recalculation flag "NEWCUM" is initialized here.
C
C  HDDV MAR values are initialized as all zeros, since they are calculated by
C  subroutine HDDMAR or supplied by the user.
C
C  AMAR and JULORG were updated for PART.
C
C  Nov-3-1993 @ ARC-bsg Subtask 339.  Made PART5 more like MOBILE5a.
C  Changed LDGV, LDGT1, LDGT2 and HDGV mileage distributions.
C  Changed LDGT1, LDGT2, HDGV, HDDV and LDDT registration
C  Changed HDGV and HDDV vehicle counts
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'REGIS.INC'
C
      DIMENSION RJ1(MAXYRS,6),RJ2(MAXYRS,6)
      DIMENSION V12MAR(MAXYRS,2),V34MAR(MAXYRS,2),V56MAR(MAXYRS,2),
     &          V78MAR(MAXYRS,2)
      DIMENSION V90MAR(MAXYRS,2),V11MAR(MAXYRS,2)
      DIMENSION V12COU(39,2),V34COU(39,2),V56COU(39,2),V78COU(39,2)
C
      EQUIVALENCE
     *(JULORG(1,1),RJ1(1,1)),
     *(JULORG(1,7),RJ2(1,1))
C
      EQUIVALENCE
     *(AMAR(1,1),V12MAR(1,1)),
     *(AMAR(1,3),V34MAR(1,1)),
     *(AMAR(1,5),V56MAR(1,1)),
     *(AMAR(1,7),V78MAR(1,1)),
     *(AMAR(1,9),V90MAR(1,1)),
     *(AMAR(1,11),V11MAR(1,1)),
C
     *(VCOUNT(1,1),V12COU(1,1)),
     *(VCOUNT(1,3),V34COU(1,1)),
     *(VCOUNT(1,5),V56COU(1,1)),
     *(VCOUNT(1,7),V78COU(1,1))
C
C  Initialize NEWCUM.
C
      DATA NEWCUM / 1 /
C
C  Initialize REGMIX and TFNORM.
C
      DATA REGMIX,TFNORM /24*0.0/
C
C  The vmt mix below represents a typical distribution, but is NOT used during
C  execution, where the mix is either computed in TFCALX or supplied by user:
C
CC    DATA VMTMIX/
CC   *     .7824, .0825, .0468, .0419, .0085, .0021, .0004, .0354,
CC   *     .0000, .0000, .0000, .0000, .0000/
C
C  Annual average mileage accumulation rates (divided by 100000)
C
C  Nov-3-1993 @ ARC-bsg Subtask 339.  Made PART5 more like MOBILE5a.
C  Changed LDGV, LDGT1, and LDGT2, and HDGV mileage distributions.
C
      DATA V12MAR/
C  LDGV
     *.14390, .13612, .12875, .12180, .11522,
     *.10899, .10310, .09751, .09225, .08726,
     *.08254, .07807, .07386, .06987, .06608,
     *.06251, .05913, .05594, .05291, .05005,
     *.04735, .04478, .04237, .04007, .03790,
C  LDGT1
     *.15442, .14508, .13631, .12807, .12032,
     *.11305, .10621, .09979, .09376, .08809,
     *.08276, .07776, .07306, .06864, .06449,
     *.06059, .05693, .05348, .05025, .04721,
     *.04436, .04168, .03916, .03679, .03456/
      DATA V34MAR/
C  LDGT2
     *.14779, .14259, .13758, .13275, .12809,
     *.12359, .11924, .11505, .11101, .10711,
     *.10335, .09972, .09621, .09283, .08957,
     *.08642, .08339, .08046, .07763, .07490,
     *.07227, .06973, .06728, .06492, .06264,
C  HDGV
     *.17251, .16185, .15185, .14246, .13365,
     *.12539, .11764, .11037, .10355, .09715,
     *.09114, .08551, .08022, .07526, .07061,
     *.06625, .06215, .05831, .05471, .05132,
     *.04815, .04517, .04238, .03976, .03730/
      DATA V56MAR/
C  MC
     *.04786, .04475, .04164, .03853, .03543,
     *.03232, .02921, .02611, .02300, .01989,
     *.01678, .01368, .00000, .00000, .00000,
     *.00000, .00000, .00000, .00000, .00000,
     *.00000, .00000, .00000, .00000, .00000,
C  LDDV
     *.17825, .16478, .15233, .14081, .13017,
     *.12033, .11124, .10283, .09506, .08788,
     *.08123, .07509, .06942, .06417, .05932,
     *.05484, .05069, .04686, .04332, .04005,
     *.03702, .03422, .03163, .02924, .02703/
      DATA V78MAR/
C  LDDT
     *.20140, .17572, .15432, .13639, .12133,
     *.10863, .09788, .08877, .08103, .07444,
     *.06883, .06405, .05999, .05655, .05365,
     *.05123, .04924, .04763, .04637, .04543,
     *.03342, .03080, .02839, .02616, .02411,
C  HDDV
C  Warning: There are no default HDDV MAR values.  Either the user supplies
C           them or they are computed by subroutine HDDMAR.
C
     * 25 * 0.000/
      DATA V90MAR/50 * 0.000/
C
      DATA V11MAR/50 * 0.000/
C
C  Vehicle registration distributions (enter unmodified data)
C   Modified Heavy Duty 2B, LHD, MHD, HHD for PART5 8-28-91
C  Nov-3-1993 @ ARC-bsg Subtask 339.  Made PART5 more like MOBILE5a.
C  Changed LDGT1, LDGT2, HDGV, LDDV, HDDV and LDDT registration
C
C
      DATA RJ1/
C  LDGV
     *.049,.079,.083,.082,.084,.081,.077,.056,.050,.051,.050,.054,.047,
     *.037,.024,.019,.014,.015,.011,.008,.006,.005,.004,.003,.010,
C  LDGT1
     *.063,.084,.084,.084,.084,.069,.059,.044,.036,.031,.030,.053,.047,
     *.046,.036,.028,.017,.022,.017,.014,.009,.008,.008,.005,.025,
C  LDGT2
     *.054,.072,.072,.072,.072,.052,.050,.034,.054,.031,.028,.080,.084,
     *.049,.039,.030,.018,.023,.018,.015,.009,.008,.009,.006,.026,
C  HDGV
     *.023,.047,.047,.047,.047,.038,.033,.021,.026,.029,.034,.064,.054,
     *.058,.051,.038,.043,.041,.035,.029,.021,.022,.022,.014,.117,
C  MC
     *.144,.168,.135,.109,.088,.070,.056,.045,.036,.029,.023,.097,.000,
     *.000,.000,.000,.000,.000,.000,.000,.000,.000,.000,.000,.000,
C  LDDV
     *.049,.079,.083,.082,.084,.081,.077,.056,.050,.051,.050,.054,.047,
     *.037,.024,.019,.014,.015,.011,.008,.006,.005,.004,.003,.010/
C
      DATA RJ2/
C  LDDT
     *.063,.084,.084,.084,.084,.069,.059,.044,.036,.031,.030,.053,.047,
     *.046,.036,.028,.017,.022,.017,.014,.009,.008,.008,.005,.025,
C  2HDV
     *.034,.067,.067,.067,.067,.073,.061,.040,.041,.051,.053,.066,.055,
     *.057,.045,.019,.023,.028,.024,.016,.011,.009,.007,.005,.016,
C  LHDV
     *.034,.067,.067,.067,.067,.073,.061,.040,.041,.051,.053,.066,.055,
     *.057,.045,.019,.023,.028,.024,.016,.011,.009,.007,.005,.016,
C  MHDV
     *.034,.067,.067,.067,.067,.073,.061,.040,.041,.051,.053,.066,.055,
     *.057,.045,.019,.023,.028,.024,.016,.011,.009,.007,.005,.016,
C  HHDV
     *.034,.067,.067,.067,.067,.073,.061,.040,.041,.051,.053,.066,.055,
     *.057,.045,.019,.023,.028,.024,.016,.011,.009,.007,.005,.016,
C  BUS
     *.030,.060,.059,.058,.057,.055,.054,.053,.052,
     *.050,.050,.049,.047,.046,.045,.044,.044,.043,
     *.042,.010,.008,.007,.006,.005,.025/
C  HDDV
c     *.057,.107,.103,.075,.080,.097,.089,.052,.046,.035,.042,.047,.034,
c     *.028,.012,.014,.017,.019,.012,.009,.006,.005,.005,.002,.007/
C
C
      DATA JULMYR/300*0./
C
C VCOUNT - Vehicle Count by IV class, scaled by / 10**5; Note LDGV & LDDV
C counts are the identical sum of their registrations and ditto with LDGT1
C and LDDT. Hence PART needs GSFVCT to split the sums properly, for the
C other IV's GSFVCT is 1.0 and has no effect.
C
C ICY calender year run from 1982 to 2020. The 1982 values are used for all
C pre 1992 ICY's. IV = 8 (MC) Motor Cycles is a constant 4.179.
C
C  LDGV
      DATA V12COU/
     * 106.867, 108.960, 112.018, 114.662, 117.268, 119.849, 121.519,
     * 122.758, 124.658, 126.556, 128.535, 130.591, 132.720, 134.917,
     * 137.030, 139.203, 141.431, 143.712, 146.044, 148.353, 150.707,
     * 153.104, 155.542, 158.020, 160.496, 163.006, 165.554, 168.132,
     * 170.745, 173.389, 176.062, 178.765, 181.497, 184.257, 186.638,
     * 189.037, 191.454, 193.887, 196.338,
C
C  LDGT1
C
     * 20.785, 21.026, 21.930, 23.102, 24.574, 26.002, 27.460,
     * 29.264, 30.558, 32.164, 33.745, 35.315, 36.822, 38.280,
     * 39.672, 41.045, 42.412, 43.768, 45.109, 46.427, 47.746,
     * 49.067, 50.383, 51.701, 53.017, 54.301, 55.605, 56.923,
     * 58.254, 59.594, 60.947, 62.309, 63.684, 65.072, 66.381,
     * 67.701, 69.039, 70.389, 71.759/
C
C  LDGT2
      DATA V34COU/
C
     * 10.175, 10.444, 10.942, 11.207, 11.886, 12.381, 13.372,
     * 13.940, 14.073, 14.503, 14.925, 15.330, 15.775, 16.246,
     * 16.704, 17.165, 17.624, 18.082, 18.551, 19.008, 19.464,
     * 19.919, 20.380, 20.844, 21.298, 21.791, 22.272, 22.749,
     * 23.225, 23.704, 24.183, 24.666, 25.152, 25.641, 26.047,
     * 26.452, 26.857, 27.261, 27.664,
C
C  Nov-3-1993 @ ARC-bsg Subtask 339.  Made PART5 more like MOBILE5a.
C  Changed HDGV and HDDV vehicle counts
C
C  HDGV
C
     *  4.522,  4.978,  5.300,  5.806,  5.827,  6.091,  6.190,
     *  6.443,  6.499,  6.680,  6.853,  7.026,  7.207,  7.396,
     *  7.569,  7.743,  7.922,  8.112,  8.303,  8.496,  8.700,
     *  8.907,  9.002,  9.225,  9.456,  9.694,  9.941, 10.182,
     * 10.394, 10.653, 10.920, 11.190, 11.463, 11.739, 11.976,
     * 12.217, 12.457, 12.695, 12.934/
C
C  MC - Motor Cycles
C
      DATA V56COU/  39*4.219,
C
C  LDDV
C
     * 106.867, 108.960, 112.018, 114.662, 117.268, 119.849, 121.519,
     * 122.758, 124.658, 126.556, 128.535, 130.591, 132.720, 134.917,
     * 137.030, 139.203, 141.431, 143.712, 146.044, 148.353, 150.707,
     * 153.104, 155.542, 158.020, 160.496, 163.006, 165.554, 168.132,
     * 170.745, 173.389, 176.062, 178.765, 181.497, 184.257, 186.638,
     * 189.037, 191.454, 193.887, 196.338/
C
C  LDDT
C
      DATA V78COU/
     * 20.785, 21.026, 21.930, 23.102, 24.574, 26.002, 27.460,
     * 29.264, 30.558, 32.164, 33.745, 35.315, 36.822, 38.280,
     * 39.672, 41.045, 42.412, 43.768, 45.109, 46.427, 47.746,
     * 49.067, 50.383, 51.701, 53.017, 54.301, 55.605, 56.923,
     * 58.254, 59.594, 60.947, 62.309, 63.684, 65.072, 66.381,
     * 67.701, 69.039, 70.389, 71.759,
C
C  Nov-3-1993 @ ARC-bsg Subtask 339.  Made PART5 more like MOBILE5a.
C  Changed HDGV and HDDV vehicle counts
C
C  HDDV
C
     *  1.505,  1.696,  1.972,  2.275,  2.541,  2.870,  3.202,
     *  3.554,  3.807,  4.144,  4.496,  4.853,  5.211,  5.566,
     *  5.920,  6.274,  6.630,  6.979,  7.329,  7.665,  7.996,
     *  8.328,  8.668,  8.988,  9.296,  9.601,  9.897, 10.202,
     * 10.494, 10.783, 11.067, 11.349, 11.629, 11.909, 12.148,
     * 12.382, 12.616, 12.847, 13.078/
C
C
      END
      BLOCK DATA BD23
C
C  BLOCK DATA Subprogram 23: /GSFCOM/
C
C  This Block Data set comes from the November, 1991 release.
C
C  BLOCK DATA 23 initializes the gasoline vs diesel sales fractions.
C
C  Common block array subscripts:
C
C  GSFRAC(22,MAXVEH,2)   -  GSFRAC ( IGSFPT, IV, IR )
C  MYGSF(22,MAXVEH,2)    -  MYGSF ( IG, IV, IR )
C
C  Common block dictionary:
C
C   Name   Type              Description
C  ------  ----  ------------------------------------------------
C  /GSFCOM/:
C
C  MAXGSF   I    maximum number of sales fractions for any IR & IV case
C  GSFRAC   I    gasoline vs diesel sales fractions
C  MYGSF    I    gasoline vs diesel sales fraction model year groups
C
C  Local array subscripts:
C
C  GSFLO(22,MAXVEH)   -  GSFLO ( IGSFPT, IV)
C  GSFHI(22,MAXVEH)   -  GSFHI ( IGSFPT, IV)
C  IGSFLO(22,MAXVEH)  -  IGSFLO ( IG, IV )
C  IGSFHI(22,MAXVEH)  -  IGSFHI ( IG, IV )
C
C  Local array dictionary:
C
C   Name   Type              Description
C  ------  ----  -----------------------------------------------
C  GSFLO    R    low altitude region sales fractions
C  GSFHI    R    high altitude region sales fractions
C  IGSFLO   I    last year of sales fraction model year groups
C                for low altitude regions
C  IGSFHI   I    last year of sales fraction model year groups
C                for high altitude regions
C
C  Notes:
C
C  GSFRAC and MYGSF were updated for PART.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'GSFCOM.INC'
C
      DIMENSION
     *   GSFLO1(22,6), GSFLO2(22,6),
     *   GSFHI(22,6), GSFHI2(22,6),
     *   IGSFL1(22,6), IGSFL2(22,6),
     *   IGSFHI(22,6), IGSFH2(22,6)
C
      EQUIVALENCE
     *   (GSFRAC(1,1,1),GSFLO1(1,1)),
     *   (GSFRAC(1,7,1),GSFLO2(1,1)),
     *   (GSFRAC(1,1,2),GSFHI(1,1)),
     *   (GSFRAC(1,7,2),GSFHI2(1,1)),
     *   (MYGSF(1,1,1),IGSFL1(1,1)),
     *   (MYGSF(1,7,1),IGSFL2(1,1)),
     *   (MYGSF(1,1,2),IGSFHI(1,1)),
     *   (MYGSF(1,7,2),IGSFH2(1,1))
C
      DATA MAXGSF/22/
C
C  Gas or diesel fraction of total (g + d) vehicle type sales
C
C  Low altitude region
      DATA GSFLO1/
C  LDGV
     *1.000, .999, .998, .997, .998, .997, .995, .991, .979, .956, .941,
     * .953, .979, .983, .991, .997,1.000, .999, .998, .997, .000, .000,
C  LDGT1
     *1.000, .992, .982, .965, .944, .907, .953, .977, .989, .993, .997,
     * .998, .996, .994, .991, .989, .987, .986, .984, .982, .980, .977,
C  LDGT2
     *1.000, .992, .982, .965, .944, .907, .953, .977, .989, .993, .997,
     * .998, .996, .994, .991, .989, .987, .986, .984, .982, .980, .977,
C  HDGV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  MC
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  LDDV
     * .000, .001, .002, .003, .002, .003, .005, .009, .021, .044, .059,
     * .047, .021, .017, .009, .003, .000, .001, .002, .003, .000, .000/
       DATA GSFLO2/
C  LDDT
     * .000, .008, .018, .035, .056, .093, .047, .023, .011, .007, .003,
     * .002, .004, .006, .009, .011, .013, .014, .016, .018, .020, .023,
C  2HDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  LHDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  MHDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  HHDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  BUS
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000/
C  HDDV
c     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
c     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000/
C
C  High altitude region
      DATA GSFHI/
C  LDGV
     *1.000, .999, .998, .997, .998, .997, .995, .991, .979, .956, .941,
     * .953, .979, .983, .991, .997,1.000, .999, .998, .997, .000, .000,
C  LDGT1
     *1.000, .992, .982, .965, .944, .907, .953, .977, .989, .993, .997,
     * .998, .996, .994, .991, .989, .987, .986, .984, .982, .980, .977,
C  LDGT2
     *1.000, .992, .982, .965, .944, .907, .953, .977, .989, .993, .997,
     * .998, .996, .994, .991, .989, .987, .986, .984, .982, .980, .977,
C  HDGV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  MC
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  LDDV
     * .000, .001, .002, .003, .002, .003, .005, .009, .021, .044, .059,
     * .047, .021, .017, .009, .003, .000, .001, .002, .003, .000, .000/
       DATA GSFHI2/
C  LDDT
     * .000, .008, .018, .035, .056, .093, .047, .023, .011, .007, .003,
     * .002, .004, .006, .009, .011, .013, .014, .016, .018, .020, .023,
C  2HDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  LHDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  MHDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  HHDV
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
C  BUS
     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000/
C  HDDV
c     *1.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
c     *.000, .000, .000, .000, .000, .000, .000, .000, .000, .000, .000/
C
C
C
C  Last year of light duty (or motorcycle) model year groups
C
C  Low altitude region
       DATA IGSFL1/
C  LDGV
     *   1970,1971,1973,1974,1975,1976,1977,1978,1979,1980,1981,
     *   1982,1983,1984,1985,1987,1990,1996,2000,2020,0000,0000,
C  LDGT1
     *   1977,1978,1979,1980,1981,1982,1983,1984,1985,1986,1987,
     *   1995,1997,1999,2001,2003,2005,2007,2009,2011,2013,2020,
C  LDGT2
     *   1977,1978,1979,1980,1981,1982,1983,1984,1985,1986,1987,
     *   1995,1997,1999,2001,2003,2005,2007,2009,2011,2013,2020,
C  HDGV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  MC
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  LDDV
     *   1970,1971,1973,1974,1975,1976,1977,1978,1979,1980,1981,
     *   1982,1983,1984,1985,1987,1990,1996,2000,2020,0000,0000/
       DATA IGSFL2/
C  LDDT
     *   1977,1978,1979,1980,1981,1982,1983,1984,1985,1986,1987,
     *   1995,1997,1999,2001,2003,2005,2007,2009,2011,2013,2020,
C  2HDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  LHDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  MHDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  HHDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  BUS
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000/
C  HDDV
c     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
c     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000/
C  High altitude region
       DATA IGSFHI/
C  LDGV
     *   1970,1971,1973,1974,1975,1976,1977,1978,1979,1980,1981,
     *   1982,1983,1984,1985,1987,1990,1996,2000,2020,0000,0000,
C  LDGT1
     *   1977,1978,1979,1980,1981,1982,1983,1984,1985,1986,1987,
     *   1995,1997,1999,2001,2003,2005,2007,2009,2011,2013,2020,
C  LDGT2
     *   1977,1978,1979,1980,1981,1982,1983,1984,1985,1986,1987,
     *   1995,1997,1999,2001,2003,2005,2007,2009,2011,2013,2020,
C  HDGV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  MC
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  LDDV
     *   1970,1971,1973,1974,1975,1976,1977,1978,1979,1980,1981,
     *   1982,1983,1984,1985,1987,1990,1996,2000,2020,0000,0000/
      DATA IGSFH2/
C  LDDT
     *   1977,1978,1979,1980,1981,1982,1983,1984,1985,1986,1987,
     *   1995,1997,1999,2001,2003,2005,2007,2009,2011,2013,2020,
C  2HDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  LHDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  MHDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  HHDV
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
C  BUS
     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000/
C  HDDV
c     *   2020,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,
c     *   0000,0000,0000,0000,0000,0000,0000,0000,0000,0000,0000/
C
C
      END
      BLOCK DATA BD24
C
C  BLOCK DATA Subprogram 24: /NAMES1/,/NAMES2/,/STRING/,/USDATA/
C
C  BLOCK DATA 24 initializes character strings used in prompts & output formats
C  and zeroes pointers into character string arrays.
C
C  Common block array subscripts:
C
C  NAMVEH(MAXVEH) - NAMVEH ( IV )
C  NAMFLG(10)     - NAMFLG ( IFG )
C  NOYES(2)       - NOYES  ( <ILDT,INO,IMFLAG,ATPFLG> )
C
C  Jan-7-1994 @ CSC-bsg Request 380 user-supplied rates
C  Apr-11-1994 @ CSC-bsg Request 411 removed tampering and misfueling
C  as user inputs
C
C  USNAME(4,4)    - USNAME ( ICH, IUSD )
C  IUSD(4)        - IUSD   ( ICT )
C
C  Common block dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------
C  /NAMES1/:
C
C  NAMVEH   C*8  vehicle type names
C
C  Oct-13-1993 @ ARC-bsg Subtask 325  correct CBD terminology
C
C  NAMBUS   C*8  alternative bus cycle names
C  NAMFLG   C*8  control flag names for prompts and error MESSAGs
C
C  /NAMES2/:
C
C  NAMPOL   C*11  pollutant names
C  NAMREG   C*4   region names
C  NAMFUD   C*28  fugitive dust names
C
C  /STRING/:
C
C  NOYES    C*4  character string for no/yes
C  COMMA    C*4  character string for comma
C  PERIOD   C*4  character string for period
C  COLON    C*1  character string for colon
C
C  /USDATA/:
C
C  IUSD     I    pointers to the names of user supplied one-time data for run
C  NUSD     I    number of names of user supplied one-time data for this run
C  USNAME   R    names of one-time data supplied by user
C
C  Notes:
C
C  BD 24 was modified for PART, adding /NAMES2/.
C  BD 24 was modified for PART
C  BD 24 was modified for new fugitive dust calc.
C        reducing the number of pollutant names to
C        thirteen.
C  Oct-13-1993 @ ARC-bsg Subtask 325  correct CBD terminology
C  Jan-7-1994 @ CSC-bsg Request 380 user-supplied rates
C  Mar-9-1994 @ CSC-bsg Request 394 SO2FLG
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  Mar-17-1994 @ CSC-bsg Request 407 Change SULFLG to RFGFLG
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'NAMES.INC'
C
C
C  /NAMES1/: These names are used in input routines.
C
      DATA NAMVEH/
     *   ' LDGV   ',
     *   'LDGT1   ',
     *   'LDGT2   ',
     *   ' HDGV   ',
     *   '  MC    ',
     *   ' LDDV   ',
     *   ' LDDT   ',
     *   '2BHDDV  ',
     *   'LHDDV   ',
     *   'MHDDV   ',
     *   'HHDDV   ',
     *   'BUSES   ',
     *   ' Veh.   '/
C
C  Oct-13-1993 @ ARC-bsg Subtask 325  correct CBD terminology
C
      DATA NAMBUS/
     *   '        ', 'Transit ', 'Buses** ',
     *   '        ', '  CBD   ', 'Buses** ',
     *   'Heavy   ', 'Urban   ', 'Buses** '/
C
C  Mar-9-1994 @ CSC-bsg Request 394 SO2FLG
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  Mar-17-1994 @ CSC-bsg Request 407 Change SULFLG to RFGFLG
C
      DATA NAMFLG/
     *            ' VMFLAG ',
     *            ' MYMRFG ',
     *            ' IMFLAG ',
     *            ' RFGFLG ',
     *            ' OUTFMT ',
     *            ' IDLFLG ',
     *            ' SO2FLG ',
     *            ' PRTFLG ',
     *            ' BUSFLG '/
C
C
C  /NAMES2/: These names are used in OUTFMT 3 and 4 output.
C  Feb-15-1994 @ CSC-bsg Request 394 SO2FLG
C  Oct-28-1994 @ CSC-ked Request 474 PART5 Fugitive Dust Reformatting
C
      DATA NAMPOL/    'Lead:      ','SOF:       ','RCP:       ',
     *  'Direct SO4:','Exhaust PM:','Gas. SO2:  ','Indir. SO4:',
     *  'Sulfate PM:','Brake:     ','Tire:      ','Total PM:  '/
cc     *  'Unpvd Dust:','Paved Dust:'/
      DATA NAMREG/'Low ','High','Mid '/
      DATA NAMFUD/'Unpaved Roads Fleet Average ',
     *            '  Paved Roads Fleet Average '/
C
C  /STRING1/:
C
      DATA NOYES/'No  ','Yes '/
      DATA COMMA/',   '/,PERIOD/'.   '/,COLON/':'/
C
C  /USDATA/:
C
C  Jan-7-1994 @ CSC-bsg Request 380 user-supplied rates
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  Apr-12-1994 @ CSC-bsg Request 419 removed all user supplied rates except
C  VMT, mileage and veh registrations.
C
      DATA USNAME/' veh mil','es trave','led mixt','ure     ',
     *            ' mileage',' accrual',' distrib','utions  ',
     *            ' veh reg','istratio','n distri','butions '/
C
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C
      DATA NUSD,IUSD/4*0/
C
      END
      BLOCK DATA BD26
C
C  BLOCK DATA Subprogram 26: /HDDMAR/,/HDDREG/
C
C  BLOCK DATA 26 initializes the HDDV fleet characterization data by weight
C  subclass (C2B,L,M,H,TRAN,COMM,SCHL array name prefixes) & by relative
C  model yr (JDX & KDX):
C  (1) annual mileage accumulation rates
C  (2) total new registrations
C
C  Common block array subscripts:
C
C  C2BDVM(MAXYRS) - C2BDVM ( JDX )
C   LHDVM(MAXYRS) -  LHDVM ( JDX )
C   MHDVM(MAXYRS) -  MHDVM ( JDX )
C   HHDVM(MAXYRS) -  HHDVM ( JDX )
C  TRANVM(MAXYRS) - TRANVM ( JDX )
C  COMMVM(MAXYRS) - COMMVM ( JDX )
C  SCHLVM(MAXYRS) - SCHLVM ( JDX )
C
C  C2BDRG(21) - C2BDRG ( KDX )
C   LHDRG(21) -  LHDRG ( KDX )
C   MHDRG(21) -  MHDRG ( KDX )
C   HHDRG(21) -  HHDRG ( KDX )
C  TRANRG(26) - TRANRG ( KDX )
C  COMMRG(26) - COMMRG ( KDX )
C  SCHLRG(26) - SCHLRG ( KDX )
C    KDX=1 for pre-1981, 2 for 1981, ... , 21 for 2000+.
C
C  Common block dictionary:
C
C   Name   Type           Description
C  ------  ----  ---------------------------------------------
C  /HDDMAR/:
C
C  C2BDVM   R    class 2b HDDV mileage accumulation rates
C  LHDVM    R    light HDDV mileage accumulation rates
C  MHDVM    R    medium HDDV mileage accumulation rates
C  HHDVM    R    heavy HDDV mileage accumulation rates
C  TRANVM   R    transit bus mileage accumulation rates
C  COMMVM   R    commercial bus mileage accumulation rates
C  SCHLVM   R    school bus mileage accumulation rates
C
C  /HDDREG/:
C
C  C2BDRG   R    class 2b HDDV new registrations
C  LHDRG    R    light HDDV new registrations
C  MHDRG    R    medium HDDV new registrations
C  HHDRG    R    heavy HDDV new registrations
C  TRANRG   R    transit bus new registrations
C  COMMRG   R    commercial bus new registrations
C  SCHLRG   R    school bus new registrations
C  Notes:
C
C  All /HDDMAR/ & /HDDREG/ arrays were updated for PART.
C  ZML/TAMDR coefficients were updated for PART.
C  Nov-3-1993 @ ARC-bsg Subtask 339.  Made PART5 more like MOBILE5a.
C  Changed HDDV mileage distributions.
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'HDFLEET.INC'
C
C  /HDDMAR/:
C
C  Annual average Class 2B truck mileage accumulation (divided by 100000)
C
      DATA C2BDVM/
     * .22517, .20009, .17779, .15798, .14038,
     * .12474, .11084, .09849, .08752, .07777,
     * .06910, .06140, .05456, .04848, .04308,
     * .03828, .03402, .03023, .02686, .02387,
     * .02121, .01884, .01675, .01488, .01322/
C
C  Annual average Light HDDV mileage accumulation (divided by 100000)
C
      DATA LHDVM/
     *.24239, .23273, .22346, .21455, .20600,
     *.19779, .18990, .18233, .17507, .16809,
     *.16139, .15496, .14878, .14285, .13716,
     *.13169, .12644, .12140, .11656, .11192,
     *.10746, .10317, .09906, .09511, .09132/
C
C  Annual average medium HDDV mileage accumulation (divided by 100000)
C
      DATA MHDVM/
     *.26081, .25204, .24357, .23538, .22746,
     *.21982, .21243, .20528, .19838, .19171,
     *.18527, .17904, .17302, .16720, .16158,
     *.15614, .15089, .14582, .14092, .13618,
     *.13160, .12718, .12290, .11877, .11478/
C
C  Annual average heavy HDDV mileage accumulation (divided by 100000)
C
      DATA HHDVM/
     *.62176, .58663, .55348, .52220, .49269,
     *.46485, .43858, .41380, .39042, .36836,
     *.34754, .32790, .30937, .29189, .27540,
     *.25983, .24515, .23130, .21823, .20590,
     *.19426, .18328, .17293, .16315, .15393/
C
C  Annual average Transit Bus mileage accumulation (divided by 100000)
C
      DATA TRANVM/
     *.66509, .61164, .56249, .51729, .47572,
     *.43749, .40234, .37001, .34027, .31293,
     *.28778, .26466, .24339, .22383, .20584,
     *.18930, .17409, .16010, .14723, .13540,
     *.12460, .11470, .10580, .09790, .09100/
C
C  Annual average Commercial Bus mileage accumulation (divided by 100000)
C
      DATA COMMVM/
     *.68841, .63309, .58222, .53543, .49240,
     *.45283, .41645, .38298, .35220, .32390,
     *.29787, .27394, .25192, .23168, .21306,
     *.19594, .18019, .16571, .15239, .14015,
     *.12915, .11914, .11004, .10194, .09489/
C
C  Annual average School Bus mileage accumulation (divided by 100000)
C
      DATA SCHLVM/
     *.15720, .14457, .13295, .12227, .11244,
     *.10341, .09510, .08746, .08043, .07396,
     *.06802, .06256, .05753, .05291, .04865,
     *.04474, .04115, .03784, .03480, .03200,
     *.02955, .02737, .02545, .02375, .02232/
C
C  /HDDREG/:
C
C  Annual Class 2B truck new registrations (1980- through 2000+)
C
      DATA C2BDRG/
     * .001, .001, .047, .119, .200, .309, .397, .495, .599, .710,
     * .831, .956,1.086,1.214,1.341,1.464,1.585,1.702,1.816,1.925,
     *2.030/
C
C  Annual light HDDV new registrations (1980- through 2000+)
C
      DATA LHDRG/
     * .003, .004, .009, .015, .024, .041, .057, .074, .091, .107,
     * .122, .136, .150, .164, .176, .188, .200, .211, .221, .232,
     * .241/
C
C  Annual medium HDDV new registrations (1980- through 2000+)
C
      DATA MHDRG/
     * .536, .570, .590, .609, .648, .711, .761, .811, .858, .902,
     * .944, .988,1.033,1.079,1.127,1.175,1.225,1.277,1.328,1.379,
     *1.430/
C
C  Annual heavy HDDV new registrations (1980- through 2000+)
C
      DATA HHDRG/
     * .990, 1.033,1.049,1.067,1.129,1.189,1.228,1.260,1.287,1.308,
     *1.324,1.340,1.356,1.372,1.387,1.406,1.425,1.447,1.470,1.495,
     *1.522/
C
C  Annual Transit Bus new registrations (1962- through 1987+)
C
      DATA TRANRG/
     * .050, .050, .050, .050, .050, .050, .050, .050, .050, .049,
     * .048, .048, .049, .051, .052, .052, .053, .054, .059, .060,
     * .062, .062, .079, .079, .058, .058/
C
C  Annual Commercial Bus new registrations (1962- through 1987+)
C
      DATA COMMRG/
     * .026, .033, .034, .035, .034, .040, .040, .041, .041, .039,
     * .040, .041, .041, .043, .044, .046, .049, .051, .047, .047,
     * .051, .049, .030, .030, .052, .053/
C
C  Annual School Bus new registrations (1962- through 1987+)
C
      DATA SCHLRG/
     * .210, .216, .221, .229, .238, .247, .262, .274, .289, .297,
     * .316, .335, .354, .366, .380, .391, .396, .411, .418, .433,
     * .442, .471, .471, .480, .480, .487/
C
      END
      BLOCK DATA BD27
C
C  BLOCK DATA Subprogram 27: /CUMCOM/,/FLAGS1/,/FLAGS2/,/FLAGS3/,/FLAGS4/,
C                            /MYRCAL/,/PROJEC/,/REGISF/,/RESUL1/,/RESUL3/
C
C  BLOCK DATA 27's common blocks did not need to be initialized, so were
C  assigned dummy zeroes, to facilitate debugging, to prevent control statement
C  failure when compiled under a FORTRAN that does not employ the left to right
C  rule, etc.
C
C  Common block array subscripts:
C
C  CUMMIL(MAXYRS,MAXVEH)    -  CUMMIL ( JDX, IV )
C  GSFVCT(MAXVEH)           -  GSFVCT ( IV )
C  JANMYR(MAXYRS,MAXVEH)    -  JANMYR ( JDX, IV )
C  PROJID(20)               -  PROJID ( ICH )
C  TF(MAXYRS,MAXVEH)        -  TF ( IDX, IV )
C  TFMYM(MAXYRS,MAXVEH)     -  TFMYM ( JDX, IV )
C  EF(MAXPOL,MAXVEH)        -  EF(IP,IV)
C  VEF(MAXPOL)              -  VEF ( IP )
C  XMYM(MAXYRS,MAXVEH)      -  XMYM ( JDX, IV )
C
C  Common block dictionary:
C
C   Name   Type              Description
C  ------  ----  --------------------------------------------------
C  /CUMCOM/:
C
C  CUMMIL   R    cumulative mileage accumulation rates
C
C  /FLAGS1/:
C
C  SPDFLG   I    1 = user supplies one speed for all vehicle types
C                2 = user supplies 8 speeds, 1 for each vehicle type
C  VMFLAG   I    1 = use default vmt mix
C                2 = user supplies a new vmt mix for each scenario
C                3 = user supplies 1 vmt mix to apply to all scenarios
C
C  /FLAGS2/:
C
C  MYMRFG   I    1 = default registration distributions/mileage accrual rates
C                2 = user supplies mileage accumulation rates
C                3 = user supplies registration distributions
C                4 = user supplies both
C  IMFLAG   I    1 = no I/M program
C                2 = I/M program
C
C  /FLAGS3/:
C
C  OUTFMT    I    various output format selections:
C                1 = long (212 column) numerical format
C                2 = short (130 column) numerical format
C                3 = 112 column descriptive format
C                4 = 80 column descriptive format
C  RFGFLG   I    1 = default case
C                2 = trigger Phase I and II of reformulated gas
C                3 = user supplied sulfur content of diesel
C                    fuel (weight percent)
C
C  /FLAGS4/:
C
C  PRTFLG   I    1 = All emission factors (including dust)
C                2 = Exhaust PM factors only
C                3 = Exhaust PM factors and Indirect PM factors,
C                               not including dust
C  IDLFLG   I    1 = Do not print idle emission factors
C                2 = Print idle emission factors
C
C  Oct-13-1993 @ ARC-bsg Subtask 325  correct CBD terminology
C
C  BUSFLG   I    1 = Do not print CBD emission factors
C                2 = Print Transit and CBD emission factors
C                3 = Print Heavy Urban Bus emission factors
C
C  /MYRCAL/:
C
C  XMYM     R    January 1 model year mileage accumulation rates used to
C                compute CUMMIL
C  JANMYR   R    January 1 registration distributions
C  TF       R    travel weighting fractions
C  TFMYM    R    January 1 mileage accumulation rates used to compute TF
C
C  /PROJEC/:
C
C  PROJID   R    user supplied project (i.e., run) title
C
C  /REGISF/:
C
C  GSFVCT   R    fleet gasoline/diesel sales fractions used to split LDV, LDT
C
C  /RESUL1/:
C
C  EF       R    Emission factor for vehicle class IV, pollutant IP
C
C  Oct-13-1993 @ ARC-bsg Subtask 325  correct CBD terminology
C
C  /RESUL3/:
C
C  Prefix in v/a in /RESUL3/:
C
C  VEF     R    For each IP, emission factor for each IV class weighted by
C                corresponding normalized vmt mix fraction and summed together
C
C
C  Notes:
C  Oct-13-1993 @ ARC-bsg Subtask 325  correct CBD terminology
C  Oct-13-1993 @ ARC-bsg Subtask 325 increase number of EF values
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
C
C
      DATA CUMMIL/300*0.0/
      DATA SPDFLG,VMFLAG/2*0/
      DATA MYMRFG,IMFLAG/2*0/
      DATA OUTFMT/1*0/
      DATA PRTFLG/0/
      DATA XMYM,JANMYR,TF,TFMYM/1200*0.0/
      DATA GSFVCT/12*0.0/
C
C  Oct-13-1993 @ ARC-bsg Subtask 325 increase number of EF values
C
C  The Repeat Counter for EF is the result of MAXPOL*(MAXVEH+3)
C
      DATA EF/165*0.0/
      DATA VEF/MAXPOL*0.0/
C
      END
      BLOCK DATA BD28
C
C  BLOCK DATA Subprogram 28: /RLCOM1/
C
C  BLOCK DATA 28 defines the road fuel economy rates.
C
C  Common block array subscripts:
C  ROADFE(32,5)  -  ROADFE ( MDX, IVTAM )
C
C  Common block dictionary:
C
C   Name   Type             Description
C  ------  ----  --------------------------------------
C  /RLCOM1/ block data supplied road fuel economy rates
C
C  ROADFE   R    road fuel economy rates
C
C  Local array subscripts:
C
C  RDFE1(32,3) - RDFE1(MDX,IVTAM)
C  RDFE2(32,2) - RDFE2(MDX,IVTAM)
C
C
C  Notes:
C
C  The MDX Mapping to MY for ROADFE (IVTAM=1 thru 4) is:
C
C   MDX     MY
C    1     1941-1969
C    2-31  1970-1999 (i.e., MDX=MY-1969+1)
C    32    2000-2020
C
C  The MDX Mapping to MY for ROADFE (IVTAM=5) is:
C
C   MDX     MY
C    1      PRE -1977
C    2-11   1977-1986 (i.e., MDX=MY-1976+1)
C    12     POST 1987
C
C  BD 28 was added for PART.
C  BD 28 was updated on 11/9/90 - added MC fuel economy rates.
C
      INCLUDE 'ROADFE.INC'
C
C
C  /RLCOM1/:
C
      DIMENSION RDFE1(32,3), RDFE2(32,2)
      EQUIVALENCE (RDFE1(1,1), ROADFE(1,1)),
     *            (RDFE2(1,1), ROADFE(1,4))
C
      DATA RDFE1/
C  LDGV
     1  12.7, 12.8, 12.3, 12.4, 12.2, 12.2, 13.5, 14.9,
     1  15.6, 17.0, 17.2, 19.8, 21.2, 21.9, 21.7, 22.0,
     1  22.6, 23.3, 23.6, 23.7, 23.6, 23.6, 23.6, 23.6,
     1  23.5, 23.5, 23.5, 23.5, 23.4, 23.4, 23.4, 23.3,
C  LDGT1
     2  11.1, 11.1, 10.7, 10.8, 10.6, 10.6, 11.9, 12.3,
     2  13.3, 13.0, 12.6, 15.7, 17.0, 17.3, 17.6, 17.2,
     2  17.3, 18.0, 18.0, 17.7, 17.8, 17.8, 17.8, 17.8,
     2  17.7, 17.7, 17.7, 17.7, 17.7, 17.6, 17.6, 17.6,
C  LDGT2
     3  11.1, 11.1, 10.7, 10.8, 10.6, 10.6, 11.9, 12.3,
     3  13.3, 13.0, 12.6, 15.7, 17.0, 17.3, 17.6, 17.2,
     3  17.3, 18.0, 18.0, 17.7, 17.8, 17.8, 17.8, 17.8,
     3  17.7, 17.7, 17.7, 17.7, 17.7, 17.6, 17.6, 17.6/
C
       DATA RDFE2/
C  HDGV
     4  6.45,  6.45,  6.08,  5.70,  6.10,  6.50,  6.92,  6.81,
     4  7.16,  7.74,  8.07,  8.75,  9.09,  9.45,  9.95, 10.01,
     4 10.01, 10.03, 10.05, 10.13, 10.19, 10.26, 10.33, 10.42,
     4 10.61, 10.72, 10.79, 10.88, 10.87, 10.94, 11.00, 11.08,
C  MC
     5 65.937, 65.937, 64.120, 63.137, 61.070, 57.834,
     5 57.394, 57.583, 56.782, 57.102, 56.794, 56.794,
     5 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
     5 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
     5 0.0, 0.0, 0.0, 0.0, 0.0, 0.0/
C
      END
      BLOCK DATA BD29
C
C  BLOCK DATA Subprogram 29: /HDCCOM/
C
C  BLOCK DATA 29 initializes grams-per-brakehorsepower-hour to grams-per-mile
C  units conversion variables.
C
C  Common block array subscripts:
C
C  Oct-20-1993 @ ARC-bsg Subtask 325 expanded BUS conversion factors
C  HDCFAC(39,8)  -  HDCFAC ( IG, IVHD )
C  BUSCF(3)
C
C  Common block dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------
C  /HDCCOM/:
C
C  HDCFAC   R    HDV gpbhp to gpm conversion factors
C  LOWYR    I    lowest my for which HDCFAC is defined.  All my < LOWYR are
C                assigned LOWYR's conversion factors.
C  MAXCIG   I    maximum HDCFAC index allowed = 1st dimension of HDCFAC = 39
C                = index of highest my for which HDCFAC is defined, currently
C                2000.  All my > 2000 are assigned MAXCIG's factors.
C
C  Local array subscripts:
C
C  HDCGAS(39)  -  HDCGAS ( IG )
C  HDCDIE(39)  -  HDCDIE ( IG )
C
C  Local array dictionary:
C
C   Name   Type                Description
C  ------  ----  -----------------------------------------
C  HDCDIE   R    HDDV gpbhp to gpm units conversion factors
C
C  BD 29 was added for PART.
C  The conversion factors were updated for PART, with MAXCIG 36 to 37.
C  Oct-20-1993 @ ARC-bsg Subtask 325 expanded BUS conversion factors
C
      INCLUDE 'GPBHP.INC'
C
C  Oct-20-1993 @ ARC-bsg Subtask 325 expanded BUS conversion factors
C
      DIMENSION HDCD2B(39),HDCDLH(39),HDCDMH(39),HDCDHH(39),
     *HDCBUS(39),HBUST1(39),HBUST2(39),HBUST3(39)
C
C  Oct-20-1993 @ ARC-bsg Subtask 325 expanded BUS conversion factors
      EQUIVALENCE
     *   (HDCFAC(1,1),HDCD2B(1)),
     *   (HDCFAC(1,2),HDCDLH(1)),
     *   (HDCFAC(1,3),HDCDMH(1)),
     *   (HDCFAC(1,4),HDCDHH(1)),
     *   (HDCFAC(1,5),HDCBUS(1)),
     *   (HDCFAC(1,6),HBUST1(1)),
     *   (HDCFAC(1,7),HBUST2(1)),
     *   (HDCFAC(1,8),HBUST3(1))
C
C  Gpbhp to gpm units conversion factors
C
C  For HDDV
C
      DATA HDCD2B/
     *    0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000,
     *    0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000,
     *    0.000, 0.942, 0.923, 0.923, 0.922, 0.921, 0.919, 0.919, 0.919,
     *    0.919, 0.919, 0.919, 0.919, 0.919, 0.919, 0.919, 0.919, 0.919,
     *    0.919, 0.919, 0.919/
C
      DATA HDCDLH/
     *    2.161, 2.161, 2.161, 2.161, 2.161, 2.161, 2.161, 2.161, 2.161,
     *    2.161, 2.161, 2.161, 2.009, 1.879, 1.762, 0.000, 0.000, 0.000,
     *    0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000,
     *    0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000,
     *    0.000, 0.000, 0.000/
C
      DATA HDCDMH/
     *    2.606, 2.603, 2.602, 2.604, 2.601, 2.636, 2.640, 2.670, 2.702,
     *    2.744, 2.784, 2.820, 2.840, 2.923, 2.960, 2.746, 2.544, 2.469,
     *    2.139, 2.394, 2.183, 2.744, 2.403, 2.301, 2.596, 2.019, 2.267,
     *    2.264, 2.259, 2.256, 2.248, 2.253, 2.252, 2.251, 2.253, 2.250,
     *    2.249, 2.249, 2.247/
C
      DATA HDCDHH/
     *    3.074, 3.074, 3.074, 3.074, 3.074, 3.138, 3.138, 3.205, 3.205,
     *    3.275, 3.275, 3.275, 3.326, 3.299, 3.353, 3.402, 3.361, 3.307,
     *    3.332, 3.255, 3.152, 3.150, 3.141, 3.138, 3.129, 3.129, 3.129,
     *    3.129, 3.129, 3.129, 3.129, 3.129, 3.129, 3.129, 3.129, 3.129,
     *    3.129, 3.129, 3.129/
C
      DATA HDCBUS/
     *    2.937, 2.937, 2.938, 2.938, 2.937, 2.939, 3.060, 3.119, 3.153,
     *    3.088, 3.285, 3.082, 2.908, 3.020, 2.881, 2.930, 2.947, 2.932,
     *    2.948, 3.008, 2.967, 3.012, 2.941, 2.791, 2.730, 2.728, 2.711,
     *    2.692, 2.675, 2.667, 2.659, 2.653, 2.643, 2.641, 2.642, 2.634,
     *    2.635, 2.636, 2.640/
C
C  Oct-20-1993 @ ARC-bsg Subtask 325 expanded BUS conversion factors
C
      DATA HBUST1 /39*3.3/
      DATA HBUST2 /39*7.9/
      DATA HBUST3 /39*18.1/
C
      DATA LOWYR,MAXCIG/1962,39/
C
      END
      BLOCK DATA BD33
C
C  BLOCK DATA Subprogram 33: /REGION/,/SCENE1/
C
C  BLOCK DATA 33 defines common blocks related to the first scenario record.
C
C  Common block array subscripts:
C
C  FEET(2)  -  FEET ( IREJN )
C
C  Common block dictionary:
C
C   Name   Type              Description
C  ------  ----  --------------------------------------------------
C  /REGION/:
C
C  IREJN    I    user supplied region code: 1 = low altitude, 2 = high
C                1 = low altitude region
C                2 = high altitude region
C  ALT      R    altitude in feet
C  INITPR   I    switch: 1 = 1st scenario's output pass, print run parameters
C                        0 = 2nd or later, do not 'CALL OUTHD<OUTFMT>'
C
C  /SCENE1/:
C
C  SPD      R    user supplied fleet average vehicle speed
C  ISPDCY   I    user supplied driving cycle type:
C                1=transient, 2=steady cruise
C  USRWT    I    user supplied fleet average vehicle weight
C  UNSILT   R    unpaved roads percent silt loading
C  PVSILT   R    paved roads silt loading (g/m^2)
C  IPDAYS   I    number of days with >0.01" precip. (20 to 200)
C
C  Notes:
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'SCENE.INC'
C
C
C  Only FEET and INITPR need to be initialized.
C
      DATA FEET/500.,5500./,INITPR/1/
C
C  The rest are read in or set during execution, so dummy zeroes are used here.
C
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting
C
      DATA IREJN,ALT,ISPDCY/3*0/
      DATA SPD/0.0/
      DATA UNSILT,PVSILT,IPDAYS/2*0.0,0/
      DATA USRWT/0/
C
      END
      BLOCK DATA BD35
C
C  BLOCK DATA Subprogram 12: /BYMYC1/,/BYMYC2/
C
C  BLOCK DATA 35 defines the By Model Year Table generation common blocks.
C
C  Common block array subscripts:
C
C  BYCUM(MAXYRS,MAXVEH)         -  BYCUM  (     JDX, IV )
C  BYFER(MAXPOL,MAXYRS,MAXVEH)  -  BYFER  ( IP, JDX, IV )
C  IVPICK(MAXVEH+3)             -  IVPICK (          IV )
C
C  Common block dictionary:
C
C   Name   Type               Description
C  ------  ----  --------------------------------------------
C  /BYMYC1/:
C
C  IVPICK   I    By Model Year (BYMY) Table vehicle class case selection vector.
C                For each IV,   1 = skip the Table(s)   2 = print the Table(s)
C  BYCUM    R    BYMY version of CUMMIL: same except zeroed out where the
C                corresponding TF is zero.  BYCUM is used as a "clean"
C                proxy for CUMMIL in the BYMY tables.  CUMMIL could be used
C                directly if it was recomputed every scenario TF was redone,
C                which is not true when the user enters AMAR.
C
C  /BYMYC2/:
C
C  BYFER    R    by model year final emission rate for IDX x IV x IP = COMPEF
C
C
C  Notes:
C                                                               
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'BYMYM.INC'
C
C  /BYMYC1/:
C
      DATA IVPICK/15*1/,BYCUM/300*-0.0001/
C
C  /BYMYC2/:
C
C  The Repeat Counter for BYFER is the result of MAXYRS*MAXPOL*(MAXVEH+3)
C
      DATA BYFER/4125*0.0/
C
      END
