      SUBROUTINE DIESL(MY, IV, ICY, RCP, SOF, DSULF, ISULF, SO2, EF)
C
C     This subroutine calculates the diesel emission factor for
C     vehicle classes:  LDDV, LDDT, 2BHDDV, LHDDV, 
C                       MHDDV, HHDDV, BUSES, HBUST1, HBUST2, HBUST3
C                       i.e. IV = 6,...,15
C  Called by EFCALX.
C
C  Calls  DIESEF and DIESLF
C
C  Input on call:
C    common blocks: /CARBON/ SOFPNT
C
C
C  Output on return: RCP, SOF, DSULF, SSULF, ISULF, EF
C
C     Local Variable Dictionary:
C
C  Variable    Type      Description
C -----------------------------------------------------------------------
C   CFRAT      R         Ratio of Conversion factor from grams/BHP-hr to
C                        grams/mile from regular Bus categories to
C                        extra bus categories
C   DUMMY      R         Dummy parameter to DIESLF subroutine 
C   DINC       R         Difference between low and high sulfur  
C   DINCL      R         Intermediate results are saved for low
C   DINCH      R         Intermediate results are saved for high
C   IDX        I         Model year indicator
C   IUSEFG     I         2=Low or 1=High Sulfur Effects Flag
C
C
C  Notes:
C  May-24-1994 @ Request 417 CSC-bsg Created to consolidate the diesel
C  EF's and to calculate the event of low sulfur diesel fuel.
C  Jun-3-1994 @ CSC-bsg Request 443 added check for DSULF GT EF for trap bus
C  categories, MY=1992, 1993 and TRAP is set.
C  Jun-3-1994 @ CSC-bsg Request 443 calculation of diesel incremental
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the new RESULTA include file
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'FRACT.INC'
      INCLUDE 'TRAP.INC'
      INCLUDE 'RESULTA.INC'
      INCLUDE 'GPBHP.INC'
C
      CALL DIESEF(MY,IV,EF)
C
C  First used 25% sulfur weight ratio
C
      IUSEFG=1
C
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the new RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
      CALL DIESLF(MY,IV,DUMMY,DSULF,ISULF,SO2,IDX,IUSEFG)
C
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file.
C
      IDX=MY-ICY+MAXYRS
      IF(IV.GT.12) THEN
        IG = MY-LOWYR+1
        IF (IG.LT.1) IG=1
        IF (IG.GT.MAXCIG) IG=MAXCIG
        IVCF = IV - 7
        CFRAT = HDCFAC(IG,IVCF)/HDCFAC(IG,5)
        DSULF=BUSLF(IDX,IUSEFG)*CFRAT
      ENDIF
C
C  Jun-3-1994 @ CSC-bsg Request 443 calculation of diesel incremental
C
      IF((IV.GE.12.AND.MY.GE.1992).OR.(MY.GE.1994)) THEN
        IUSEFG=2
C
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
        CALL DIESLF(MY,IV,DUMMY,DINCL,ISULF,SO2,IDX,IUSEFG)
C
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C
        IF(IV.GT.12) DINCL=BUSLF(IDX,IUSEFG)*CFRAT
        DINCH=DSULF
        DINC=DINCH-DINCL
        EF=EF+DINC
      ENDIF
      SOF = 0.0
      RCP = 0.0
C
      IF(IV.LE.12) THEN
        SOF = SOFPNT(IV)*(EF-DSULF)
      ELSE
        SOF = SOFPNT(12)*(EF-DSULF)
      ENDIF
      RCP = EF-DSULF-SOF
CC    IVV=IV
CC    IF(IV.GT.12) IVV=12
CC    IF(MY.EQ.1995) WRITE(15,201) DSULF,EF,SOFPNT(IVV),IV,MY
CC201 FORMAT(' DSULF EF SOFPNT IV MY',3(F9.6,1X),I2,1X,I4/)
C
C  Second recalculate with lower 5% sulfur weight ratio
C  for calendar years 1993+ applied to all model years
C
      IF(ICY.GE.1993) THEN
        IUSEFG=2
C
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
        CALL DIESLF(MY,IV,DUMMY,DSULF,ISULF,SO2,IDX,IUSEFG)
C
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C
        IF(IV.GT.12) DSULF=BUSLF(IDX,IUSEFG)*CFRAT
      ENDIF
      EF = RCP + DSULF + SOF
      RETURN
C
      END
      SUBROUTINE DIESEF(MY, IV, EF)
C
C     This subroutine calculates the diesel emission factor for
C     vehicle classes:  LDDV, LDDT, 2BHDDV, LHDDV, 
C                       MHDDV, HHDDV, BUSES, HBUST1, HBUST2, HBUST3
C                       i.e. IV = 6,...,15
C  Called by EFCALX.
C
C  Calls  none
C
C  Input on call:
C
C    common blocks: /PSIZE/, /DIESEL/, /HDCCOM/
C
C  Output on return: EF
C
C     Local Variable Dictionary:
C
C  Variable    Type      Description
C -----------------------------------------------------------------------
C   CF         R         Conversion factor from grams/BHP-hr to grams/mile
C   EFBUS      R         (IYEAR=1/2)
C                        Where IYEAR=1 => MY=1992
C                        Where IYEAR=2 => MY=1993
C
C
C  Notes:
C  Oct-20-1993 @ ARC-bsg Subtask 325
C  Jun-7-1994 @ CSC-bsg Request 443 check trap flag and use alternative
C  emission values and weight them together with user supplied trap pct.
C  Jun-22-1994 @ CSC-bsg Request 429 Changed block data LDDV/T emission values
C  increased array size of IDIEYR and EFDPM to include new LDDV/T standards.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'FRACT.INC'
      INCLUDE 'GPBHP.INC'
      INCLUDE 'PSIZE.INC'
      INCLUDE 'TRAP.INC'
C
C  Jun-6-1994 @ CSC-bsg Request 443 check trap flag and use alternative
C  emission values and weight them together with user supplied trap pct.
C  only use block data when not a bus
C
      DIMENSION EFBUS(2)
      EFBUS(1)=.0257
      EFBUS(2)=.0240
C
      EF = 0.0
      IF (IV .LT. 6) RETURN
C
      IVEF=IV - 5
      IVCF = IV - 7
C
C  Jun-22-1994 @ CSC-bsg Request 429 Changed block data LDDV/T emission values
C  increased array size of IDIEYR and EFDPM to include new LDDV/T standards.
C
      DO 10 I = 1, 9
        IF (MY .GE. IDIEYR(I,IVEF)) EF = EFDPM(I,IVEF)
   10 CONTINUE 
C
C  Jun-7-1994 @ CSC-bsg Request 443 check trap flag and use alternative
C  emission values and weight them together with user supplied trap pct.
C  only use block data when not a bus
C
      IF(IV.GE.12.AND.TRAPFG.EQ.2.AND.(MY.EQ.1992.OR.MY.EQ.1993)) THEN
        IF(MY.EQ.1992) THEN
          EF=(TRAPCT(1)/100.)*EFBUS(1)+(1-TRAPCT(1)/100.)*EF
        ELSE
          EF=(TRAPCT(2)/100.)*EFBUS(2)+(1-TRAPCT(2)/100.)*EF
        ENDIF
      ENDIF
C
C     Compute the emission factor for LDDV and LDDT:
C
CC    IVV=IV
CC    IF(IV.GT.12) IVV=12
CC    IF(MY.EQ.1995) WRITE(15,201) EF,PSDIE,IV,MY
CC201 FORMAT('  INSIDE EF SUB-> EF PSDIE IV MY',2(F9.6,1X),I2,1X,I4)
      IF (IV.LT.8) THEN
         EF = EF * PSDIE
         RETURN
      ENDIF
C
C     Compute the emission factor for 2BHDDV, LHDDV, MHDDV, HHDDV,
C     BUSES, HBUST1, HBUST2, HBUST3 (i.e. IV = 8...15):
C
C     Note:  the emission factor EFDPM is in grams/BHP-Hr for
C            the heavy duty vehicles, so they must be converted
C            to grams/mile.
C
      IF (IV.GE.8) THEN
         IG = MY-LOWYR+1
         IF (IG.LT.1) IG=1
         IF (IG.GT.MAXCIG) IG=MAXCIG
         CF = HDCFAC(IG,IVCF)
         EF = EF * PSDIE * CF
         RETURN 
      ENDIF
C
      END 
      SUBROUTINE DIESLF(MY,IV,SSULF,DSULF,ISULF,SO2,IDX,IUSEFG)
C
C  Input on call:
C    parameter list: MY, IV, IDX, IUSEFG
C    common blocks:
C
C  Output on return: DSULF,ISULF,SO2
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------------
C  MY       I    Model year 
C  MDX      I    Model year index mapping to Model year(MY) for DIESFE
C  LCNVRT   R    Local version of DCNVRT for LDDV, and LDDT
C
C
C  Notes: 
C  Oct-13-1993 @ ARC-bsg Subtask 325 change code to remove warning
C  Dec-3-1993 @ ARC-bsg  Subtask 362 install correct grams to pound
C  conversion
C  Mar-9-1994 @ CSC-bsg Request 401  Add user input variables for
C  sulfur weight percent for gasoline and diesel fuel or default values
C  Mar-10-1994 @ CSC-bsg Request 401  changed application of diesel sulfur 
C  sulfur weight percent ratio to be like gasoline 
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG         
C  Changed Diesel percent to depend on calendar year
C  Apr-6-1994 @ CSC-bsg Request 417 removed diesel percent depending on
C  calendar year
C  May-25-1994 @ CSC-bsg Request 434 Regression and integration testing
C  zero out DSULF for 2BHDDV for model years less than 1981 and LHDDV
C  for model years greater than 1976.
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'LEAD.INC'
      INCLUDE 'FRACT.INC'
      INCLUDE 'PSIZE.INC'
      INCLUDE 'RESULTA.INC'
C
      REAL ISULF,LCNVRT
C
      IF (IV.LT.6) THEN
         DSULF = 0.
         ISULF = 0.
         SO2   = 0.
         GOTO 99
      ENDIF        
C
      FDNSTY = DDENS
      IVV = IV - 5
C
C  For each Vehicle Type select the corresponding MDX to MY for DIESFE
C
      DO 10 IYR=1,32
         IF (MY.LE.IYRFE(IYR)) THEN
            MDX=IYR
            GO TO 11
         ENDIF
10    CONTINUE
11    CONTINUE
      FECONM = DIESFE(MDX,IVV)
C
C     Compute the grams/mile emission factor of the direct sulfate material:
C 
C     13.6078 = (453.592 * 3.)/100.
C     where: 453.592 = number of grams in a pound
C                  3 = weight ratio of SO4 to sulfur
C     and the division by 100 is to correct for DSWGTR the diesel weight ratio
C     of sulfur content in fuel.
C
C     WATER  = weight ratio of seven water molecules to sulfate 
C              (see p. 6-25 of "Regulatory Impact Analysis,
C              Control of Sulfur and Aromatics Contents of On-
C              Highway Diesel Fuel")
C     FDNSTY = fuel density in lbs/gallon
C     FECONM = fuel economy
C     DSWGTR = Diesel weight ratio of sulfur content in fuel
C     DCNVRT  = percent of sulfur exhausted that is directly converted
C               into sulfuric acid.
C
C
C  May-24-1994 @ CSC-bsg Request 417 Changed DCNVRT to "0.015" for 
C  light duty diesel vehicles and trucks.  This will reflect the 
C  Regulatory Impact Analysis which states that 1.5% sulfur in fuel
C  is converted to sulfate for these types of vehicles
C      
      IF(IVV.LE.2) THEN
        LCNVRT=0.015
      ELSE
        LCNVRT=DCNVRT
      ENDIF
      DSULF = 13.6078*(1.+ WATER)*FDNSTY*DSWGTR(IUSEFG)*LCNVRT/FECONM
C
C  Jul-28-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
      IF(IV.EQ.12) BUSLF(IDX,IUSEFG)=DSULF
C
C  May-25-1994 @ CSC-bsg Request 434 Regression and integration testing
C  zero out DSULF for 2BHDDV for model years less than 1981 and LHDDV
C  for model years greater than 1976.
C
      IF(IV.EQ.8.AND.MY.LT.1981) DSULF=0.0
      IF(IV.EQ.9.AND.MY.GT.1976) DSULF=0.0
C
C     SSULF = expected direct sulfate emissions at 0.25 weight % sulfur 
C             content.
C  Mar-10-1994 @ CSC-bsg Request 401  changed application of diesel sulfur 
C  sulfur weight percent ratio to be like gasoline 
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG
C
      SSULF = DSULF
C
C
C     Compute the exhausted SO2:
C
C     9.072 = (453.592 * 2.)/100.
C     where: 453.592 = number of grams in a pound
C                 2. = weight ratio of SO2 to sulfur
C     and the division by 100 is to correct for the user supplied or default 
C     weight percent of sulfur, DSWGTU.
C
      SO2 = 9.072*FDNSTY*DSWGTR(IUSEFG)*(1.-LCNVRT)/FECONM
C
C            3./2. = weight ratio of SO2 to SO4
C           AMNWGT = the extimated weight ratio of the combination of
C                    ammonium bisulfate and ammonium sulfate in the
C                    atmosphere to SO4 (see p 6-25).
C
C
C     Comput the estimated sulfate material that is formed in the 
C     in the atmosphere due to the SO2 emissions:
C
      ISULF = ICNVRT * SO2 * (3./2.) * AMNWGT
C
 99   RETURN
      END
