      FUNCTION FRACTS(MY,ICY,IV,INUM)
C
C  FRACTS calculates fractions for use in any number of functions
C
C  Called by CEFPM, CXEFGF.
C
C  Calls LEADED, LEDPTR, and TAMPER. 
C
C  Input on call:
C
C    parameter list: MY, ICY, IV, INUM
C    INUM = 1 leaded
C           2 unleaded catalyst
C           3 unleaded no catalyst
C           4 unleaded catalyst no air
C           5 unleaded catalyst air 
C
C
C    common blocks:
C
C  Output on return: FRACTS
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------------
C  IYPT     I    Discretionary fuel switching index variable 
C  IFRAC    I    model year pointer to obtain CTLFRC from common array FRACA
C  VLNOCT   R    Number of non-catalyst vehicles
C                using leaded fuel
C  VUNOCT   R    Number of non-catalyst vehicles
C                using unleaded fuel
C  VLYSCT   R    Number of catalyst equipped
C                vehicles using leaded fuel
C  VUYSCT   R    Number of catalyst equipped
C                vehicles using unleaded fuel
C
C
C  Notes: 
C  Mar-4-1994 @ CSC-bsg Request 340 this was added to overhaul
C  lead emission factor calculation
C  May-12-1994 @ CSC-bsg Request 430 this was added to help 
C  calculate various fractions in the model
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'DFSBLK.INC'
      INCLUDE 'LEAD.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'PSIZE.INC'
      INCLUDE 'FRACT.INC'
C
      FRACTS = 0.0
C
C  skip Diesels.
C
      IF(IV.GT.5) RETURN
C
      IF (MY.LT.1968) THEN
          IFRAC = 1
      ELSE IF (MY.GE.1968.AND.MY.LE.1971) THEN
          IFRAC = 2
      ELSE IF (MY.LE.1991) THEN
          IFRAC = 3 + (MY - 1972)
      ELSE 
          IFRAC = 22
      ENDIF
C
C  Get the catalyst fraction of the gasoline vehicle population.
C
      CATFCT = FRACA(IFRAC,1,IV)+FRACA(IFRAC,2,IV)+
     2         FRACA(IFRAC,3,IV)+FRACA(IFRAC,4,IV)
C
C  determine discretionary fuel switching index variable.
C
      CALL LEDPTR(IYPT,IV,MY)
C
C  determine the tampering and misfueling rates.
C
      CALL TAMPER(ICY,MY,IV,TAMFRC,RMIS)
C
C  determine the fraction of all vehicles which 
C  have NOT had the catalyst removed.
C
      CATS = CATFCT * (1.-TAMFRC)
C
C  determine the fraction of all vehicles which are 
C  non-catalyst vehicles fueled with leaded gasoline.
C
      VLNOCT = (1.-CATS) * (1.-DFS(IYPT,IV))
C
C  determine the fraction of all vehicles which are 
C  non-catalyst vehicles fueled with unleaded gasoline.
C
      VUNOCT = (1.-CATS) * DFS(IYPT,IV)
C
C  determine the fraction of all vehicles which are 
C  catalyst equipped vehicles fueled with leaded gasoline.
C
      VLYSCT = CATFCT * (RMIS - TAMFRC)
C
C  determine the fraction of all vehicles which are 
C  catalyst equipped vehicles fueled with unleaded gasoline.
C
      VUYSCT = (1.-VLNOCT-VUNOCT-VLYSCT)
C
C  Set fraction depending on INUM requested
C
C  inum = 1: add leaded cat to leaded no cat
C
      IF(INUM.EQ.1) THEN
        FRACTS=VLNOCT+VLYSCT
C
C  inum = 2: use unleaded catalyst fraction
C
      ELSEIF(INUM.EQ.2) THEN
        FRACTS=VUYSCT
C
C  inum = 3: use unleaded no catalyst fraction
C
      ELSEIF(INUM.EQ.3) THEN
        FRACTS=VUNOCT
C
C  inum = 4: use block data catalyst fractions, then sum ox no air and
C  3-way no air
C
      ELSEIF(INUM.EQ.4) THEN
        FRACTS=FRACA(IFRAC,1,IV)+FRACA(IFRAC,3,IV)
C
C  inum = 5: use block data catalyst fractions, then sum ox air and
C  3-way air
C
      ELSEIF(INUM.EQ.5) THEN
        FRACTS=FRACA(IFRAC,2,IV)+FRACA(IFRAC,4,IV)
      ENDIF
      RETURN
      END
      SUBROUTINE CXEFGF(IV,MY,ICY,CXNOLD,CXYSLD)
C  Calculates carbon emissions for gasoline vehicles
C
C  Called by: CEFPM
C
C  Calls: FRACTS
C
C  Output on Return: leaded and unleaded carbon emissions for gasoline
C  vehicles
C                    
C  Common Blocks: 
C  /EFPMC/ GSCRBN,MYPTRC
C  /PSIZE/  PSL, PSNL, PSNLCT
C  /SULFR/ EXPECV
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -----------------------------------------------
C  CXICAT   R    Emission value of GSCRBN for a given ICAT
C  FCATFR   R    Fraction catalyst type for ICAT 1/2/3/4 depends
C                on IV
C  ICAT     I    1=LEADED, for 2-4 UNLEADED, 2=NO AIR CAT,
C                3=CAT AIR, 4=NCAT
C  IFRAC         model year pointer to obtain CTLFRC from common
C                array FRACA
C  IMYPTR   I    value of MYPTRC array pointer which points
C                into the GSCRBN data array.
C  
C  Notes:
C  May-12-1994 @ CSC-bsg Request 430 created for revisions of emission
C  factor for gasoline vehicles.
C  May-24-1994 @ CSC-bsg Request 434 integration and regression testing
C  Jun-17-1994 @ CSC-bsg Request 430 MC use lead instead of gas carbon
C  Jun-24-1994 @ CSC-bsg Request 430 MC use lead and gas carbonn
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'EFGAS.INC'
      INCLUDE 'PSIZE.INC'
      INCLUDE 'FRACT.INC'
C
      REAL CXICAT(4),FCATFR(4)
      INTEGER IMYPTR(4)
C
C  Jun-24-1994 @ CSC-bsg Request 430 changed MC calculation
C
      CXNOLD=0.0
      IF(IV.EQ.5.AND.MY.LE.1978) THEN
        CXYSLD=(0.49*0.230+0.51*0.032)*PSL
        RETURN
      ELSEIF(IV.EQ.5.AND.MY.GT.1978) THEN
        CXYSLD=0.032*PSL
        RETURN
      ENDIF
C
      FCATFR(1)=1.0
C
C  Assign fraction using unleaded cat no air result of FCTNS
C
      FCATFR(2)=FRACTS(MY,ICY,IV,4)
      FCATFR(3)=FRACTS(MY,ICY,IV,5)
      FCATFR(4)=FRACTS(MY,ICY,IV,3)
C
      DO 30 ICAT=1,4
C
C  Initialize pointer to first EF GSCRBN element of array 
C
        IMYPTR(ICAT) = 1
C
C  Once pointer has been found then break out of loop
C
  10    IF(MY.LE.MYPTRC(IMYPTR(ICAT),ICAT,IV)) THEN
          GOTO 20
        ELSE
          IMYPTR(ICAT)=IMYPTR(ICAT)+1
          GOTO 10
        ENDIF
  20    CONTINUE
C
C  Assign Carbon array to element of MYPTRC array model year pointer
C
        CXICAT(ICAT)=GSCRBN(IMYPTR(ICAT),ICAT,IV)
  30  CONTINUE
      CXYSLD=CXICAT(1)*FCATFR(1)*PSL
      CXNOLD=(CXICAT(2)*FCATFR(2)+CXICAT(3)*FCATFR(3))*
     *        FRACTS(MY,ICY,IV,2)*PSNLCT*EXPECV+
     *        CXICAT(4)*FCATFR(4)*PSL
      RETURN
      END
      FUNCTION CEFPM(IV,MY,ICY,CLEAD,CDSULF)
C  Calculates EFPM for gasoline vehicles, by adding lead and sulfate to
C  the weighted emission factor for carbon in leaded and unleaded fuel
C  uses.
C
C  Called by: EFCALX
C
C  Calls: FRACTS, CXEFGF
C
C  Output on Return: total PM emission factor
C                    
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  ------------------------------------------------
C  CXNOLD    R    Carbon emission factor for not leaded fuel use
C  CXYSLD    R    Carbon emission factor for leaded fuel use
C
C
C  Notes:
C  May-10-1994 @ CSC-bsg Request 430 this was created to overhaul
C  total exhaust particulate emission factors
C  Mar-24-1994 @ CSC-bsg Request 415 this was created to overhaul
C  total exhaust particulate emission factors
C  Jun-17-1994 @ CSC-bsg Request 430 MC use lead instead of gas carbon
C  Jun-24-1994 @ CSC-bsg Request 430 MC use lead and carbon
C
C
      CALL CXEFGF(IV,MY,ICY,CXNOLD,CXYSLD)
      IF(IV.EQ.5) THEN
        CEFPM = CLEAD + CXNOLD + CXYSLD 
      ELSE
        CEFPM = CXYSLD*FRACTS(MY,ICY,IV,1) + CXNOLD + CLEAD + CDSULF
CC      IF(IV.EQ.4.AND.ICY.EQ.2010) WRITE(16,201) 
CC   *  CXYSLD,FRACTS(MY,ICY,IV,1),
CC   *  CXYSLD*FRACTS(MY,ICY,IV,1),CXNOLD,CLEAD,CDSULF,
CC   *  CXYSLD*FRACTS(MY,ICY,IV,1) + CXNOLD + CLEAD + CDSULF,MY,ICY,IV
CC201 FORMAT(' CXYSLD FRACTS CXYSLD*FRACTS CXNOLD CLEAD CDSULF CEFPM'/
CC   *7F9.6/' MY ICY IV'/3I5//)
      ENDIF
      RETURN
      END
      SUBROUTINE EFCALX(ICY) 
C
C  EFCALX calculates composite emission factors.
C
C  Called by MAIN.
C
C  Calls DIESL, FDCALX, GASSLF, GETCUM, IPBFUN, IGSFPT, 
C        OUTPOL, UNLDED, TAMPER
C
C  Input on call:
C
C    parameter list: ICY
C    common blocks:
C     /BASEFD/ IVEHWL(MAXVEH),CUNPVD,CPAVED
C     /BYMYC1/ BYCUM(MAXYRS,MAXVEH)
C     /BYMYC2/ BYFER(MAXPOL,MAXYRS,MAXVEH)
C     /CARBON/ SOFPNT(MAXVEH)
C     /CUMCOM/ CUMMIL(MAXYRS,MAXVEH)
C     /GSFCOM/ GSFRAC(22,MAXVEH,2)
C     /IOUCOM/ IOUERR
C     /MAXIMA/ MAXVEH,MAXYRS
C     /MYRCAL/ TF(MAXYRS,MAXVEH)
C     /MYRSAV/ NEWCUM
C     /PSIZE/  PSBRK, PSTIRE
C     /REGION/ IREJN
C     /RESUL1/ EF(MAXPOL,MAXVEH+3)
C     /RESUL3/ VEF(MAXPOL)
C     /VMXCOM/ VMTMIX(MAXVEH)
C
C  Output on return:
C
C    common blocks:
C     /BYMYC2/ BYFER
C     /RESUL1/ EF
C     /RESUL3/ VEF
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  CLEAD    R    Lead emission factor for a given IDX, IV
C  CSOF     R    SOF emission factor for a given IDX, IV
C  CRCP     R    RCP emission factor for a given IDX, IV
C  CDSULF   R    Direct Sulfate emission factor (sulfuric acid) for a 
C                       given IDX, IV
C  SSULF    R    Direct sulfate emission factor from diesel fueled vehicles
C                assuming .25 weight percent sulfur content in diesel fuel.
C  CISULF   R    Indirect Sulfate emission factor for a given IDX, IV
C  CTSULF   R    Total Sulfate emission factor for a given IDX, IV
C  CSO2     R    Exhaust SO2 emission factor for a given IDX, IV
C  CBRAKE   R    Brake emission factor for a given IDX, IV
C  CTIRE    R    Tire emission factor for a given IDX, IV
C  CPM10    R    Total PM emission factor (Lead + Total Sulfate + SOF + 
C                      RCP + Tire + Brake) for a given IDX, IV
C  CUNPVD   R    Unpaved road dust emission factor for a given IDX, IV
C  CPAVED   R    Paved road dust emission factor for a given IDX, IV
C  ISPDCY   I    Driving cycle used in Speed correction factors:
C                  1=cycle driving,   2=steady driving
C  FEC      R    Fuel economy correction factor for lead emissions.
C  DUMMY    R    Dummy parameter for variables not used in return functions
C
C
C  Notes:
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations added ICY
C  parameter to GASSLF because RMIS is calculated from a call to 
C  NLCONS which requires ICY.  RMIS is used in the new equations.
C  Feb-2-1994 @ CSC-bsg Subtask 385 Incorrect Fuel Economy Application
C  for Direct Sulfate, Indirect Sulfate, Exhaust SO2, and Exhaust PM10
C  Feb-18-1994 @ CSC-bsg Request 390 use same cat frac for pm as sulfate
C  Mar-4-1994 @ CSC-bsg Request 340 replaced original call to lead with
C  EFLEAD function that overhauls all lead formulas.
C  Mar-4-1994 @ CSC-bsg request 377 fix bus categories 
C  Mar-18-1994 @ CSC-bsg Request 406 Simplified terms in equation to
C  avoid confusion (CDSULF=DSULF=SSULF).  Applied maximum function to
C  ensure that CSOF and CRCP are non-negative numbers and added the 
C  application of the amax function to cpm10 to ensure the breakdown
C  of all pollutants sum to the total exhaust PM 
C  Mar-18-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG         
C  Apr-6-1994 @ CSC-bsg Request 417 removed diesel percent depending on
C  calendar year and added call to DIESL for calculation of diesel EF's
C  Apr-8-1994 @ CSC-bsg  Request 419 removed the subroutine NLCONS and
C  replaced it with TAMPER to calculate TAMFRC and RMIS
C  May-24-1994 @ CSC-bsg Request 434 integration and regression testing
C  Jul-27-1994 @ CSC-bsg Request 434 Discovered total Sulfate PM should be
C  the sum of indirect and direct sulfate
C  Oct-28-1994 @ CSC-ked Request 474 PATH5 Fugitive Dust Reformatting
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'FRACT.INC'
      INCLUDE 'BASEFD.INC'
      INCLUDE 'IDLE.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'GSFCOM.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'BYMYM.INC'
      INCLUDE 'PSIZE.INC'
C
      REAL DSULF,ISULF
C
C Request 422 Debug exhaust particulates
C
      DATA EMIN/1.E-10/
C
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG         
C  Phase I RFG will apply to 1995 - 1999 calendar years
C
      EXPECV = 1.0
      IF(RFGFLG.NE.1) THEN
        IF(ICY.GE.1995.AND.ICY.LE.1999) THEN
          EXPECV = 1.0 - 0.1305
C
C  Phase II RFG will apply to 2000+ calendar years
C
        ELSEIF(ICY.GE.2000) THEN
          EXPECV = 1.0 - 0.2024
          GSWGTR = 0.0138
        ENDIF
      ENDIF
C
      IF(NEWCUM.NE.0) CALL GETCUM
      NEWCUM=0
C
C     CUMMIL, a parameter array, is recast here for the BYMY tables as 
C     BYCUM, with zero replacing the potential CUMMIL, when TF=0.0.
C     Initialize IDLE emissions.
C
      EMSIDL(MAXVP1) = 0.
      DO 10 IV=1,MAXVEH
         EMSIDL(IV) = 0.
         DO 10 IDX=1,MAXYRS 
            JDX=(MAXYRS+1)-IDX
            IF(TF(JDX,IV).EQ.0.0) BYCUM(IDX,IV)=0.0
            IF(TF(JDX,IV).GT.0.0) BYCUM(IDX,IV)=CUMMIL(IDX,IV)
   10 CONTINUE
C
      CALL OUTPOL(IP1,IP2)
C
C     Loop over the pollutants:
      DO 25 IP=IP1,IP2
         VEF(IP) = 0.0
         DO 21 IV=1,MAXVEH+3
            EF(IP,IV) = EMIN
            DO 20 JDX=1,MAXYRS
               BYFER(IP,JDX,IV) = 0.0
   20       CONTINUE
   21    CONTINUE
   25 CONTINUE
C            
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting.
C  Take call to FDCALX out of the vehicle class loop and remove IVV as a
C  parameter.
C
C  Calculate the FUGITIVE DUST factors
C
      CUNPVD  = 0.
      CPAVED  = 0.
      CALL FDCALX(CUNPVD,CPAVED)
C
C     Loop over the vehicle classes:
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories
C
      DO 60 IV=1,MAXVEH+3
         IVV=IV
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories VMTMIX is the same as BUS
C
         IF(IV.GT.12) IVV=12
         IF(VMTMIX(IVV).EQ.0.0) GOTO 60
C
C   Calculate the fuel economy correction factor:
C
         IF (IV.LT.4 .OR. IV.EQ.6 .OR. IV.EQ.7) THEN
            FEC = 1./SCF(ISPDCY)
         ELSE
            FEC = 1.
         ENDIF
C
C  Zero out BYMY save areas before VMTMIX check.  Since VMTMIX 
C  can be altered by scenario, a VMTMIX(i) > 0.0 case followed 
C  by a VMTMIX(i) = 0.0 case would lead to the latter scenario 
C  using the former scenario's BYMY data for IV=i.
C
CC       IF(IV.EQ.6) IDOIT=0
C
C  Loop over the years:
         DO 50 IDX=1,MAXYRS
C
C  Initialize emissions to 0
C
            CLEAD   = 0.
            CSOF    = 0.
            CRCP    = 0.
            CDSULF  = 0.
            CISULF  = 0.
            CTSULF  = 0.
            CSO2    = 0.
            CBRAKE  = 0.
            CTIRE   = 0.
            CPM10   = 0.
            CIDLE   = 0.
C
            JDX=(MAXYRS+1)-IDX
            MY=ICY+IDX-MAXYRS
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories IGSFPT and TF are the same as BUS
C    
            IGS=IGSFPT(MY,IVV)
C
C  If no mileage for this model year / vehicle class case, 
C  skip ef calculation.
C
            IF(TF(IDX,IVV).LE.0.0) GOTO 50
C
C  Calculate IDLE emission factors:
C
           IF (IDLFLG.GT.1) CALL GETIDL(CIDLE,MY,IVV,ICY)
C
C  Calculate the LEAD emission factors:
C  (for vehicle classes greater than 5 (MC's), the emission
C  factor is 0.)
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories COML and COMNL are the same as BUS
C
C  Mar-3-1994 @ CSC-bsg Request 340 Complete overhaul of lead 
C  emission factor calculations and formulas
C
            CLEAD = FEC*EFLEAD(MY,ICY,IVV)
CC          IF(IV.LE.5.AND.MY.EQ.1990) WRITE(12,201) CLEAD
CC201 FORMAT(' FINAL LEAD IS:',F10.8)
CC            COML = LEADED(MY,JDX,ICY,IVV)
CC            COMNL = UNLDED(MY,JDX,ICY,IVV)
CC          CLEAD = FEC*(COML + COMNL)*TF(IDX,IV)
CC            CLEAD = FEC*(COML + COMNL)
CC          IF(IV.EQ.1) WRITE(10,101) COML,COMNL,FEC,TF(IDX,IV)
CC   *      ,CLEAD,MY,JDX,IDX
CC101 FORMAT(2F6.4,F8.4,F6.4,F12.8,4I5)
C                  
C   Calculate the SULFATE emission factors:
C  Consolidated the sulfur and exhaust diesel EF's into one routine
CC            IF (IV.GT.5) CALL DIESLF(MY,IV,SSULF,DSULF,ISULF,SO2)
C
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations added ICY
C  parameter to GASSLF because RMIS is calculated from a call to 
C  NLCONS which requires ICY.  RMIS is used in the new equations.
C
            IF (IV.LE.5) CALL GASSLF(ICY,MY,IV,DSULF,ISULF,SO2)
CC          CDSULF=FEC*DSULF*TF(IDX,IV)
C
C  Feb-2-1994 @ CSC-bsg Subtask 385 Incorrect Fuel Economy Application
C  for Direct Sulfate, Indirect Sulfate, Exhaust SO2, and Exhaust PM10
C
            CDSULF=DSULF
CC          IF(IDOIT.EQ.0) THEN
CC              WRITE(10,103) 
CC103 FORMAT(
CC   * 'The numbers behind the Direct Sulfate numbers ( SO4 ) for ',
CC   * 'LDGV CY 1995 by model year'/'Created July 1, 1993 using PART5a '
CC   * 'Aug-18-1993, The CDSULF=FEC*TF*DSULF'//
CC   * '     DSULF',' FEC ','  MY ','IDX','  TF  ',
CC   * 'CDSULF LONG','CDSULF SHORT','CDSULF/TF LONG',
CC   * 'CDSULF/TF SHORT')
CC               IDOIT=1
CC          ENDIF
CC     IF(IV.EQ.1) 
CC   *     WRITE(10,102) DSULF,FEC,MY,IDX,TF(IDX,IV),
CC   *     CDSULF,CDSULF,CDSULF/TF(IDX,IV),CDSULF/TF(IDX,IV)
CC102 FORMAT(F10.8,F6.3,I5,I3,F6.4,3X,F10.8,6X,F6.4,6X,F10.8,F14.4)
CC     IF(IDOIT.EQ.0) THEN
CC     WRITE(10,104) 
CC104 FORMAT(
CC   * 'The numbers behind the Direct Sulfate numbers ( SO4 ) for ',
CC   * 'LDDV CY 1995 by model year'/'Created July 1, 1993 using PART5a '
CC   * 'Aug-18-1993, The CDSULF=FEC*TF*DSULF'//
CC   * '     DSULF','  FEC ','   MY ',' IDX','  TF  ',
CC   * 'CDSULF LONG  ','CDSULF SHORT  ','CDSULF/TF LONG  ',
CC   * 'CDSULF/TF SHORT')
CC               IDOIT=1
CC     ENDIF
CC     IF(IV.EQ.6)
CC   *     WRITE(10,102) DSULF,FEC,MY,IDX,TF(IDX,IV),
CC   *     CDSULF,CDSULF,CDSULF/TF(IDX,IV),CDSULF/TF(IDX,IV)
CC          CISULF=FEC*ISULF*TF(IDX,IV)
C
C  Feb-2-1994 @ CSC-bsg Subtask 385 Incorrect Fuel Economy Application
C  for Direct Sulfate, Indirect Sulfate, Exhaust SO2, and Exhaust PM10
C
            CISULF=ISULF
            CTSULF = CDSULF + CISULF
CC          CSO2 = FEC*SO2*TF(IDX,IV)
C
C  Feb-2-1994 @ CSC-bsg Subtask 385 Incorrect Fuel Economy Application
C  for Direct Sulfate, Indirect Sulfate, Exhaust SO2, and Exhaust PM10
C
            CSO2 = SO2
C
C  Calculate the soluble organic emission factor (SOF), remaining 
C  carbon portion (RCP), and total PM10 emission factor for 
C  gasoline vehicles:
C
            IF (IV.LE.5) THEN
CC              IF (MY.LT.1968) THEN
CC                IFRAC = 1
CC              ELSE IF (MY.GE.1968.AND.MY.LE.1971) THEN
CC                IFRAC = 2
CC              ELSE IF (MY.LE.1991) THEN
CC                IFRAC = 3 + (MY - 1972)
CC              ELSE 
CC                IFRAC = 22
CC              ENDIF
C
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations Get the
C  misfueling rates:
C
CC            CALL TAMPER(ICY, MY, IV, TAMFRC, RMIS)
C
C  Feb-10-1994 @ CSC-bsg Request 390 Modified calculation of CATFRC to 
C  include RMIS and remove RMIS from sulfate calculation.
C  Get the catalyst fraction of the gasoline vehicle population.
C
CC              CTLFRC = (FRACA(IFRAC,1,IV)+FRACA(IFRAC,2,IV)+
CC     2                  FRACA(IFRAC,3,IV)+FRACA(IFRAC,4,IV))
              CPM10=CEFPM(IV,MY,ICY,CLEAD,CDSULF)
C
C  Feb-18-1994 @ CSC-bsg Request 390 Modified calculation of FRCLED
C  to be 1-CTLFRC and installed a dummy parameter in call to GASPM
C
C  Mar-18-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Mar-21-1994 @ CSC-bsg  Request 411 Checking Exhaust PM for greater than
C  sum of LEAD and Direct Sulfate
CC            IF(CPM10.LT.(CLEAD+CDSULF-.01)) 
CC   *WRITE(13,213) IV,MY,ICY,CPM10,CLEAD,CDSULF,SPD(1)
CC213 FORMAT(' IV    MY    ICY   CPM10   CLEAD   CDSULF   SPEED'/
CC   *I2,T7,I4,T13,I4,4F8.3)   
CC            CPM10=AMAX1(CPM10,(CLEAD+CDSULF))
C
CC               CARBC = CTLFRC*AMAX1((PMCAT - CLEAD - CDSULF),0.)
CC               CARBNC = (1-CTLFRC)*AMAX1((PMNOC - CLEAD - CDSULF),0.)
CC               ORGCAT = GASORG(IV, 2, CARBC)
CC               ORGNOC = GASORG(IV, 1, CARBNC)
CC               CSOF = ORGCAT + ORGNOC
CC               CRCP = CARBC + CARBNC - CSOF
CC               CRCP = AMAX1((CPM10 - CLEAD - CDSULF - CSOF),0.) 
CC               CPM10 = AMAX1(CPM10,(CLEAD+CDSULF+CSOF+CRCP))
CC    IF(MY.EQ.1990) THEN
CC    WRITE(11,211) IV,MY,CLEAD,CDSULF,CSOF,CRCP,CPM10
CC211      FORMAT(' >>>> For vehicle type:',I4,' in MY:',I5/
CC   *' The calculated value of <<<<<< lead is:',F8.3/
CC   *' The calculated value of <<<< sulfur is:',F8.3/
CC   *' The calculated value of <<<<<<< sof is:',F8.3/
CC   *' The calculated value of <<<<<<< rcp is:',F8.3/
CC   *' The calculated value of <<<<<<<< pm is:',F8.3/)
CC    ENDIF
            ENDIF
C
C  Calculate the total PM10 emission factor, soluable organic
C  fraction (SOF), and the remaining carbon portion (RCP) for 
C  diesel fueled vehicles:
C
            IF (IV.GT.5) THEN
CC            CALL DIESEF(MY, IV, DIELEF)
C
C   Correct the total emission factor (which assumes
C   25 weight % sulfur in the fuel by the difference
C   in the actual amount of sulfur (DSULF) by the amount
C   of sulfur at 25 weight % (SSULF):
C
CC            CPM10=FEC*(DIELEF + DSULF - SSULF)*TF(IDX,IV)
C
C  Feb-2-1994 @ CSC-bsg Subtask 385 Incorrect Fuel Economy Application
C  for Direct Sulfate, Indirect Sulfate, Exhaust SO2, and Exhaust PM10
C
CC            CPM10=(DIELEF + DSULF - SSULF)
C  Mar-18-1994 @ CSC-bsg Request 406 Simplified terms in equation to
C  avoid confusion (CDSULF=DSULF=SSULF).  Applied maximum function to
C  ensure that CSOF and CRCP are non-negative numbers and added the 
C  application of the amax function to cpm10 to ensure the breakdown
C  of all pollutants sum to the total exhaust PM 
C
CC
CC            CPM10=DIELEF
              CALL DIESL(MY,IV,ICY,CRCP,CSOF,CDSULF,CISULF,CSO2,CPM10)
C
C  Jul-27-1994 @ CSC-bsg Request 434 Discovered total Sulfate PM should be
C  the sum of indirect and direct sulfate
C
              CTSULF = CDSULF + CISULF
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories use same SOFPNT as BUS
C  Mar-21-1994 @ CSC-bsg  Request 411 Checking Exhaust PM for greater than
C  sum of Direct Sulfate, SOF, and RCP
C  also checking if Exhaust PM is greater than Direct Sulfate
CC              CSOF = SOFPNT(IVV)*(CPM10-CDSULF)
CC              CRCP = (1.-SOFPNT(IVV))*(CPM10-CDSULF)
CC              IF(CPM10.GT.(CDSULF+.01)) 
CC     *WRITE(13,214) IV,MY,ICY,CPM10,CDSULF
CC  214 FORMAT(' IV    MY    ICY   CPM10   CDSULF'/
CC     *3I5,2F8.3)   
CC              IF(CPM10.GT.(CDSULF+CSOF+CRCP+.01))
CC     *WRITE(13,215) IV,MY,ICY,CPM10,CDSULF,CSOF,CRCP
CC  215 FORMAT(' IV    MY    ICY   CPM10   CDSULF    CSOF    CSOF'/
CC     *3I5,4F8.3)   
C    
CC              CSOF = AMAX1(SOFPNT(IVV)*(CPM10-CDSULF),0.)
CC              CRCP = AMAX1((1.-SOFPNT(IVV))*(CPM10-CDSULF),0.)
CC              CPM10 = AMAX1(CPM10, CDSULF + CSOF + CRCP) 
            ENDIF
C
C           Calculate the BRAKE emission factors:
C
CC          CBRAKE = 0.0128*PSBRK*TF(IDX,IV)
CC          CTIRE = 0.002*PSTIRE*IVEHWL(IV)*TF(IDX,IV)
            CBRAKE = 0.0128*PSBRK
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories use same IVEHWL as BUS
C
            CTIRE = 0.002*PSTIRE*IVEHWL(IVV)
C
C  Calculate the FUGUTIVE DUST factors:
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories use same IVEHWL and VEHWT (in FDCALX) as BUS
C
CC          CALL FDCALX(IVV,CUNPVD,CPAVED)
CC          CUNPVD=CUNPVD*TF(IDX,IV)
CC          CPAVED=CPAVED*TF(IDX,IV)
CC          CUNPVD=CUNPVD
CC          CPAVED=CPAVED
C
CC    IF((MY.EQ.1970.AND.ICY.EQ.1980).OR.(MY.EQ.1995.AND.ICY.EQ.1998))
CC   *    WRITE(14,211) IV,MY,CLEAD,CDSULF,CSO2,CISULF,CSOF,CRCP,CPM10
CC211 FORMAT(' For vehicle type:',I4,' in MY:',I5/
CC   *'   The calculated value of       lead is:',F9.6/
CC   *'   the calculated value   direct sulfate:',F9.6/
CC   *'   the calculated value  exhaust sulfate:',F9.6/
CC   *'   the calculated value indirect sulfate:',F9.6/
CC   *'   the calculated value of           sof:',F9.6/
CC   *'   the calculated value of           rcp:',F9.6/
CC   *'   the calculated value of    exhaust pm:',F9.6/)
          TOPART = CPM10 + CISULF + CBRAKE + CTIRE 
C
C  Oct-19-1993 @ ARC-bsg Subtask 325  Expansion of vehicle classes
C  to include bus categories use same TF as BUS
C
            IF(IV.EQ.IVV) EMSIDL(IV) = EMSIDL(IV) + CIDLE*TF(IDX,IVV)
C
            BYFER(1,JDX,IV)  = BYFER(1,JDX,IV)  + CLEAD
C
C  Mar-18-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C
            IF(IV.GT.5) THEN
              BYFER(2,JDX,IV)  = BYFER(2,JDX,IV)  + CSOF
              BYFER(3,JDX,IV)  = BYFER(3,JDX,IV)  + CRCP
            ENDIF
C
            BYFER(4,JDX,IV)  = BYFER(4,JDX,IV)  + CDSULF
            BYFER(5,JDX,IV)  = BYFER(5,JDX,IV)  + CPM10
C
            BYFER(6,JDX,IV)  = BYFER(6,JDX,IV)  + CSO2
            BYFER(7,JDX,IV)  = BYFER(7,JDX,IV)  + CISULF
            BYFER(8,JDX,IV)  = BYFER(8,JDX,IV)  + CTSULF
C
            BYFER(9,JDX,IV)  = BYFER(9,JDX,IV)  + CBRAKE
            BYFER(10,JDX,IV) = BYFER(10,JDX,IV) + CTIRE
            BYFER(11,JDX,IV) = BYFER(11,JDX,IV) + TOPART
C
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting
C
CC            BYFER(12,JDX,IV) = BYFER(12,JDX,IV) + CUNPVD
CC            BYFER(13,JDX,IV) = BYFER(13,JDX,IV) + CPAVED
C
            EF(1,IV) =  EF(1,IV)  + CLEAD*TF(IDX,IVV)
C
C  Mar-18-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C
            IF(IV.GT.5) THEN
              EF(2,IV) =  EF(2,IV)  + CSOF*TF(IDX,IVV)
              EF(3,IV) =  EF(3,IV)  + CRCP*TF(IDX,IVV)
            ENDIF
C
            EF(4,IV) =  EF(4,IV)  + CDSULF*TF(IDX,IVV)
            EF(5,IV) =  EF(5,IV)  + CPM10*TF(IDX,IVV)
C
            EF(6,IV) =  EF(6,IV)  + CSO2*TF(IDX,IVV)
            EF(7,IV) =  EF(7,IV)  + CISULF*TF(IDX,IVV)
            EF(8,IV) =  EF(8,IV)  + CTSULF*TF(IDX,IVV)
C
            EF(9,IV) =  EF(9,IV)  + CBRAKE*TF(IDX,IVV)
            EF(10,IV) = EF(10,IV) + CTIRE*TF(IDX,IVV)
            EF(11,IV) = EF(11,IV) + TOPART*TF(IDX,IVV)
C
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting
C
CC            EF(12,IV) = EF(12,IV) + CUNPVD*TF(IDX,IVV)
CC            EF(13,IV) = EF(13,IV) + CPAVED*TF(IDX,IVV)
C
         DO 52 IP=IP1,IP2 
           IF((IV.LT.4.OR.IV.EQ.6.OR.IV.EQ.7).AND.  
     *        (EF(IP,IV).GT.EMIN.AND.GSFRAC(IGS,IV,IREJN).EQ.0.0)) 
     *        THEN
              WRITE(IOUERR,888) IP,IV
              WRITE(IOUERR,880) EF(IP,IV), GSFRAC(IGS,IV,IREJN)
              STOP 'Execution Terminated with Errors'
           ENDIF
   52    CONTINUE
 888            FORMAT(' Pollutant # = ',I2,2X,' Vehicle Class # = ',I2)
 880     FORMAT('ERROR:  Emission factor is ',E10.2,' and gasoline ',
     *          ' .vs. ',/,7X,' diesel sales fraction is ',E10.2)
C
   50    CONTINUE
C
         IF(IV.EQ.IVV) EMSIDL(13) = EMSIDL(13) + EMSIDL(IV)*VMTMIX(IV)
C
C        Sales fractions = 1.0 for all 4 HDV (HDG,HDD x L,H alt) 
C        groups and all MC's.
C
         DO 55 IP=IP1,IP2
            IF(EF(IP,IV).EQ.0.0 .AND. IV.LT.5) THEN
               WRITE(IOUERR,888) IP,IV
               WRITE(IOUERR,890) EF(IP,IV)
               STOP 'Execution Terminated with Errors'
            ENDIF
            IF(IV.EQ.IVV) VEF(IP)=VEF(IP)+EF(IP,IV)*VMTMIX(IV)
 55      CONTINUE
 890     FORMAT('ERROR:  Emission factor is = ',E10.2) 
C
   60 CONTINUE
C
      RETURN
      END
