      SUBROUTINE GASSLF(ICY,MY,IV,DSULF,ISULF,SO2)
C
C  Called by: EFCALX
C
C  Calls TAMPER, LEDPTR
C
C  Input on call:
C    parameter list: ICY, MY, IV
C    common blocks:
C
C  Output on return: DSULF,ISULF,SO2
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------------
C  CTLFRC   R    Catalyst fraction for a given IV and MY 
C  DCSULF   R    Direct calculation of sulfate emissions based upon the
C                fuel sulfur content and the fuel economy (not used)
C  DSULFC   R    Direct sulfate emission factor for catalyst vehicles
C  DSLFCL   R    19.6 MPH or slower D-sulf for catalyst unleaded vehicles
C  DSLFCH   R    34.8 MPH or faster D-sulf for catalyst unleaded vehicles
C  DSULFN   R    Direct sulfate emission factor for noncatalyst vehicles
C  DSULF    R    Direct sulfate emission factor for fleet average gasoline
C                vehicle
C  DSUFNL   R    No cat no lead direct sulfur emissions term
C  DUMMY    R    Used as a dummy parameter in call to TAMPER
C  FCNVRC  R    Estimated percent of sulfur that is converted to sulfate
C                in a catalyst vehicle
C  FCNVRN  R    Estimated percent of sulfur that is converted to sulfate
C                in a noncatalyst vehicle
C  HDNLTM   R   Heavy Duty Gasoline Vehicle No-lead Not-catalyst equipped
C                term
C  ISULFC   R    Estimated indirect sulfate from catalyst vehicles
C  ISULFN   R    Estimated indirect sulfate from noncatalyst vehicles
C  ISULF    R    Estimated indirect sulfate emission factor
C  IFRAC    I    MY Pointer to catalyst fraction array
C  IYPT     I    Discretionary fuel switching index variable 
C  SO2C     R    Gaseous sulfur emissions from catalyst vehicles
C  SO2N     R    Gaseous sulfur emissions from noncatalyst vehicles
C  SO2      R    Gaseous sulfur emission factor
C
C
C  Notes: 
C  Oct-13-1993 @ ARC-bsg Subtask 325 change code to remove warning
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations added ICY
C  parameter to GASSLF because RMIS is calculated from a call to 
C  NLCONS which requires ICY.  RMIS is used in the new equations.
C  Feb-7-1994 @ CSC-bsg Request 390 modified the calculation of catalyst
C  fractions.  They now come from the sum of four block data numbers.  
C  Eliminated the need for a call to GETPTR to get the catalyst fractions.
C  Feb-10-1994 @ CSC-bsg Request 390 Modified calculation of CATFRC to 
C  include RMIS and remove RMIS from sulfate calculation
C  Mar-9-1994 @ CSC-bsg Request 401  Add user input variables for
C  sulfur weight percent for gasoline and diesel fuel or default values
C  Mar-9-1994 @ CSC-bsg Request 402 Change Sulfate calculation to include
C  DFS term
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG 
C  Apr-7-1994 @ CSC-bsg Request 418 Removed Particle sizes from sulfur
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'LEAD.INC'
      INCLUDE 'FRACT.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'PSIZE.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'DFSBLK.INC'
C
      REAL ISULF,ISULFC,ISULFN
C
C  The base sulfate emission factors come from
C  EPA 460/3-85-005, "Size Specific Total Particulate Emission Factors
C  for Mobile Sources"
C
C  Oct-13-1993 @ ARC-bsg Subtask 325 change code to remove warning
C
      IF (IV.GT.5) THEN
         DSULF = 0.
         ISULF = 0.
         SO2   = 0.
         GOTO 99
      ENDIF        
C
C  Feb-7-1994 @ CSC-bsg Request 390 modified the calculation of catalyst
C  fractions.  They now come from the sum of four block data numbers.  
C  Get the model year pointer to the catalyst fraction array
C
      IF (MY.LT.1968) THEN
        IFRAC = 1
      ELSE IF (MY.GE.1968.AND.MY.LE.1971) THEN
        IFRAC = 2
      ELSE IF (MY.LE.1991) THEN
        IFRAC = 3 + (MY - 1972)
      ELSE 
        IFRAC = 22
      ENDIF
C
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations Get the
C  misfueling rates:
C
      CALL TAMPER(ICY, MY, IV, DUMMY, RMIS)
C
C  Mar-9-1994 @ CSC-bsg Request 402 Change Sulfate calculation to include
C  DFS term -- determine discretionary fuel switching index variable.
C
      CALL LEDPTR(IYPT,IV,MY)
C
C  Feb-10-1994 @ CSC-bsg Request 390 Modified calculation of CATFRC to 
C  include RMIS and remove RMIS from sulfate calculation.
C  Get the catalyst fraction of the gasoline vehicle population.
C
      CTLFRC = (FRACA(IFRAC,1,IV)+FRACA(IFRAC,2,IV)+
     2          FRACA(IFRAC,3,IV)+FRACA(IFRAC,4,IV))*(1.-RMIS)
C
C  For each Vehicle Type get the corresponding fuel economy
C
      FECONM = FLECON(MY,IV)
C
C  Mar-9-1994 @ CSC-bsg Request 401  Add user input variables for
C  sulfur weight percent for gasoline and diesel fuel or default values
C
CC      SWGHT = GSWGHT
      FDNSTY = GDENS
C
C     Compute the grams/mile emission factor of the direct sulfate material:
C 
C     13.6079 = (453.592 * 3.)/100.
C     where: 453.592 = number of grams in a pound
C                  3 = weight ratio of SO4 to sulfur
C     and the division by 100 is to correc for GSWGTR the gasoline weight 
C     ratio of sulfur content in fuel.
C
C     WATER  = weight ratio of seven water molecules to sulfate 
C              (see p. 6-25 of "Regulatory Impact Analysis,
C              Control of Sulfur and Aromatics Contents of On-
C              Highway Diesel Fuel")
C     FDNSTY = fuel density in lbs/gallon
C     FECONM = fuel economy
C     GSWGTR = gasoline weight ratio of sulfur content in fuel
C     DCNVRT  = percent of sulfur exhausted that is directly converted
C               into sulfuric acid.
C
C  
C  Equation 1:  This is the equation that is used to calculate direct 
C      sulfate as a function of the sulfur content and fuel economy: 
C      (used for calculating the fraction of sulfur in the fuel that
C      gets converted to sulfate, DCNVRT.
CC     DCSULF = 13.6079*(1.+ WATER)*FDNSTY*GSWGTU*DCNVRT/FECONM
C
      IF(IV.NE.4) THEN
C
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations
C  Calculation for LDGV, LDGT1, LDGT2, MC
C  Calculate the direct sulfate for catalyst and noncatalyst vehicles:
C  Feb-10-1994 @ CSC-bsg Request 390 Modified calculation of CATFRC to 
C  include RMIS and remove RMIS from sulfate calculation
C
        IF (SPD.LE.19.6) THEN
C
C  Mar-9-1994 @ CSC-bsg Request 402 Change Sulfate calculation to include
C  DSUFNL term
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG removed
C  user input for sulfur weight
C
          DSUFNL = .002
          DSULFN = .002
          DSULFC = 
     2   (FRACA(IFRAC,1,IV)+FRACA(IFRAC,3,IV))*.005
     3   +(FRACA(IFRAC,2,IV)+FRACA(IFRAC,4,IV))*.016       
C
        ELSE IF (SPD.GE.34.8) THEN
          DSULFN = .001
          DSULFC =  
     2          (FRACA(IFRAC,1,IV)* .005
     3          +FRACA(IFRAC,3,IV)* .001 
     4          +FRACA(IFRAC,2,IV)* .020 
     5          +FRACA(IFRAC,4,IV)* .025 ) 
        ELSE
C
C  Interpolate for speeds between 19.6 and 34.8
C
          DSULFN = ((.002-.001)*(SPD-19.6)/(19.6-34.8)+.002)
          DSLFCL = 
     2    ((FRACA(IFRAC,1,IV)+FRACA(IFRAC,3,IV))*.005
     3    +(FRACA(IFRAC,2,IV)+FRACA(IFRAC,4,IV))*.016)
          DSLFCH =  
     2          (FRACA(IFRAC,1,IV)* .005
     3          +FRACA(IFRAC,3,IV)* .001 
     4          +FRACA(IFRAC,2,IV)* .020 
     5          +FRACA(IFRAC,4,IV)* .025 )
          DSULFC = (DSLFCL-DSLFCH)*(SPD-19.6)/(19.6-34.8)+DSLFCL
C
C  end of interpolation section
C
        ENDIF
        DSULF = CTLFRC*DSULFC + (1. - CTLFRC)*DSULFN
CC      IF(ICY.EQ.1995.AND.IV.EQ.1) WRITE(11,201) IV,ICY,MY,SPD(1),
CC   *CTLFRC,DSULFC,DSULFN,DSULF
CC201 FORMAT(' IV  ICY   MY SPEED   CTLFRC   DSULFC   DSULFN    DSULF'/
CC   *I3,I5,I5,F5.1,1X,4F9.6)
C
C  end of non-HDGV section
C
      ELSE IF(IV.EQ.4) THEN
C
C  HDGV code goes here
C
        DSULFN = .006*(5.0/FECONM)
        DSULFC = (.048)*(5.0/FECONM)
C
C  Mar-9-1994 @ CSC-bsg Request 402 Change Sulfate calculation to include
C  DSUFNL term
C
        IF(SPD.LE.19.6) THEN
          DSUFNL = 0.002
        ELSEIF(SPD.GE.34.8) THEN
          DSUFNL = 0.001
        ELSE
C
C  Interpolate for speeds between 19.6 and 34.8
C
          DSUFNL = ((.002-.001)*(SPD-19.6)/(19.6-34.8)+.002)
        ENDIF
C
C  end of HDGV section
C  Sum the contributions from catalyst and noncatalyst vehicles:
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations
C  Mar-9-1994 @ CSC-bsg Request 402 Change Sulfate calculation to include
C  DFS term
C
        DSULF = CTLFRC*DSULFC + (1. - CTLFRC)*DSULFN*(1.-DFS(IYPT,IV))
     2                        + (1. - CTLFRC)*DSUFNL*DFS(IYPT,IV)
      ENDIF
C
C
C     Calculate the fraction of sulfur in the fuel that was converted
C     to sulfate (based on Equation 1 above) for catalyst and non-
C     catalyst vehicles:
C
      FCNVRC = DSULFC*FECONM/( 13.6079*(1.+WATER)*FDNSTY*GSWGTR )
      FCNVRN = DSULFN*FECONM/( 13.6079*(1.+WATER)*FDNSTY*GSWGTR )
C
C     Compute the exhausted SO2:
C
C     9.072 = (453.592 * 2.)/100.
C     where: 453.592 = number of grams in a pound
C                 2. = weight ratio of SO2 to sulfur
C     and the division by 100 is to correct for GSWGTR the gasoline weight
C     ratio of sulfur content in fuel
C
      SO2C = 9.072*FDNSTY*GSWGTR*(1.-FCNVRC)/FECONM
      SO2N = 9.072*FDNSTY*GSWGTR*(1.-FCNVRN)/FECONM
      SO2 = CTLFRC*SO2C + (1.-CTLFRC)*SO2N
C
C            3./2. = weight ratio of SO2 to SO4
C           AMNWGT = the extimated weight ratio of the combination of
C                    ammonium bisulfate and ammonium sulfate in the
C                    atmosphere to SO4 (see p 6-25).
C
C
C     Comput the estimated sulfate material that is formed in the 
C     in the atmosphere due to the SO2 emissions:
C
      ISULFC = ICNVRT * SO2C * (3./2.) * AMNWGT
      ISULFN = ICNVRT * SO2N * (3./2.) * AMNWGT
C
C  Feb-10-1994 @ CSC-bsg Request 390 
C  Changed to make consistent with direct sulfates
C
CC    ISULF = CTLFRC*ISULFC*PSNLCT + (1.-CTLFRC)*ISULFN*PSC
      ISULF = CTLFRC*ISULFC + (1.-CTLFRC)*ISULFN
C
 99   RETURN
      END
