      SUBROUTINE GETBYM
C
C  GETBYM gets the By Model Year Tables selection flags.
C
C  Called by ONESEC.
C
C  Input on call:
C
C    common blocks:
C    /IOUCOM/ IOUGEN,IOUASK
C    /MAXIMA/ MAXVEH
C
C  Output on return:
C
C    common block: /BYMYC1/: IVPICK
C
C
C  Notes:
C  GETBYM was added for PART for OUTFMT=5.
C  Jan-6-1994 @ CSC-bsg  Request 377 Expansion of by-model year to include
C  transit and CBD or heavy urban when applicable.  The application
C  criteria is determined with the BUSFLG.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'BYMYM.INC'
      INCLUDE 'FLAGS.INC'
C
      IF(IOUGEN.EQ.IOUASK) WRITE(IOUASK,200)
  200 FORMAT('&','Enter By Model Year Table picks (format 12i1):  ',/)
      IF(BUSFLG.EQ.1) THEN
       READ(IOUGEN,100,END=99) (IVPICK(IV),IV=1,MAXVEH)
       IF(IOUGEN.EQ.IOUASK) WRITE(IOUASK,100) (IVPICK(IV),IV=1,MAXVEH)
  100 FORMAT(12I1)
      ELSE IF(BUSFLG.EQ.2) THEN
       READ(IOUGEN,110,END=99)
     *   (IVPICK(IV),IV=1,MAXVEH),IVPICK(13),IVPICK(14)
       IF(IOUGEN.EQ.IOUASK) WRITE(IOUASK,110)
     *   (IVPICK(IV),IV=1,MAXVEH),IVPICK(13),IVPICK(14)
  110 FORMAT(14I1)
      ELSE
       READ(IOUGEN,120,END=99)
     *   (IVPICK(IV),IV=1,MAXVEH),IVPICK(15)
       IF(IOUGEN.EQ.IOUASK) WRITE(IOUASK,120)
     *   (IVPICK(IV),IV=1,MAXVEH),IVPICK(15)
      ENDIF
C
  120 FORMAT(13I1)
      DO 10 IV=1,MAXVEH
      IF(IVPICK(IV).LT.1.OR.IVPICK(IV).GT.2) THEN
       WRITE(IOUERR,300) IV, IVPICK(IV)
       STOP ' Execution Terminated with Errors'
      ENDIF
   10 CONTINUE
 300  FORMAT('ERROR:  IVPICK(',I2,') = ',I2,' is invalid input for ',
     *        'the vehicle class picks')
C
      RETURN
C
C  EOF on any attempted read => run aborts.
C
   99 WRITE(IOUERR,400)
 400  FORMAT('ERROR:  Premature end of file.  Trying to read the by-',
     *        'model year picks.')
      PAUSE 'Hit a key to continue'
      STOP ' Execution Terminated with Errors'
C
      END
      SUBROUTINE GETCUM
C
C  GETCUM computes average January 1 fleet cumulative mileages.  GETCUM is
C  called on the first scenario of every run.  If the user enters AMAR, that
C  is the only call.  If the default AMAR is used and therefore ICY dependent
C  HDDV AMAR is calculated for every scenario whose ICY differs from the
C  prior scenario, then GETCUM is correspondingly called to recompute CUMMIL.
C  (Actually, only HDDV CUMMIL need be recalculated)
C
C  Called by EFCALX.
C
C  Input on call:
C
C    common blocks:
C    /MAXIMA/ MAXVEH,MAXYRS
C    /MYRCAL/ XMYM
C
C  Output on return:
C
C    common block: /CUMCOM/ CUMMIL
C
C
C  Notes:
C  None.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'RESULT.INC'
C
      DO 10 IV=1,MAXVEH
      CUMMIL(1,IV)=XMYM(1,IV)*100000.
C
      DO 10 JDX=2,MAXYRS
      CUMMIL(JDX,IV)=XMYM(JDX,IV)*100000.+CUMMIL(JDX-1,IV)
   10 CONTINUE
C
      RETURN
      END
      SUBROUTINE GETIDL(CIDLE,MY,IV,ICY)
C
C  This subroutine returns the idle emission factor
C  for vehicle class IV, model year MY, calendar year ICY.
C
C  Called by EFCALX.
C
C  Calls DIESLF
C
C  Input on call:
C    common blocks: /CARBON/ SOFPNT
C
C
C  Output on return: CIDLE
C
C     Local Variable Dictionary:
C
C  Variable    Type      Description
C -----------------------------------------------------------------------
C   DUMMY      R         Dummy parameter to DIESLF subroutine 
C   DINC       R         Difference between low and high sulfur  
C   DINCL      R         Intermediate results are saved for low
C   DINCH      R         Intermediate results are saved for high
C   IDX        I         Model year indicator
C   UNRCP      R         Unused variables but calculated RCP
C   UNSOF      R         Unused variables but calculated SOF
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'FRACT.INC'
      INCLUDE 'IDLE.INC'
      INCLUDE 'PSIZE.INC'
C
C  Notes: Jul-6-1994 @ CSC-bsg Made Idle EF backout sulfur calculations
C  added ICY to parameter list to determine if low sulfur weight is used
C  Jul-29-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
C
      CIDLE = 0.
C
      IF (IV.LT.8) RETURN
C
      IVV = IV - 7
C
      DO 10 IPTR=1,4
      IF(MY .LE. IDLYRS(IPTR)) GOTO 11
10    CONTINUE

11    IDLPNT=IPTR

C     Multiply by the particle size cutoff, PSDIE:
      CIDLE=BASIDL(IDLPNT,IVV)*PSDIE
C
C  for calendar years 1993+ applied to all model years
C  First used 25% sulfur weight ratio
C  Second recalculate with lower 5% sulfur weight ratio
C
      IF(ICY.LT.1993) GOTO 99
C
C
C  Jul-29-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
      IDX=MY-ICY+MAXYRS
      CALL DIESLF(MY,IV,DUMMY,DSULF,DUMMY,DUMMY,IDX,1)
C
C  Jun-3-1994 @ CSC-bsg Request 443 calculation of diesel incremental
C
      IF((IV.GE.12.AND.MY.GE.1992).OR.(MY.GE.1994)) THEN
C
C  Jul-29-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
	CALL DIESLF(MY,IV,DUMMY,DINCL,DUMMY,DUMMY,IDX,2)
	DINCH=DSULF
	DINC=DINCH-DINCL
	CIDLE=CIDLE+DINC
      ENDIF
      UNSOF = 0.0
      UNRCP = 0.0
C
      IF(IV.LE.12) THEN
	UNSOF = SOFPNT(IV)*(CIDLE-DSULF)
      ELSE
	UNSOF = SOFPNT(12)*(CIDLE-DSULF)
      ENDIF
      UNRCP = CIDLE-DSULF-UNSOF
C
C  Jul-29-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C  should be a correction factor adjustment from regular bus EF for direct
C  sulfates.  Also added the BUSLF array to the RESULTA include file
C  This forced the expansion of the parameter list to include IDX the first
C  dimension of the array.
C
      CALL DIESLF(MY,IV,DUMMY,DSULF,DUMMY,DUMMY,IDX,2)
      CIDLE = UNRCP + DSULF + UNSOF
C
  99  RETURN
      END
      SUBROUTINE GETIOU
C
C  GETIOU reads in the prompt / mode flag
C
C  Called by CONSEC.
C
C  Input on call:
C
C    common blocks:
C    /IOUCOM/ IOUIMD,IOUGEN,IOUREP,IOUERR,IOUASK
C
C  Output on return:
C
C    common blocks:
C    /IOUCOM/ IOUREP,IOUERR,IOUGEN
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  -----   ----  -------------------------------------------------------
C  DFILE   C*40  Driver file name
C  FEXIST  L     Indicates existance of implementation files
C  IFIL    C*80  Names for implementation files
C  IOUDRV  I     Unit number for driver file
C
C
C  Notes:
C
C
C  GETIOU was added for CONSEC.
C  May-25-1993 @ ARC-bsg Subtask 248
C  Oct-29-1993 @ ARC-bsg Subtask 332 reinstated driver that SAI removed
C  May-18-1994 @ CSC-bsg Request 434 Integration and regression testing
C
C
      INCLUDE 'IOU.INC'
C
      CHARACTER*80 IFIL
      CHARACTER*40 DFILE
      CHARACTER*1 YN
      LOGICAL FEXIST
      DFILE='PART5.IN'
      IOUDRV=7
C
C  Read in prompt/mode flag and output unit changes (if any).
C
      WRITE(IOUASK,200)
  200 FORMAT(' PART5'//' Revised Feb 24, 1995'///
     *' Looking for Driver file PART5.IN')
C
      INQUIRE(FILE=DFILE,EXIST=FEXIST)
C
      IF(.NOT.FEXIST) THEN
	WRITE(IOUASK,210)
  210   FORMAT(' ERROR Program is aborted, please create Driver file ',
     *  'PART5.IN according to proper criteria.')
	PAUSE 'Hit a key to continue'
	STOP
      ENDIF
C
      OPEN(IOUDRV,FILE=DFILE,STATUS='OLD')
C
      READ(IOUDRV,100) YN
  100 FORMAT(A1)
  110 FORMAT(A80)
C
C  Check the interactive option
C
      IF (YN.EQ.'N' .OR. YN.EQ.'n') THEN
C
       READ(IOUDRV,110) IFIL
       WRITE(IOUASK,*) ' Read in input file name: ',IFIL
C
       INQUIRE(FILE=IFIL,EXIST=FEXIST)
C
       IF(.NOT.FEXIST) THEN
	  WRITE(IOUASK,220) IFIL
  220     FORMAT(' ERROR:  input FILE ',A80,'does not exist',
     *    'please check directory -- program is aborted')
	  PAUSE 'Hit a key to continue'
	  STOP
       ENDIF
C
       OPEN(IOUGEN,FILE=IFIL,STATUS='OLD')
       WRITE(IOUASK,*) ' Opened input file ',IFIL
C
       READ(IOUDRV,110) IFIL
       WRITE(IOUASK,*) ' Read in report file name: ',IFIL
       WRITE(IOUASK,*) ' Opened report file ',IFIL
C
C  Feb-18-1994 @ CSC-bsg Request 394 Incompatible WATCOM remove RECL
C  on the MAC
C  Mar-16-1994 @ CSC-bsg Request 398 Add bus categories as output
C
       OPEN(IOUREP,FILE=IFIL)
C
       READ(IOUDRV,110) IFIL
       WRITE(IOUASK,*) ' Read in errors file name: ',IFIL
       OPEN(IOUERR,FILE=IFIL)
       WRITE(IOUASK,*) ' Opened errors file ',IFIL
      ELSE
       WRITE(IOUASK,230)
  230    FORMAT(' You have chosen interactive PART5 execution'//
     *   ' enter the report file name')
       WRITE(IOUASK,240)
       READ(IOUASK,110) IFIL
       OPEN(IOUGEN,FILE=IFIL,STATUS='OLD')
       WRITE(IOUASK,*) ' Opened input file ',IFIL

       WRITE(IOUASK,250)
       OPEN(IOUREP,FILE=IFIL)
       WRITE(IOUASK,*) ' Opened report file ',IFIL
C
       WRITE(IOUASK,260)
  240    FORMAT(' Please enter the input file name')
  250    FORMAT(' Please enter the report file name')
  260    FORMAT(' Please enter the errors file name')
       READ(IOUASK,110) IFIL
       OPEN(IOUERR,FILE=IFIL)
       WRITE(IOUASK,*) ' Opened errors file ',IFIL
       IOUASK=IOUGEN
      ENDIF
C
      RETURN
C
C  EOF on any attempted read => take alternate return 1 => run aborts.
C
      END
CC    SUBROUTINE GETLED
CC
CC    This subroutine reads in the user supplied lead content of leaded
CC    and unleaded gasoline
CC
CC    Called by:  ONESEC
CC
CC    Output on return:  /LEDCOM/ IYRPB
CC
CC
CC
CC Notes:
CC Jan-4-1994 @ CSC-bsg Request 376 User's Guide input files
CC Fixed user supplied lead content option.  Finish year minus start
CC year is not ever supposed to be more than the array size of undefined
CC values and other erroneous results will occur.
CC
CC
CC    CHARACTER*45 MESSAG(2)
CC    DATA MESSAG/'beginning and ending years for lead input',
CC   *             'lead content of fuel'/
CC
CC    LCGSIZ=22
CC
CC    WRITE (IOUASK,10)
CC10    FORMAT ('0', 'Enter lead content of gasoline (grams/gallon)',
CC   *              ' by year',/)
CC
CC    WRITE (IOUASK,20)
CC20    FORMAT(' Enter first and last year to change -',
CC   *       ' format (I4,1X,I4) ')
CC
CC    ILINE = 1
CC30    READ (IOUGEN,40,END=110) ISTART, IFIN
CC    WRITE (IOUASK,40) ISTART, IFIN
CC40    FORMAT (I4, 1X, I4)
CC
CC    IF (ISTART .LT. 1974 .OR. ISTART .GT. IFIN) THEN
CC     WRITE(IOUERR,500) ISTART,IFIN
CC     STOP ' Execution Terminated with Errors'
CC    ENDIF
CC500  FORMAT('ERROR:  ',I4,' is an invalid start year.  It must be',
CC   *         ' less than ',I4,/,7X,' and greater than 1974.')
CC
CC Jan-4-1994 @ CSC-bsg Request 376 User's Guide input files
CC Fixed user supplied lead content option.  Finish year minus start
CC year is not ever supposed to be more than the array size of undefined
CC values and other erroneous results will occur.
CC
CC    IF ((IFIN-ISTART+1).GT.LCGSIZ) THEN
CC     WRITE(IOUERR,510) ISTART,IFIN,LCGSIZ
CC     STOP ' Execution Terminated with Errors'
CC    ENDIF
CC510  FORMAT(' The difference between the first lead year:',I5,
CC   *' and the last lead year:',I5/' must be less than:',I5)
CC    IPTR = 1
CC
CC    DO 50 I = 1, LCGSIZ
CC50    IF (IYRPB(I) .LT. ISTART .AND. IYRPB(I).GT.0) IPTR = I
CC
CC    LCGSIZ = IPTR
CC    WRITE (IOUASK,60)
CC60    FORMAT ('0', 'Enter lead content of leaded and unleaded gasoline',
CC   *      ' -- format (F5.3,1X,F5.3)',/)
CC
CC    ILINE = 2
CC    DO 100 IYR = ISTART, IFIN
CC
CC70       WRITE (IOUASK,80) IYR
CC80       FORMAT (' for year ', I5)
CC
CC     IYRPB(LCGSIZ) = IYR
CC
CC     READ (IOUGEN,90,END=110) (PB(LCGSIZ,IFUEL),IFUEL=1,2)
CC     WRITE (IOUASK,90) (PB(LCGSIZ,IFUEL),IFUEL=1,2)
CC90       FORMAT (F5.3, 1X, F5.3)
CC
CC     IF (PB(LCGSIZ,1) .LT. 0.0) THEN
CC        WRITE(IOUERR,520) PB(LCGSIZ,1)
CC        PB(LCGSIZ,1) = -1.*PB(LCGSIZ,1)
CC     ENDIF
CC     IF (PB(LCGSIZ,2) .LT. 0.0) THEN
CC        WRITE(IOUERR,520) PB(LCGSIZ,2)
CC        PB(LCGSIZ,2) = -1.*PB(LCGSIZ,2)
CC     ENDIF
CC     LCGSIZ = LCGSIZ + 1
CC520        FORMAT('WARNING:  ',F10.2,' is invalid input for the',
CC   *            ' lead content of the fuel',/,7X,' The value',
CC   *            ' has been multiplied by -1.')
CC
CC100   CONTINUE
CC    RETURN
CC110   WRITE(IOUERR,530) MESSAG(ILINE)
CC530  FORMAT('ERROR:  Premature end of file.  Trying to read:',/,7X,A45)
CC    STOP ' Execution Terminated with Errors'
CC
CC    END
      SUBROUTINE GETMRN
C
C  GETMRN checks for and reads in and screens user supplied mileage accrual
C  rates and registration distributions.
C
C  Called by ONESEC.
C
C  Input on call:
C
C    common blocks:
C    /FLAGS2/ MYMRFG
C    /IOUCOM/ IOUGEN,IOUASK
C    /MAXIMA/ MAXVEH,MAXYRS
C    /MYRSAV/ AMAR(25,12),JULMYR(25,12)
C
C  Output on return:
C
C    common blocks:
C    /MYRSAV/ AMAR,JULMYR
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  MYF      I    my of first (JDX order) AMAR / JULMYR to be entered on READ
C  MYL      I    my of last (JDX order) AMAR / JULMYR to be entered on READ
C  SUMMYR   R    sum of myr for IV; used to normalize user entered JULMYR
C  SUM8     R    sum of 2BHDDV distributions over all 25 years
C  SUM9     R    sum of LHDDV distributions over all 25 years
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'FLAGS.INC'
C
      CHARACTER*11 NAMMMR(12)
      CHARACTER*34 ESTRIN(2)
C
      DATA ESTRIN/'average mileage accumulation rates',
     *             'July 1 registration distributions '/
C
      DATA NAMMMR/'for LDGV:  ', 'for LDGT1: ',
     *            'for LDGT2: ', 'for HDGV:  ',
     *            'for MC:    ', 'for LDDV:  ',
     *            'for LDDT:  ', 'for 2BHDDV:',
     *            'for LHDDV: ', 'for MHDDV: ',
     *            'for HHDDV: ', 'for BUSES: '/
C
      IF (MYMRFG.EQ.1) RETURN
C
C  Check for user supplied my mileage accrual rates and / or registration
C  distributions.
C
      IF(MYMRFG.EQ.3) GOTO 20
C
C  Get mileage accrual rates.
C
      ISTRNG = 1
      WRITE(IOUASK,200)
      WRITE(IOUASK,205)
      DO 10 IV=1,MAXVEH
       WRITE(IOUASK,210) NAMMMR(IV)
       READ(IOUGEN,110,END=99) (AMAR(JDX,IV),JDX=1,MAXYRS)
       WRITE(IOUASK,110) (AMAR(JDX,IV),JDX=1,MAXYRS)
 10   CONTINUE
C
      DO 15 IV=1,MAXVEH
       DO 15 JDX=1,MAXYRS
	  IF (AMAR(JDX,IV).LT.0.0 .OR. AMAR(JDX,IV).GT.1.) THEN
	     WRITE(IOUERR,400) AMAR(JDX,IV),JDX,NAMVEH(IV)
	     STOP 'Execution Terminated with Errors'
	  ENDIF
   15 CONTINUE
C
      IF(MYMRFG.EQ.2) GOTO 45
C
C  Get vehicle registration distributions.
C
      ISTRNG = 2
   20 WRITE(IOUASK,200)
      WRITE(IOUASK,220)
      DO 35 IV=1,MAXVEH
	  WRITE(IOUASK,210) NAMMMR(IV)
	  READ(IOUGEN,120,END=99) (JULMYR(JDX,IV),JDX=1,MAXYRS)
	  WRITE(IOUASK,120) (JULMYR(JDX,IV),JDX=1,MAXYRS)
       CHKMYR=0.0
       DO 30 JDX=1,MAXYRS
	  CHKMYR=JULMYR(JDX,IV)+CHKMYR
   30  CONTINUE
       IF(CHKMYR .GT. 1.01 .OR. CHKMYR .LT. 0.99) THEN
	  WRITE(IOUERR,410) NAMVEH(IV), CHKMYR
	  STOP 'Execution Terminated with Errors'
       ENDIF
   35 CONTINUE
C
      DO 40 IV=1,MAXVEH
       DO 40 JDX=1,MAXYRS
	  IF(JULMYR(JDX,IV).LT.0.0 .OR. JULMYR(JDX,IV).GT.1.) THEN
	     WRITE(IOUERR,420) JULMYR(JDX,IV),JDX,NAMVEH(IV)
	     STOP 'Execution Terminated with Errors'
	  ENDIF
   40 CONTINUE
C
   45 CONTINUE
C
C  Check vehicle equalities (LDGV,LDDV), (LDGT1,LDDT) mod yr regs.
C
      DO 60 JDX=1,MAXYRS
       IF(JULMYR(JDX,1).NE.JULMYR(JDX,6)) THEN
	  WRITE(IOUERR,430) NAMVEH(1),NAMVEH(6),JULMYR(JDX,1),
     *                        JULMYR(JDX,6),JDX
	  STOP 'Execution Terminated with Errors'
       ENDIF
       IF(JULMYR(JDX,2).NE.JULMYR(JDX,7)) THEN
	  WRITE(IOUERR,430) NAMVEH(2),NAMVEH(7),JULMYR(JDX,2),
     *                        JULMYR(JDX,7),JDX
	  STOP 'Execution Terminated with Errors'
       ENDIF
   60 CONTINUE
C
      RETURN
C
 110  FORMAT(10F7.5)
 120  FORMAT(10F5.3)
 200  FORMAT(/)
 210  FORMAT(' ',A11,/)
 205  FORMAT(' Enter the average mileage accumulation rates in',
     *  ' miles over 100,000',/,' by age from newest to oldest',
     *  ' for 25 years: (FORMAT 10F7.5)',/)
 220  FORMAT(' ','Enter the registration distributions ',/,
     *       ' from newest to oldest over 25 years:',
     *       ' (FORMAT 10F5.3)',/)
C
 400  FORMAT('ERROR: ',F7.5,' is invalid input for the average ',
     *    'mileage accumulation rate,',/,
     *     7X,' for vehicle age ',i2,' and vehicle class ',A8)
 410  FORMAT('ERROR:  July 1 registration distributions do not sum to 1',
     *      /,7X,' for vehicle class ',A8,'; they sum to ',F6.4)
 420  FORMAT('ERROR: ',F5.3,' is invalid input for the July 1 ',
     *    'registration distributions,',/,
     *     7X,' for vehicle age ',i2,' and vehicle class ',A8)
 430  FORMAT('ERROR:  July 1 registration distributions must be the',
     *       ' same for vehicle classes ',/,7X,A8,' and ',A8,'.',
     *       '  Values input were ',2(2X,F5.3),' for year ',i2)
C
C  EOF on any attempted read => run aborts.
C
  99  WRITE(IOUERR,300) ESTRIN(ISTRNG)
 300  FORMAT('ERROR:  premature end of file.',/,7X,' Trying to read ',
     *        A34)
      STOP 'Execution Terminated with Errors'
C
      END
CC    SUBROUTINE GETPTR(SAPT, IV, MY)
CC
CC GETPTR selects index pointers for sales fractions for
CC  unleaded catalyst/noncatalyst vehicles
CC
CC Called by ORGANC.
CC
CC Calls none.
CC
CC Input on call:
CC
CC   parameter list: SAPT, IV, MY
CC   common blocks:
CC   /EMCCOM/ MYEMC
CC
CC Output on return: SAPT = pointer for sales fractions of catalyst vehicles
CC
CC Notes: none.
CC
CC    INTEGER SAPT
CC
CC    INCLUDE 'PARAM.INC'
CC    INCLUDE 'LEAD.INC'
CC
CC Select pointer index(SAPT) for Sales Fractions for catalyst vehicles
CC
CC20    DO 30 SAPT=1,22
CC    IF(MY .LE. MYEMC(SAPT,IV)) GOTO 90
CC30    CONTINUE
CC
CC90    RETURN
CC    END
      SUBROUTINE GETSC1(ICY)
C
C  GETSC1 reads in and validates the 1st required scenario parameter record.
C
C  Called by PARSEC.
C
C  Input on call:
C
C    common blocks:
C     /IOUCOM/ IOUGEN,IOUASK
C     /MAXIMA/ MAXVEH
C     /YEARS4/ IY1941,IY1960,IY2020
C
C  Output on return: ICY
C     /SCENE1/ SPD,ISPDCY,UNSILT,PVSILT,IPDAYS
C     /REGION/ IREJN
C     /CITPAR/ SCNAME(8)
C     /PSIZE/  PSZCUT
C     /FESCFA/ SCF(2)
C
C    parameter list: ICY
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  MESSAG  C    Error MESSAG string corresponding to the input line being
C                read.
C  ILINE    I    Line number being read.   Used as an indes for MESSAG.
C  SPD      R    user supplied average speed
C  ISPDCY   I    user supplied driving cycle type:
C                1=transient, 2=steady cruise
C  UNSILT   R    unpaved roads percent silt loading
C  PVSILT   R    Paved roads silt loading (g/m^2)
C  IPDAYS   I    number of days with >0.01" precip. (20 to 200)
C  IWHLFG   I    indicate that user has put in number of wheels
C
C
C  Notes:
C  May-25-1993 @ ARC-bsg Subtask 248
C  Sep 1993 - Modified to conform to new fugitive dust calcalculation
C             REMOVED:  IROAD (industrial road type), NLANES (number of
C             industrial road lanes), and INDF (industrial activity factor)
C  Oct-29-1993 @ ARC-bsg Subtask 332 reinstated driver that was removed by SAI
C  Jun-7-1994 @ CSC-bsg Request 443 user defined bus trap input
C  Jul-21-1994 @ CSC-bsg Changed particle size cut off for fugitive dust to
C  be a minimum of 2.5 and non-dust to have a minimum of 1.0
C  Jul-25-1994 @ CSC-bsg Request 434 adding the wheel flag to indicate
C  and process user input for number of wheels
C  Oct-28-1994 @ CSC-ked Request 474 PART5 Fugitive Dust Reformatting
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'BASEFD.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'PSIZE.INC'
      INCLUDE 'TRAP.INC'
C
      CHARACTER*60 MESSAG(6)
      CHARACTER*1 YN
C
      DATA MESSAG/ 'Region, Year, Speed Cycle, Speed',
     *       'Unpvd Silt%, Paved Silt(g/m^2)',
     *       'Number of Lanes & Number of Precipitation Days',
     *       'Scene Name',
     *       'Particle Size Cutoff',
     *       'Fleet Average Vehicle Weight'/
C
C  GETSC1 is called once for each scenario of the run.
C
      IF (IOUGEN.EQ.IOUASK .AND. ISCENE.GT.1) THEN
       WRITE(IOUASK,90)
       READ(IOUGEN,190,END=98) YN
       IF (YN.EQ.'N' .OR. YN.EQ.'n') go to 98
       ENDIF
 90    FORMAT(' Do you wish to run another scenario? ')
 190   FORMAT(A1)
C
C
C***********************************************************************
C  Get the region, year, speed cycle, and speed:
      ILINE = 1
      NSPDS=1
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,200)
      READ(IOUGEN,100,END=98) IREJN,ICY,ISPDCY,SPD
      IF (IREJN.EQ.9) THEN
CC       WRITE(IOUASK,*) ENDMSG
CC       PAUSE 'Hit a key to continue'
       STOP
      ENDIF
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,300) IREJN,ICY,ISPDCY,SPD
C
C  Check to see if the input year is in-range:
C
      IF(ICY.LT.IY1960 .OR. ICY.GT.IY2020) THEN
       WRITE(IOUERR,410) ICY
       PAUSE 'Hit a key to continue'
       STOP ' Execution Terminated with Errors'
      ENDIF
C
C  Check to see if the region is either 1 or 2:
C
      IF (IREJN.LT.1 .OR. IREJN.GT.2) THEN
       WRITE(IOUERR,420) IREJN
       IREJN = 1
       ENDMSG = ' Execution Terminated with Warnings'
      ENDIF
C
C  Check to see if the speed cycle is either 1 or 2:
C
      IF (ISPDCY.LT.1 .OR. ISPDCY.GT.2) THEN
       WRITE(IOUERR,430) ISPDCY
       ENDMSG = ' Execution Terminated with Warnings'
       ISPDCY = 2
      ENDIF
C
C  Check the speed input:
C
      IF(SPD .LT. 0.0) THEN
       WRITE(IOUERR,440) SPD
       PAUSE 'Hit a key to continue'
       STOP ' Execution Terminated with Errors'
      ENDIF
      IF(SPD .LT. 2.5) THEN
       WRITE(IOUERR,450) SPD
       ENDMSG = ' Execution Terminated with Warnings'
       SPD = 2.5
      ENDIF
      IF (SPD .GT. 55.) THEN
       WRITE(IOUERR,460) SPD
       ENDMSG = ' Execution Terminated with Warnings'
       SPD = 55.
      ENDIF
C
C
 100  FORMAT(I1,1X,I4,1X,I1,1X,F4.1)
 200  FORMAT('0','Enter:  Region, Year(i4), Speed cycle, Speed',/)
 300  FORMAT(1X,I1,1X,I4,1X,I1,1X,F4.1,1X,I1,1X,F6.2)
 400  FORMAT('ERROR:  ',I2,' is invalid input for the region.',/,
     *     7X,' The value should be 1 or 2 for low or high altitude.')
 410  FORMAT('ERROR:  ',I4,' is an invalid input for the year.',/,
     *       7X,' The year must be between 1960 and 2020')
 420  FORMAT('WARNING:  ',I2,' is not a valid input for the region',/,
     *          7X,' The value has been reset to 1')
 430  FORMAT('WARNING:  The speed cycle ',I2,' is not a valid input.',/,
     *        7X,' The value has been reset equal to 2 (i.e. cruise)')
 440  FORMAT('ERROR:  ',F5.2,' is not a valid input for the speed.',/,
     *       7X,' The speed must be between 2.5 and 55 miles/hour')
 450  FORMAT('WARNING:  ',F5.2,' is too small a speed.',/,
     *      7X,' The speed has been reset to 2.5 miles/hour')
 460  FORMAT('WARNING:  ',F5.2,' is too great a speed.',/,
     *      7X,' The speed has been reset to 55 miles/hour')
C
C
C***********************************************************************
C  Jul-25-1994 @ CSC-bsg Request 434 adding the wheel flag to indicate
C  and process user input for number of wheels
C  Get the unpaved road silt%, paved road silt loading (g/m^2), WHEELFLG
C
      ILINE = 2
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,201)
      IWHLFG = 1
      READ(IOUGEN,101) UNSILT,PVSILT,IWHLFG
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,301) UNSILT,PVSILT,IWHLFG
C
C  Check the unpaved silt %
C
      IF (UNSILT.LT.4.3) THEN
       WRITE(IOUERR,470) UNSILT
       UNSILT = 4.3
       ENDMSG = ' Execution Terminated with Warnings'
      ENDIF
      IF (UNSILT.GT.20.) THEN
       WRITE(IOUERR,480) UNSILT
       UNSILT = 20.
       ENDMSG = ' Execution Terminated with Warnings'
      ENDIF
C
C  Check the paved road silt loading (g/m^2):  PVSILT
C
      IF (PVSILT.LT.0.02) THEN
       WRITE(IOUERR,500) PVSILT
       PVSILT = 0.02
       ENDMSG = ' Execution Terminated with Warnings'
      ENDIF
      IF (PVSILT.GT.400.) THEN
       WRITE(IOUERR,510) PVSILT
       PVSILT = 400.
       ENDMSG = ' Execution Terminated with Warnings'
      ENDIF
C
  101 FORMAT(F4.1,1X,F6.2,1X,I1)
  201 FORMAT('0','Enter:  Unpaved silt%, Paved silt (g/m^2)')
  301 FORMAT(1X,F4.1,1X,F6.2)
 470  FORMAT('WARNING:  ',F5.2,' is an invalid input for the unpaved',
     *    ' silt %',/,7X,' Unpaved silt % must be greater than 4.3%.',/,
     *    7X,' The value has been reset to 4.3')
 480  FORMAT('WARNING:  ',F5.2,' is an invalid input for the unpaved',
     *    ' silt %',/,7X,' Unpaved silt % must be less than 20.0%.',/,
     *       7X,' The value has been reset to 20.0')
C
C  Jun-14-1994 @ CSC-bsg Request 449 silt content in the printout to have enough
C  significant digits so that 0.02 is reported instead of 0.0 in the echo.
C
 500  FORMAT('WARNING:  ',F6.2,' is an invalid input for the ',
     *  'paved silt (g/m^2)',/,7X,' Paved silt  must be greater ',
     *  'than 0.02.',/,7X,' Value has been reset to 0.02')
 510  FORMAT('WARNING:  ',F6.2,' is an invalid input for the ',
     *  'paved silt (g/m^2)',/,7X,' Paved silt  must be less ',
     *  'than 400.',/,7X,' Value has been reset to 400.0')
C
C***********************************************************************
C     Get the number of precipitation days/year:
      ILINE = 3
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,202)
C
C  Jun-7-1994 @ CSC-bsg Request 443 user defined bus trap input
C  Read the trap flag and percentages
C
      READ(IOUGEN,102,END=99) IPDAYS,TRAPFG,TRAPCT(1),TRAPCT(2)
C
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUGEN,102) IPDAYS
C
C     Check the number of precipitation days/year:  IPDAYS
C
      IF (IPDAYS.LT.20) THEN
       WRITE(IOUERR,540) IPDAYS
       ENDMSG = ' Execution Terminated with Warnings'
       IPDAYS = 20
      ENDIF
      IF (IPDAYS.GT.200) THEN
       WRITE(IOUERR,550) IPDAYS
       ENDMSG = ' Execution Terminated with Warnings'
       IPDAYS = 200
      ENDIF
C
C  Jun-7-1994 @ CSC-bsg Request 443 user defined bus trap input
C  Check the trap flag
C
      IF (TRAPFG.NE.2) TRAPFG = 1
C
      IF (TRAPFG.EQ.2) THEN
	IF (TRAPCT(1).LT.0. .OR. TRAPCT(1).GT.100.0) TRAPCT(1) = 0.0
	IF (TRAPCT(2).LT.0. .OR. TRAPCT(2).GT.100.0) TRAPCT(2) = 0.0
      ENDIF
C
  102 FORMAT(I3,1X,I1,1X,F5.1,1X,F5.1)
  202 FORMAT('0','Enter:  Number ',
     *           'of precipitation days per year   ',/)
  302 FORMAT(1X,I3)
 540  FORMAT('WARNING:  ',I3,' is too low an input for the # of',
     *     ' precipitation days/year.',/,7X,' The value has been',
     *     ' reset to 20')
 550  FORMAT('WARNING:  ',I3,' is too high an input for the # of',
     *     ' precipitation days/year.',/,7X,' The value has been',
     *     ' reset to 200')
C
C***********************************************************************
C     Get the scene name
      ILINE = 4
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,203)
      READ(IOUGEN,103,END=99) SCNAME
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,303) SCNAME
C
  103 FORMAT(8A4)
  203 FORMAT('0','Enter:  Scenario Name   ')
  303 FORMAT(1X,8A4)
C
C***********************************************************************
C  Jul-21-1994 @ CSC-bsg Changed particle size cut off for fugitive dust to
C  be a minimum of 2.5 and non-dust to have a minimum of 1.0
C
C     Get the particle size cutoff:
      ILINE = 5
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,130)
      READ(IOUGEN,230,END=99) PSZCUT
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,330) PSZCUT
C
C     Check the particle size cutoff:  PSZCUT
C
      IF (PSZCUT.LT.1.0) THEN
       WRITE(IOUERR,560) PSZCUT
       ENDMSG = ' Execution Terminated with Warnings'
       PSZCUT = 1.
      ENDIF
      IF (PSZCUT.GT.10.) THEN
       WRITE(IOUERR,570) PSZCUT
       ENDMSG = ' Execution Terminated with Warnings'
       PSZCUT = 10.
      ENDIF
      IF (PSZCUT.LT.2.5) WRITE(IOUREP,571)
  571 FORMAT('   NOTE:'/T10,'The lower limit for particle size ',
     *'cuttoff for Fugitive Dust is'/T10,'2.5 microns.  This output ',
     *'reflects emissions for 2.5 microns for'/T10,'Fugitive Dust ',
     *'only (Unpaved and Paved Dust.)'/)
C
C
 130  FORMAT('0','Enter the particle size cutoff (0.1 to 10.):  ')
 230  FORMAT(F5.2)
 330  FORMAT(1X,F5.2)
 560  FORMAT('WARNING:  ',F5.2,' is an invalid input for the particle',
     *       ' size cutoff.',/,7X,' The value has been reset to 1.0')
 570  FORMAT('WARNING:  ',F5.2,' is an invalid input for the particle',
     *       ' size cutoff.',/,7X,' The value has been reset to 10.0')
C
C***********************************************************************
C     Get the user defined vehicle weights for each of the 12
C         vehicle types
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting.
C  Replaced 'Av. Veh. Weight for 12 classes' with 'Fleet Av. Veh. Wt.'
C
      ILINE = 6
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,702)
 702  FORMAT('0','Enter the Fleet Average Vehicle Weight:',/)
      READ(IOUGEN,712,END=99) USRWT
 712  FORMAT(I6)
C***  Internal flag for EPA use only:
      INTRNL = 0
C***
      IF (INTRNL.EQ.1) THEN
	 USRWT=VEHWT
      ENDIF
C  FORMAT('NOTE:  Using default weight of ',I5,' for vehicle ',
C    *       ' type #',I2)
C
C  Jul-25-1994 @ CSC-bsg Request 434 adding the wheel flag to indicate
C  and process user input for number of wheels
C
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting.
C  Replaced 'Av. Veh. Wheels for 12 classes' with 'Fleet Av. Veh. Wheels'
C  
      IF(IWHLFG.EQ.2) THEN 
	READ(IOUGEN,800) IFAVWL
      ENDIF
C
  800 FORMAT(I2)
C
C***********************************************************************
C  Assign altitude in feet corresponding to selected (low,high) region.
C
      ALT=FEET(IREJN)
C
      IF (NSPDS.GT.1) RETURN
CC      DO 20 IV=2,MAXVEH
CC      SPD(IV)=SPD(1)
CC   20 CONTINUE
C
C     For lead setup, calculate fuel economy correction factors:
C     1 = Cycle driving,  2 = Steady driving
C
      SCF(1)=0.1793+(0.038561*SPD)-(0.00041067*(SPD**2))
      SCF(2)=0.26929+(0.054607*SPD)-(0.00069818*(SPD**2))
C
      RETURN
C
C     Terminate the run if end of file on first line of input,
C     and print out the end MESSAG
C
 98   WRITE(IOUASK,*) ENDMSG
CC      PAUSE 'Hit a key to continue'
      STOP
C
C  EOF on any attempted read => run aborts.
C
 99   WRITE(IOUERR,600) MESSAG(ILINE)
 600  FORMAT('ERROR:  Premature end of file.  Trying to read:',/,
     *       8X,A60)
      PAUSE 'Hit a key to continue'
      STOP ' Execution Terminated with Errors'
      END
      SUBROUTINE GETSLF
C
C     This subroutine reads in the user supplied sulfur content of
C     diesel fuels when the RFGFLG=3
C
C     Called by: ONESEC
C
C     Calls: none
C
C     Input on call:
C     /IOUCOM/ IOUGEN,IOUASK
C
C     Output on return:
C     /SULFR/DSWGTR
C
C
C  Notes:
C  Mar-9-1994 @ CSC-bsg Request 401  Add user input variables for
C  sulfur weight percent for gasoline and diesel fuel or default values
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'FRACT.INC'
C
CC    WRITE (IOUASK,10)
CC10    FORMAT ('0', 'Enter sulfur weight percent of gasoline fuel: ')
C
CC      READ(IOUGEN,20,END=99) GSWGTU
CC      WRITE(IOUASK,20) GSWGTU
C
CC      WRITE (IOUASK,30)
CC30    FORMAT ('0', 'Enter sulfur weight percent of diesel fuel: ')
      READ(IOUGEN,20,END=99) DSWGTR
      WRITE(IOUASK,20) DSWGTR
C
CC      IF (GSWGTU.GT.1. .OR. GSWGTU.LT.0.) THEN
CC     WRITE(IOUERR,300) GSWGTU
CC     STOP 'Execution Terminated with Errors'
CC      ENDIF
C
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG
C
      IF (DSWGTR(1).GT.1. .OR. DSWGTR(1).LT.0.) THEN
       WRITE(IOUERR,300) DSWGTR(1)
       STOP 'Execution Terminated with Errors'
      ENDIF
      IF (DSWGTR(2).GT.1. .OR. DSWGTR(2).LT.0.) THEN
       WRITE(IOUERR,300) DSWGTR(2)
       STOP 'Execution Terminated with Errors'
      ENDIF
 300  FORMAT('ERROR:  ',F6.3,' is invalid input for the sulfur weight',
     *     ' percent.',/,8X,' The value must be between 0.0 and 1.0')
C
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG
C
 20   FORMAT(F6.4/F6.4/F6.4)
      RETURN
C
 99   WRITE(IOUERR,310)
 310  FORMAT('ERROR:  Premature end of file.  Trying to read:',/,
     *       8X,' Sulfur content of fuel')
      STOP 'Execution Terminated with Errors'
C
      END
      SUBROUTINE GETVER
C
C  GETVER reads in and validates the Control Section flags via the vertical
C  input mode: one flag per input line in I1 format.
C
C  Called by CONSEC.
C
C  Input on call:
C    common blocks:
C    /IOUCOM/ IOUGEN,IOUASK
C    /NAMES1/ NAMFLG(9)
C    /STRING/ COLON
C
C  Output on return:
C    common blocks:
C    /FLAGS1/ SPDFLG,VMFLAG
C    /FLAGS2/ MYMRFG,IMFLAG
C    /FLAGS3/ OUTFMT,RFGFLG
C    /FLAGS4/ SO2FLG,PRTFLG,IDLFLG,BUSFLG
C    /PROJEC/ PROJID
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  IFLAG     I   Array of flag inputs.  The actual flags are set equal to
C                the correct IFLAG element before leaving the subroutine.
C  IFLBND    I   The greatest possible input value for a flag.  This array
C                is of the same length of IFLAG.
C
C
C  Notes:
C
C  May-25-1993 @ ARC-bsg Subtask 248
C  Oct-13-1993 @ ARC-bsg Subtask 325 this must be I1 to work on MTS
C  Oct-29-1993 @ ARC-bsg Subtask 332 reinstated the driver that was removed by SAI
C  Feb-15-1994 @ CSC-bsg Request 394 SO2FLG
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  May-24-1994 @ CSC-bsg Request 434 Integration and regression testing
C  added bounds check IMFLAG=3 for no tampering option
C  25-May-1994 @ CSC-tmm Request 0-434 Added warning about registration
C  rates that get changed by NORMAL
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
C
C  Feb-15-1994 @ CSC-bsg Request 394 SO2FLG
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  Mar-23-1994 @ CSC-bsg Request 409 removal of SULFLG
C
      INTEGER IFLAG(9),IFLBND(9)
      DATA IFLBND/3,4,3,3,5,2,2,4,3/
C
      IF(IOUASK.EQ.IOUGEN) WRITE(IOUASK,200)
  200 FORMAT(' Enter project id: ')
      READ(IOUGEN,100) PROJID
      WRITE(IOUASK,210) PROJID
  100 FORMAT(A80)
  210 FORMAT(' ',A80)
C
C  Do the in-range check immediately after flag read, since if in interactive
C  mode, user can then receive out-of-range MESSAG immediately
C  after entering an erroneous flag value.
C  Feb-15-1994 @ CSC-bsg Request 394 SO2FLG
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C
      DO 50 IFL=1,9
       IF(IOUASK.EQ.IOUGEN) WRITE (IOUASK,211) NAMFLG(IFL),COLON
       READ (IOUGEN,110,END=99) IFLAG(IFL)
       IF(IOUASK.EQ.IOUGEN) WRITE (IOUASK,110) IFLAG(IFL)
       IF (IFLAG(IFL).LT.1.OR.IFLAG(IFL).GT.IFLBND(IFL)) THEN
	  WRITE(IOUERR,220) IFLAG(IFL),NAMFLG(IFL),IFLBND(IFL)
	  IFLAG(IFL) = 1
       ENDIF
 50   CONTINUE
C
C  Apr-11-1994 @ CSC-bsg Request 419 removed GETMIS and GETTAM subroutines
C
      VMFLAG = IFLAG(1)
      MYMRFG = IFLAG(2)
      IMFLAG = IFLAG(3)
C
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C
      RFGFLG = IFLAG(4)
      OUTFMT = IFLAG(5)
      IDLFLG = IFLAG(6)
C
C  Feb-15-1994 @ CSC-bsg Request 394 SO2FLG
C
      SO2FLG = IFLAG(7)
      PRTFLG = IFLAG(8)
      BUSFLG = IFLAG(9)
C
C  Oct-13-1993 @ ARC-bsg Subtask 325 this must be I1 to work on MTS
C
  110 FORMAT(I1)
  211 FORMAT(' ','Enter',T7,A8,T14,A1)
  220 FORMAT(' WARNING: ',I2,' is out of bounds for ',A8,
     *       '; the value must be between 1 and ',I1,'.  ',/,
     *       7X,' The flag value has been reset equal to 1')
C
C  25-May-1994 @ CSC-tmm Request 0-434 Added warning about registration
C  rates that get changed by NORMAL
C
      IF (MYMRFG.EQ.3.OR.MYMRFG.EQ.4) WRITE (IOUREP,221)
  221 FORMAT(' WARNING: According to historical records',/,
     *  10X,'there are no Class 2B Heavy Duty Diesel vehicles',/,
     *  10X,'for model years before 1981 or Light Heavy Duty',/,
     *  10X,'Diesel vehicles after 1976.  PART5 will always',/,
     *  10X,'assume 0.0 registration for these vehicles',/,
     *  10X,'during those periods.',/)
C
C
C   For now, allow PRTFLG to take values from 1-8:  This gives
C   support to printing a number of pollutant groups. (See OUTPOL)
C
      RETURN
C
C  EOF on any attempted read:
C
   99 WRITE(IOUERR,230) NAMFLG(IFL)
  230 FORMAT('ERROR:  premature end of file.  Trying to read ',A8//
     *'Excution terminated with errors'///)
      PAUSE 'Hit a key to continue'
      STOP
C
      END
      SUBROUTINE GETVMT
C
C  GETVMT gets the fleet vehicle miles travelled (vmt) mix by vehicle type.
C
C  Called by ONESEC and PARSEC.
C
C  Input on call:
C
C    common blocks:
C    /IOUCOM/ IOUGEN,IOUASK
C    /MAXIMA/ MAXVEH
C
C  Output on return:
C
C    common block: /VMXCOM/ VMTMIX
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  VMTCHK   R    vmt mix check: sum of the vmt fractions = 1.0 +/- 1.E-4
C                (i.e., a normalized vmt distribution has been entered)
C
C
C  Notes:
C  None.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'NAMES.INC'
C
      WRITE(IOUASK,200)
  200 FORMAT('0','Enter VMT split -- format 6(F6.4,1X)):',/)
      READ(IOUGEN,100,END=99) (VMTMIX(IV),IV=1,MAXVEH)
      WRITE(IOUASK,100) (VMTMIX(IV),IV=1,MAXVEH)
  100 FORMAT(6(F6.4,1X))
C
      VMTCHK=0.0
      DO 10 IV=1,MAXVEH
      VMTCHK=VMTMIX(IV)+VMTCHK
      IF(VMTMIX(IV).LT.0.0.OR.VMTMIX(IV).GT.1.) THEN
       WRITE(IOUERR,300) VMTMIX(IV),NAMVEH(IV)
       STOP 'Execution Terminated with Errors'
      ENDIF
 300  FORMAT('ERROR:  ',F6.4,' is invalid input for the VMT mix ',
     *         'for vehicle class ',A8,/,7X,' The input must be',
     *          ' between 0.0 and 1.0')
   10 CONTINUE
      IF(VMTCHK+1.E-4.LT.1..OR.VMTCHK-1.E-4.GT.1.) THEN
       WRITE(IOUERR,320) VMTCHK
       STOP 'Execution Terminated with Errors'
      ENDIF
 320  FORMAT('ERROR:  The VMT mix should sum to 1.0, but instead',
     *              ' it sums to ',F6.4)
C
      RETURN
C
C  EOF on any attempted read => run aborts.
C
   99 WRITE(IOUERR,350)
 350  FORMAT('ERROR:  Premature end of file.  Trying to read the VMT ',
     *            'mix')
      STOP
C
      END
