      SUBROUTINE CONSEC
C
C  CONSEC reads in and validates the Control Section flags.  It also sets the
C  input mode for the run, resets the output units (if requested) and reads in
C  and stores the run title.
C
C  Called by MAIN.
C
C  Calls GETIOU, GETVER, OUTHDR
C
C  Input on call:
C
C    common blocks:
C    /IOUCOM/ IOUGEN,IOUREP,IOUASK
C
C  Output on return:
C
C    common blocks:
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C
C  Notes:
C
C  CONSEC was modularized for PART, creating GETIOU, GETVER.
C
C
C  First pick up the I/O parameters (prompting or not, vertical or horizontal
C  control flag input, and alternate output units) and identify & assign (if
C  any) any allowable entered output units.
C
      CALL GETIOU
C
C  Ready to read in flags in either vertical mode.
C
      CALL GETVER
C
      CALL OUTHDR
C
C  1 or more flag values out of range => warn user & then stop run.
C
      RETURN
C
      END
      SUBROUTINE FDCALX(UNPVD,PAVED)
C
C  FDCALX is the routine for fugitive dust emission factors calcs.
C
C  Called by EFCALX
C
C  Calls none
C
C  Input on call: 
C
C  Output on return:  none
C    common blocks:
C    /BASEFD/ VEHWT,IVEHWL(12),IFAVWL,CUNPV2,CPAVE2
C    /SCENE1/ SPD,ISPDCY,UNSILT,PVSILT,IPDAYS
C
C  Notes:  Modified Sept'93
C          fugitive dust is calculated only for
C          paved and unpaved roads
C  Dec-1-1993 @ ARC-bsg Subtask 362 unpaved road calculation has been fixed
C  SAI sent this code 10-1993 with the number of wheels divided by four
C  "twice" this has been fixed to one time
C  Oct-28-1994 @ CSC-ked Subtask 474 (PART5 Fugitive Dust Reformatting)
C  Replace 12 vehicle class weights and wheels with one 'Fleet average vehicle
C  wt.' and 'Fleet average vehicle wheels' by calling FDCALX once from PART5.
C  Jan-26-1995 @ CSC-ked Subtask 484 (PART5 Output)  Add calculation for CUNPV2
C  and CPAVE2.
C
      REAL WEIGHT,LBSTOG,PIPE80,TIRE80
      INCLUDE 'PARAM.INC'
      INCLUDE 'BASEFD.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'PSIZE.INC'
C
C     Tailpipe emission (Exhaust PM) from 1980 calendar year:
C
      PIPE80 = 0.195
C
C     Tire-wear emission (Tire) from 1980 calendar year:
C
      TIRE80 = 0.009
C
C     The conversion factor to convert pounds to grams:
      LBSTOG = 453.592
C
C  For each vehicle model year for unpaved roads and paved roads.
C
      WEIGHT=FLOAT(USRWT)/2000.
      VWHEEL=FLOAT(IFAVWL)
C
C     Unpaved road:
C
      C1=(PSDUNP*5.9)*(UNSILT/12.0)*(SPD/30.0)
      C2=FLOAT(365-IPDAYS)/FLOAT(365)
      UNPVD=C1*((WEIGHT/3.0)**0.7)*((VWHEEL/4.)**0.5)*C2
C
      UNPVD=UNPVD*LBSTOG
C
C     Unpaved road as calculated in AP42 Vol 1 9/88, minus tailpipe and
C     tire-wear emissions from 1980 calendar year.
C
      CUNPV2=UNPVD - PIPE80 - TIRE80
C
C     Paved road:
C
      PAVED=PSDPVD*((PVSILT/2)**(0.65))*((WEIGHT/3)**(1.5))
C
C     Paved road as calculated in AP42 Vol 1 3/93, minus tailpipe and
C     tire-wear emissions from 1980 calendar year.
C
      CPAVE2=PAVED - PIPE80 - TIRE80
C
      RETURN
      END
      REAL FUNCTION FLECON(MY,IV)
C
C  GETFLEC gets the fuel economy
C
C  Called by GASSLF LEADED UNLDED
C
C    common blocks:
C     /RLCOM1/ ROADFE(32,5)
C
C  Output on return:
C     FLECON
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------------
C  MY       I    Model year
C  MDX      I    Model year index mapping to Model year(MY) for ROADFE
C
C  Notes:
C    none.
C
C
      INCLUDE 'ROADFE.INC'
C
C  For each Vehicle Type select the corresponding MDX to MY for ROADFE
C
      IF(IV .EQ. 5) THEN
	 MDX=MY-1976+1
	 IF (MDX .GT. 12) MDX=12
      ELSE
	 MDX=MY-1969+1
	 IF(MDX .GT. 32) MDX=32
      ENDIF
      IF (MDX .LT. 1) MDX=1
C
      FLECON = ROADFE(MDX,IV)
C
      RETURN
      END
      REAL FUNCTION GASORG(IV, ICAT, CARBON)
C
C     This subroutine finds the soluble organic fraction of the
C     exhausted carbon PM for gasoline fueled vehicles
C
C     Called by: EFCALX
C
C     Calls: none
C
C     Output on Return:   GASORG = soluble organic fraction
C
C     Common Blocks: /EFPMC/:
C
C     Notes:
C
      INCLUDE 'EFGAS.INC'
C
C
      GASORG = 0.0
C
      FRACT = SOFFRC(ICAT,IV)
C
      GASORG = FRACT*CARBON
C
      RETURN
      END
      SUBROUTINE HDDMYM(ICY)
C
C  HDDMYM computes annual weighted calendar year mileage for BUS.
C  HDDMYM also sets annual year mileage for the 4 classes of HDDVs.
C
C  Called by REGMOD.
C
C  Input on call:
C
C    parameter list: ICY
C    common blocks:
C    /HDDMAR/ C2BDVM,LHDVM,MHDVM,HHDVM
C    /HDDREG/ C2BDRG,LHDRG,MHDRG,HHDRG
C    /BUSMAR/ TRANVM,COMMVM,SCHLVM
C    /BUSREG/ TRANRG,COMMRG,SCHLRG
C
C    common block: /MYRSAV/ AMAR,NEWCUM
C
C  Notes:
C
C  none
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'HDFLEET.INC'
C
C
C  Set annual mileage distribution for each class of HDDV.
C
      DO 10 JDX=1,MAXYRS
      AMAR(JDX,8)=C2BDVM(JDX)
      AMAR(JDX,9)=LHDVM(JDX)
      AMAR(JDX,10)=MHDVM(JDX)
      AMAR(JDX,11)=HHDVM(JDX)
   10 CONTINUE
C
C Determine pointer KDX.  KDX=1 for 1962-, 2 for 1963,
C 3 for 1964, ..., 26 for 1987+
C
      KDX = ICY - 1961
      IF (KDX.LT.1) KDX = 1
      IF (KDX.GT.26) KDX = 26
C
C Compute registration weighted annual mileage distribution for BUS
C
      DO 20 JDX=1,MAXYRS
      AMAR(JDX,12) = (TRANRG(KDX)*TRANVM(JDX) +
     *   COMMRG(KDX)*COMMVM(JDX) + SCHLRG(KDX)*SCHLVM(JDX))
     *   / (TRANRG(KDX) + COMMRG(KDX) + SCHLRG(KDX))
   20 CONTINUE
C
C  Set flag so that model year mileage is recalculated in EFCALX.
C
      NEWCUM=1
      RETURN
      END
      FUNCTION IGSFPT(MY,IV)
C
C  IGSFPT selects the pointer to the gas/diesel sales fractions.
C
C  Called by EFCALX, and REGMOD.
C
C  Input on call:
C
C    parameter list: MY,IV
C    common blocks:
C    /GSFCOM/ MAXGSF,MYGSF
C    /REGION/ IREJN
C
C  Output on return:
C
C    function: IGSFPT
C
C  Notes:
C
C  none
C
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'GSFCOM.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'SCENE.INC'
C
C
      DO 10 IG=1,MAXGSF
      IF (MYGSF(IG,IV,IREJN).GT.0.) IGG = IG
      IF(MY.LE.MYGSF(IG,IV,IREJN)) GOTO 20
   10 CONTINUE
C
C  Set default for case where MY exceeds highest yr in MYGSF, given IV & IREJN.
C
      IG=IGG
      WRITE(IOUERR,300)
 300  FORMAT('WARNING:  Model year exceeds highest year in the ',
     *       'gasoline sales fraction data for vehicle class ',A8,/,
     *       7X,' The sales fraction for latest year has been used.')
      RETURN
C
   20 IGSFPT=IG
C
      RETURN
      END
      FUNCTION IPBFUN(ICY)
C
C  IPBFUN selects pointer index(IPTR) for Lead content of gas by calendar
C  year(PB).
C
C  Called by  EFCALX
C
C  Calls none.
C
C  Input on call:
C
C    parameter list: ICY
C    common block: /LEDCOM/ IYRPB
C
C  Output on return:
C    function: IPBFUN
C
C  Local variable dictionary:
C
C  Name    Type              Description
C  ------  ----  -------------------------------------------------------------
C  IPTR     I    Pointer index for Lead content of gas by calendar year
C
C  Notes: none.
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'LEAD.INC'
C
      DO 10 IPTR=1,22
      IF(ICY .LE. IYRPB(IPTR)) GOTO 90
10    CONTINUE
C
90    IPBFUN=IPTR
CC    IG=2
CC    IVA=2
CC    IMFLAG=1
CC    ZML1 = TAMRAT(IMFLAG,1,IG,IVA,1) 
CC    DR1 =  TAMRAT(IMFLAG,2,IG,IVA,1)
CC    SR1 = TAMRAT(IMFLAG,3,IG,IVA,1)
CC    WRITE(28,201) ZML1,DR1,SR1,ICY
CC201 FORMAT('IMFLAG=1: ZML,DR,SR,ICY',3F9.6,I5)
CC    IMFLAG=2
CC    ZML2 = TAMRAT(IMFLAG,1,IG,IVA,1) 
CC    DR2 =  TAMRAT(IMFLAG,2,IG,IVA,1)
CC    SR2 = TAMRAT(IMFLAG,3,IG,IVA,1)
CC    WRITE(28,202) ZML2,DR2,SR2
CC202 FORMAT('IMFLAG=2: ZML,DR,SR',3F9.6/)
      RETURN
      END
      FUNCTION EFLEAD(MY,ICY,IV)
C
C  LEADED calculates Lead Particulate Emission Factors
C
C  Called by EFCALX.
C
C  Calls LEADED, LEDPTR, and TAMPER.
C
C  Input on call:
C
C    parameter list: MY, ICY, IV
C
C    common blocks:
C
C  Output on return: LEADP
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------------
C  IV       I    Vehicle type
C  MY       I    Model year
C  IYPT     I    Discretionary fuel switching index variable
C  IFRAC    I    model year pointer to obtain CTLFRC from common array FRACA
C  PLNOCT   R    Particulate emission factor for non-catalyst vehicles
C                using leaded fuel
C  PUNOCT   R    Particulate emission factor for non-catalyst vehicles
C                using unleaded fuel
C  PLYSCT   R    Particulate emission factor for catalyst equipped
C                vehicles using leaded fuel
C  PUYSCT   R    Particulate emission factor for catalyst equipped
C                vehicles using unleaded fuel
C  VLNOCT   R    Number of non-catalyst vehicles
C                using leaded fuel
C  VUNOCT   R    Number of non-catalyst vehicles
C                using unleaded fuel
C  VLYSCT   R    Number of catalyst equipped
C                vehicles using leaded fuel
C  VUYSCT   R    Number of catalyst equipped
C                vehicles using unleaded fuel
C
C
C  Notes:
C  Mar-4-1994 @ CSC-bsg Request 340 this was added to overhaul
C  lead emission factor calculation
C  Jun-17-1994 @ CSC-bsg Request 430 MC use lead instead of gas carbon
C  Jun-24-1994 @ CSC-bsg Request 430 MC use lead and carbon
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'DFSBLK.INC'
      INCLUDE 'LEAD.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'PSIZE.INC'
      INCLUDE 'FRACT.INC'
C
      EFLEAD = 0.0
C
C  skip Diesels.
C
      IF(IV.GT.5) RETURN
C
C  determine the lead particulate emission rates
C
      CALL LEADED(MY,ICY,IV,PLNOCT,PUNOCT,PLYSCT,PUYSCT)
C
C  Jun-24-1994 @ CSC-bsg Request 430 MC use lead and carbon
C
      IF(IV.EQ.5) THEN
	EFLEAD = PLNOCT + PUNOCT + PLYSCT + PUYSCT
	RETURN
      ENDIF
C
      IF (MY.LT.1968) THEN
	  IFRAC = 1
      ELSE IF (MY.GE.1968.AND.MY.LE.1971) THEN
	  IFRAC = 2
      ELSE IF (MY.LE.1991) THEN
	  IFRAC = 3 + (MY - 1972)
      ELSE
	  IFRAC = 22
      ENDIF
C
C  Get the catalyst fraction of the gasoline vehicle population.
C
      CATFCT = FRACA(IFRAC,1,IV)+FRACA(IFRAC,2,IV)+
     2         FRACA(IFRAC,3,IV)+FRACA(IFRAC,4,IV)
C
C  determine discretionary fuel switching index variable.
C
      CALL LEDPTR(IYPT,IV,MY)
C
C  determine the tampering and misfueling rates.
C
      CALL TAMPER(ICY,MY,IV,TAMFRC,RMIS)
C
C  determine the fraction of all vehicles which
C  have NOT had the catalyst removed.
C
      CATS = CATFCT * (1.-TAMFRC)
C
C  determine the fraction of all vehicles which are
C  non-catalyst vehicles fueled with leaded gasoline.
C
      VLNOCT = (1.-CATS) * (1.-DFS(IYPT,IV))
C
C  determine the fraction of all vehicles which are
C  non-catalyst vehicles fueled with unleaded gasoline.
C
      VUNOCT = (1.-CATS) * DFS(IYPT,IV)
C
C  determine the fraction of all vehicles which are
C  catalyst equipped vehicles fueled with leaded gasoline.
C
      VLYSCT = CATFCT * (RMIS - TAMFRC)
C
C  determine the fraction of all vehicles which are
C  catalyst equipped vehicles fueled with unleaded gasoline.
C
      VUYSCT = (1.-VLNOCT-VUNOCT-VLYSCT)
C
C  determine the combined lead particulate emission factor
C
      EFLDRT =
     &        PLNOCT * VLNOCT
     &      + PUNOCT * VUNOCT
     &      + PLYSCT * VLYSCT
     &      + PUYSCT * VUYSCT
      EFLEAD = EFLDRT
CC    IF( (MY.EQ.1990.AND.ICY.EQ.1998).OR.(MY.EQ.1970.AND.ICY.EQ.1980))
CC   *THEN
CC      IF(IV.EQ.4.AND.ICY.EQ.1985) THEN
CC      WRITE(12,201) IV,MY,IFRAC,ICY,IYPT
CC      WRITE(12,202) CATFCT,RMIS,TAMFRC,CATS,DFS(IYPT,IV)
CC      WRITE(12,203)
CC     *PLNOCT,VLNOCT,PUNOCT,VUNOCT,PLYSCT,VLYSCT,PUYSCT,VUYSCT,EFLDRT
CC      ENDIF
CC  201 FORMAT(' IV  MY IFRAC ICY IYPT '/1X,5I5)
CC  202 FORMAT('CATFCT RMIS TAMFRC CATS DFS(IYPT,IV)'
CC     */1X,6(F5.3,1X))
CC  203 FORMAT(
CC     *' PLNOCT VLNOCT PUNOCT VUNOCT PLYSCT VLYSCT PUYSCT VUYSCT ',
CC     *'EFLEAD'/
CC     *1X,4(F7.3,1X,F7.5,1X),F7.4)
      RETURN
      END
      SUBROUTINE LEADED(MY,ICY,IV,PLNOCT,PUNOCT,PLYSCT,PUYSCT)
C
C  LEADED calculates Lead Particulate Emission Factors
C
C  Called by EFCALX.
C
C  Calls IPBFUN.
C
C  Input on call:
C    parameter list: MY, ICY, IV
C    common blocks:
C     /PSIZE/ PSL, PSNL, PSNLCT
C     /DFSBLK/ ABURN
C     /LEDCOM/ PB
C              FLECON
C
C  Output on return:
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------------
C  FECONM   R    Vehicle fuel economy (units?)
C  IPBPTR   I    Index for fuel lead content by calendar year
C  IV       I    Vehicle type
C  JDX      I    Model year window index (age)
C  MY       I    Model year
C  PBL      R    Lead content of leaded fuel
C  PBNL     R    Lead content of unleaded fuel
C  PLNOCT   R    Particulate emission factor for non-catalyst vehicles
C                using leaded fuel
C  PUNOCT   R    Particulate emission factor for non-catalyst vehicles
C                using unleaded fuel
C  PLYSCT   R    Particulate emission factor for catalyst equipped
C                vehicles using leaded fuel
C  PUYSCT   R    Particulate emission factor for catalyst equipped
C                vehicles using unleaded fuel
C
C
C  Notes:
C  11-29-93 @ ARC-bsg Subtask 340  Replaced incorrect value with correct value
C  of PbClBr mass to Pb mass.  Also fixed implementation of DFS value to read
C  the way the comments say they do and they way the EPA documentation reads
C  this will fix errors in SAI code delivered 10-22-93
C  Mar-4-1994 @ CSC-bsg Request 340 this new routine was added to overhaul
C  calculation of lead emission factors formulas
C  Jun-24-1994 @ CSC-bsg Request 430 MC use lead and carbon
C  Jul-22-1994 @ CSC-bsg Fixed mistake in derivation of catalyst lead EF
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'DFSBLK.INC'
      INCLUDE 'LEAD.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'PSIZE.INC'
C
C  Skip Diesels.
C
      IF(IV.GT.5) RETURN
      PLNOCT=0.0
      PUNOCT=0.0
      PLYSCT=0.0
      PUYSCT=0.0
C
C     function to find the pointer index for Lead content of Gas(g/m)
C     by calendar year.
C
      IPBPTR = IPBFUN(ICY)
C
C     get the lead content of fuel:
C
      PBL    = PB(IPBPTR,1)
      PBNL   = PB(IPBPTR,2)
C
C  Jun-24-1994 @ CSC-bsg Request 430 changed MC calculation
C
      IF(IV.EQ.5.AND.MY.LE.1978) THEN
	PLNOCT=(0.49*0.100+0.51*0.014)*PSL*PBL*0.5
	RETURN
      ELSEIF(IV.EQ.5.AND.MY.GT.1978) THEN
	PLNOCT=0.014*PSL*PBL*0.5
	RETURN
      ENDIF
C
C     for each Vehicle Type get the corresponding fuel economy
C
      FECONM = FLECON(MY,IV)
C
C     Partical weight ratios:
C     1.557  = PbClBr / Pb
C
C     determine the lead particulate emission factor
C     for non-catalyst vehicles using leaded fuel
C
      PLNOCT = ((ABURN(1)*1.557)/FECONM) * PBL * PSL
C
C     determine the lead particulate emission factor
C     for non-catalyst vehicles using unleaded fuel
C
      PUNOCT = ((ABURN(1)*1.557)/FECONM) * PBNL * PSNL
C
C  Jul-22-1994 @ CSC-bsg Fixed mistake in derivation of catalyst lead EF
C     determine the lead particulate emission factor
C     for catalyst equipped vehicles using leaded fuel
C
      PLYSCT = ((ABURN(1)*1.557)/FECONM) * PBL * PSL
C
C  Jul-22-1994 @ CSC-bsg Fixed mistake in derivation of catalyst lead EF
C     determine the lead particulate emission factor
C     for catalyst equipped vehicles using unleaded fuel
C
      IF(MY .LT. 1981) THEN
	PUYSCT = ((ABURN(2)*1.557)/FECONM) * PBNL * PSNLCT
      ELSE
	PUYSCT = ((ABURN(3)*1.557)/FECONM) * PBNL * PSNLCT
      ENDIF
C
      RETURN
      END
      SUBROUTINE LEDPTR(IYPT, IV, MY)
C
C  LEDPTR selects index pointers for Base Lead Emission Rates(DFS) and
C  Sales Fractions for Leaded Fuel Vehicles(PBFRAC).
C
C  Called by LEADED and UNLDED.
C
C  Calls none.
C
C  Input on call:
C
C    parameter list: IYPT, IV, MY
C    common blocks:
C    /DFSBLK/ MYLEAD, MAXLED
C
C  Output on return:
C
C    parameter list: IYPT
C
C  Notes: 5-31-94 @ CSC-bsg Request 434 Integration and regression testing
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'DFSBLK.INC'
      INCLUDE 'LEAD.INC'
C
C  Select pointer index(IYPT) for Base Lead Emission Rates(DFS)
C
      DO 10 IYPT=1, MAXLED
      IF(MY .LE. MYLEAD(IYPT,IV)) GOTO 90
10    CONTINUE
C
90    RETURN
      END
      SUBROUTINE NORMAL(ICY)
C
C  NORMAL normalizes the registration distributions.
C
C  Called by PARSEC.
C
C  Input on call:
C
C    common blocks:
C    /JULREG/ JULORG(25,12)
C    /FLAGS2/ MYMRFG
C    /MAXIMA/ MAXVEH,MAXYRS
C    /MYRSAV/ AMAR(25,12),JULMYR(25,12)
C
C  Output on return:
C
C    common blocks:
C    /MYRSAV/ AMAR,JULMYR
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  SUMMYR   R    sum of myr for IV; used to normalize user entered JULMYR
C  SUM8     R    sum of 2BHDDV distributions over all 25 years
C  SUM9     R    sum of LHDDV distributions over all 25 years
C
C  Notes:
C     JULORG was added in order to keep the original registributions so that
C     the july registributions could be renormalized for every scene
C     simulated.  The renormalizations are done to reflect zero 2BHDDV's
C     before 1981 and zero LHDDV's after 1976.
C  25-May-1994 @ CSC-tmm Request 0-434  Deleted IF that was around two
C  blocks of code
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'FLAGS.INC'
C
C  25-May-1994 @ CSC-tmm Request 0-434  Deleted IF that was around these
C  next two blocks of code
C
      IF (MYMRFG .EQ. 1 .OR. MYMRFG .EQ. 2) THEN
	DO 2 IV=1,MAXVEH
	  DO 2 JDX=1,MAXYRS
	    JULMYR(JDX,IV) = JULORG(JDX,IV)
 2      CONTINUE
      ENDIF
C
C     Multiply the vehicle classes 2BHDDV and LHDDV by zero for the years
C     in which there are no vehicles,i.e. no 2BHDDV's until 1981, and
C     no LHDDV's after 1977.
C
      SUM8 = 0.
      SUM9 = 0.
      DO 5 JDX=1,MAXYRS
	IYEAR = ICY - JDX + 1
	IF (IYEAR.LT.1981) JULMYR(JDX,8)=0.
	IF (IYEAR.GT.1976) JULMYR(JDX,9)=0.
	SUM8 = SUM8 + JULMYR(JDX,8)
	SUM9 = SUM9 + JULMYR(JDX,9)
 5    CONTINUE
      DO 6 JDX=1,MAXYRS
	IF (SUM8.GT.0.) JULMYR(JDX,8) = JULMYR(JDX,8)/SUM8
	IF (SUM9.GT.0.) JULMYR(JDX,9) = JULMYR(JDX,9)/SUM9
 6    CONTINUE
C
C  Normalize JULMYR.
C
      DO 75 IV=1,MAXVEH
	 SUMMYR=0.0
	 DO 70 JDX=1,MAXYRS
	    SUMMYR=JULMYR(JDX,IV)+SUMMYR
   70    CONTINUE
	 IF(SUMMYR.EQ.0.0) RETURN
	 DO 75 JDX=1,MAXYRS
	    JULMYR(JDX,IV)=JULMYR(JDX,IV)/SUMMYR
   75 CONTINUE
C
      RETURN
      END
      SUBROUTINE OBYHDR
C
C  OBYHDR writes the By Model Year Tables page header ( = run + scenario titles)
C  on unit IOUOUT.
C
C  Called by OUTDT5.
C
C  Calls OUTHDR
C
C  Input on call:
C
C    parameter list: IOUOUT
C    common blocks:
C    /CITPAR/ SCNAME
C    /PROJEC/ PROJID
C
C  Notes:
C  (1) OBYHDR was added for OUTFMT=5
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'RESULT.INC'
      INCLUDE 'SCENE.INC'
C
      CALL OUTHDR
C
      WRITE(IOUREP,210) SCNAME
  210 FORMAT(' ',8A4)
C
      WRITE(IOUREP,220)
 220  FORMAT(1X,'Emission Factors (Gm/Mile)')
C
      RETURN
      END
      SUBROUTINE ONESEC
C
C  ONESEC checks if control flags indicate One-time Data. It then reads in,
C  validates, and stores the data.
C
C  Called by MAIN.
C
C  Calls  GETVMT, GETLED, GETSLF, GETBYM
C
C  Input on call:
C
C    common blocks:
C     COMMON /FLAGS1/ TAMFLG,VMFLAG
C     COMMON /FLAGS2/ MISFLG
C     COMMON /FLAGS3/ OUTFMT,RFGFLG
C
C  Output on return:
C
C
C  Notes:
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG
C  Apr-11-1994 @ CSC-bsg Request 419 removed GETTAM and GETMIS
C
C
      INCLUDE 'FLAGS.INC'
C
C  Check for user supplied vmt mix to be used for all scenarios of this run.
C
      IF(VMFLAG.EQ.3) CALL GETVMT
C
C  Optionally read in and screen model year mileage accrual rates and / or
C  registration distributions.  In all cases, normalize the distributions.
C
      IF (MYMRFG.GT.1) CALL GETMRN
C
C  Mar-22-1994 @ CSC-bsg  Request 409 Changed SULFLG to RFGFLG
C  Get the user supplied sulfur content of diesel fuel for 3 cy groups:
C
      IF(RFGFLG.EQ.3) CALL GETSLF
C
C  If the user asks for by model year emission factor results tables, find
C  out which tables are to be printed.
C
      IF(OUTFMT.EQ.5) CALL GETBYM
C
C  Normal return: Either there are no one-time data errors ( => + no other
C  errors => evaluate scenarios) OR there are errors ( => check for errors,
C  but do not process the scenario(s) or + number of errors > 50 =>
C  terminate the run).
C
      RETURN
C
C  EOF on any attempted read => take alternate return 1 => run aborts.
C
      END
      SUBROUTINE PARSEC(ICY)
C
C  PARSEC reads in the Parameter Section variables and validates them.
C
C  Notes:
C
C  16-Jan-1995 @ CSC/ked Request 4-483 (VMT/Mil.Accu)  Add check for VMTMIX
C  <> 0 when VMT is user-supplied and calendar year is > 2000
C
C
C  Called by MAIN.
C
C  Calls GETSC1, GETMRN, GETVMT, PARSIZ
C
C  Input on call:
C
C    common blocks:
C     /FLAGS1/ VMFLAG
C     /IOUCOM/ IOUERR
C     /VMXCOM/ VMTMIX(MAXVEH)
C
C  Output on return: ICY
C
      INCLUDE 'FLAGS.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'PARAM.INC'
      INCLUDE 'REGIS.INC'
C
C  PARSEC is called once for each scenario of the run.
C
C  Get the first required scenario record.
C
      CALL GETSC1(ICY)
C
C  Normalize the registration distributions.
C
      CALL NORMAL(ICY)
C
      CALL PARSIZ
C
C  Check for user supplied vmt mix to be used for this scenario only.
C
      IF(VMFLAG.EQ.2) CALL GETVMT
C
C  Stop processing for ICY > 2000 and VMFLAG > 1 and VMTMIX(9) <> 0
C  because there are no LHDDV's after the year 2000.
C
      IF (ICY.GT.2000 .AND. VMFLAG.GT.1 .AND. VMTMIX(9).NE.0.0) THEN
	 WRITE (IOUERR,100)
  100    FORMAT (' ERROR:  The VMT mix for vehicle class 9',
     *           ' must equal zero for processing of',/,' calendar ',
     *           'years greater than 2000 because there are no ',
     *           'LHDDV''s.')
	 STOP
      ENDIF
C
      RETURN
C
      END
      SUBROUTINE PARSIZ
C
C     This subroutine computes the fraction of particles less than
C     or equal to the particle size cutoff input by the user, PSZCUT.
C
C     Called by:  PARSEC
C
C     Calls: none
C
C     Input on call:
C     /PSIZE/ PSZCUT
C     /PSBLK/ PSDIST(5,2,8)
C
C     Output on return:
C     /PSIZE/ PSL, PSNL, PSNLCT, PSDIE, PSBRK, PSTIRE
C     /PSDUST/ PSDUNP,PSDPVD
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  MXDATA   I     The maximum number of size bins for the array PSDIST
C  MXSRCE   I     The maximum number of categories of sources of PM in
C                    the array PSDIST.
C  PSCALC   R     The minimum PS cut off for fugitive dust is now 2.5
C
C
C  Notes:
C  There are six categories of sources:
C
C          PSL         fraction for leaded gasoline
C          PSNLCT      fraction for unleaded gasoline, Catalyst
C          PSNL        fraction for unleaded gasoline, no Catalyst
C          PSDIE       fraction for diesel fuel
C          PSBRK       fraction for break wear
C          PSTIRE      fraction for tire wear
C          PSDUNP      fraction for unpaved road dust
C          PSDPVD      linear interpolation of base emission
C                      factor (g/VMT)
C
C     The fractions are linearly interpolated from the data in psdist,
C
C          PSDIST=PSDIST(ipts,I, categorie)
C     where
C          ipts = the number of particle sizes for which there is
C                 data about the fraction of total particles less
C                 than or equal to those sizes (MXDATA=5)
C          I = 1  corresponds to the particle size
C          I = 2  corresponds to the fraction of particles less than or
C                 equal to that size
C          categorie = the source categorie, i.e. the same six listed
C                 above in the same order.
C
C
C  Jul-21-1994 @ CSC-bsg Changes output of fugitive dust to reflect
C  the new lower limit of Particle Size Cutoff if less than 2.5
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'LEAD.INC'
      INCLUDE 'PSIZE.INC'
C
      DATA MXDATA /5/
      DATA MXSRCE /8/
C
      DO 50 ISRC = 1, MXSRCE
	 PSCALC=PSZCUT
	 IF(ISRC.GE.7) THEN
	   IF(PSZCUT.LT.2.5) PSCALC=2.5
	 ENDIF
	 PS = 0.0
C
	 IF (PSZCUT .LE. PSDIST(1,1,ISRC)) THEN
	    SLOPE = (PSDIST(2,2,ISRC) - PSDIST(1,2,ISRC)) /
     *              (PSDIST(2,1,ISRC) - PSDIST(1,1,ISRC))
	    PS = PSDIST(1,2,ISRC) - SLOPE * (PSDIST(1,1,ISRC) - PSCALC)
	 ELSE
	    DO 10 IDATA = 1, MXDATA
	       SLOPE = 0.0
	       NPTR = 1
	       MXSIZE = MXDATA
	       DO 5 I = 2, MXDATA
		  IF (PSDIST(I,1,ISRC).EQ.0.0 .AND.
     *                       PSDIST(I-1,1,ISRC).GT.0.) MXSIZE = I-1
5              CONTINUE
	       DO 20 I = 2, MXSIZE
		  IF (PSDIST(I,1,ISRC) .GE. PSCALC) THEN
		     NPTR = I
		     GO TO 30
		  ENDIF
   20          CONTINUE
   30          SLOPE = (PSDIST(NPTR,2,ISRC) - PSDIST(NPTR-1,2,ISRC)) /
     *                 (PSDIST(NPTR,1,ISRC) - PSDIST(NPTR-1,1,ISRC))
	       PS = SLOPE*(PSCALC - PSDIST(NPTR-1,1,ISRC)) +
     *                              PSDIST(NPTR-1,2,ISRC)
10          CONTINUE
	 ENDIF
C
	 IF (ISRC .EQ. 1) PSL = PS
	 IF (ISRC .EQ. 2) PSNLCT = PS
	 IF (ISRC .EQ. 3) PSNL = PS
	 IF (ISRC .EQ. 4) PSDIE = PS
	 IF (ISRC .EQ. 5) PSBRK = PS
	 IF (ISRC .EQ. 6) PSTIRE = PS
	 IF (ISRC. EQ. 7) PSDUNP = PS
	 IF (ISRC. EQ. 8) PSDPVD = PS
C
   50 CONTINUE
C
      RETURN
      END
      PROGRAM PART5
C  Feb-23-1995 @ CSC-wcs Subtask 484 (PART5 Output)  Fix scenario loop so that
C  32767 scenarios can be run instead of just a hundred.
C  Jul-29-1994 @ CSC-bsg Request 434 Changed the Unpaved Dust to one decimal 
C      place after the decimal point for OUTFMT=2
C  Jul-29-1994 @ CSC-bsg Request 434 Modified Idle Output to include extra
C      Bus Categories with the same EF as Regular Buses
C  Jul-29-1995 @ CSC-bsg Request 434 Discovered that extra Bus Categories
C      should be a correction factor adjustment from regular bus EF for 
C      direct sulfates.
C  Jul-27-1994 @ CSC-bsg Request 434 Discovered total Sulfate PM should be
C      the sum of indirect and direct sulfate
C  Jul-25-1994 @ CSC-bsg Request 434 adding the wheel flag to indicate
C      and process user input for number of wheels
C  Jul-29-1994 @ CSC-bsg Request 434 Changed the Unpaved Dust to one decimal 
C      place after the decimal point for OUTFMT=1
C  Jul-22-1994 @ CSC-tmm Request 434 Added PRTFLG=3 with new pollutants printed
C  Jul-22-1994 @ CSC-bsg Fixed mistake in derivation of catalyst lead EF
C  Jul-21-1994 @ CSC-bsg Changed particle size cut off for fugitive dust to
C      be a minimum of 2.5 and non-dust to have a minimum of 1.0
C  Jul-21-1994 @ CSC-bsg Changed block data LDDV/T emission values and IDIEYR
C      values to take pre-control standards into account
C  Jul-6-1994 @ CSC-bsg Made Idle EF backout sulfur calculations
C      added ICY to parameter list to determine if low sulfur weight is used
C  Jul-1-1994 @ CSC-bsg Request 447 Investigate graphical trends in the
C      particulate model by comparing IMFLAG=1 to IMFLAG=2 for various 
C      calendar years.  Discovered a mistake with HDGV DFS rate.
C      Discovered a mistake with the tampering rates block data.
C  Jun-24-1994 @ CSC-bsg Request 430 MC use lead and carbon
C  Jun-22-1994 @ CSC-bsg Request 429 Changed block data LDDV/T emission values
C      increased array size of IDIEYR and EFDPM to include new LDDV/T standards.
C  Jun-21-1994 @ CSC-bsg Request 449 silt content in the printout to have enough
C      significant digits so that 0.02 is reported instead of 0.0 in the echo.
C      Same problem with VMT mix, three significant digits printed, 4 read in.
C  Jun-7-1994 @ CSC-bsg Request 443 changed bus category exhaust particulate
C      default no trap rates for model years 1992 and later due to standard
C      changes.  Changed other heavy duty rates for 1994 and later due to a
C      better prediction of new technology
C      check trap flag and use alternative emission values and weight them 
C      together with user supplied trap pct. only use block data when not a 
C      bus
C  Jun-2-1994 @ CSC-tmm Request 443 user defined bus trap input
C  May-31-1994 @ CSC-bsg Request 434 Regression and integration testing
C      take out dead code, LEDPTR, BLOCK DATA BD02 parts are unused
C      zero out DSULF for 2BHDDV for model years less than 1981 and LHDDV
C      for model years greater than 1976.  This makes for consistancy with
C      the effects of the NORMAL module.
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C      for OUTFMT=5
C  May-25-1994 @ CSC-tmm Request 0-434 Added warning about registration
C      rates that get changed by NORMAL.
C  May-25-1994 @ CSC-tmm Request 0-434  Deleted IF that was around two
C      blocks of code in NORMAL.
C  May-24-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C      for OUTFMT=3
C  May-13-1994 @ CSC-bsg Request 430 Changed block data for emission values
C      added the FRACTS subroutine to change exhaust particulates for
C      gasoline vehicles
C  May-12-1994 @ CSC-bsg Request 428 Changed block data content of lead in
C      gasoline fuel
C  Apr-12-1994 @ CSC-bsg Request 419 made PART5 like MOBILE5a with respect
C      to the tampering rates of catalyst removal and misfueling removed
C      tampering and misfueling as user inputs also removed sulfur fuel
C      as a user supplied input message, this undoes most of request 380.
C  Apr-7-1994 @ CSC-bsg Request 418 removed particles size from sulfur
C      calculations.
C  Apr-7-1994 @ CSC-bsg Request 417 modified diesel calculations to take into
C      account the effect of low sulfur weight ratio effects.
C  Apr-5-1994 @ CSC-bsg Request 415 Exhaust Particulate EF
C  Mar-29-1994 @ CSC-bsg Request 398 Add bus categories as output
C  Mar-28-1994 @ CSC-bsg Request 410 There is no reliable data to support
C      a soluble organic fraction for gasoline vehicles at this date.
C  Mar-23-1994 @ CSC-bsg Request 409 Add RFG output echo in header.
C      Changed SULFLG to RFGFLG.
C  Mar-18-1994 @ CSC-bsg Request 408 Exhaust Particulate Base numbers
C      Added a pointer into the EFPM array.
C  Mar-18-1994 @ CSC-bsg Request 406 Simplified terms in equation to
C      avoid confusion (CDSULF=DSULF=SSULF).  Applied maximum function to
C      ensure that CSOF and CRCP are non-negative numbers and added the
C      application of the amax function to cpm10 to ensure the breakdown
C      of all pollutants sum to the total exhaust PM
C  Mar-15-1994 @ CSC-bsg Request 407 Change the fuel density for both
C       gasoline and diesel fuels.
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C       this should not be a user input
C  Mar-10-1994 @ CSC-bsg Request 401  changed application of diesel sulfur
C       sulfur weight percent ratio to be like gasoline
C  Mar-10-1994 @ CSC-bsg Request 403 Created this from OUTDT3 to modularize
C       BUSFLG
C  Mar-9-1994 @ CSC-bsg Request 402 Change Sulfate calculation to include
C       DFS term
C  Mar-9-1994 @ CSC-bsg Request 401  Add user input variables for
C       sulfur weight percent for gasoline and diesel fuel or default values
C  Mar-7-1994 @ CSC-bsg Request 394 SO2FLG
C  Mar-4-1994 @ CSC-bsg Request 340 replaced original call to lead with
C       EFLEAD function that overhauls all lead formulas.
C  Feb-23-1994 @ CSC-bsg Request 397 add in paved dust for all vehicle
C  Jan-31-1994 @ CSC-bsg Request 390 New Sulfate equations
C  Jan-31-1994 @ CSC-bsg Request 387 Investigate catalyst fractions
C  Jan-7-1994 @ CSC-bsg Request 380 user-supplied rates
C  Jan-6-1994 @ CSC-bsg Request 377 Expansion of by-model year to include
C       transit and CBD or heavy urban when applicable.  The application
C       criteria is determined with the BUSFLG.
C  Jan-5-1994 @ CSC-bsg Request 379 Conversion of OUTFMT=4 to OUTFMT=3
C  Jan-4-1994 @ CSC-bsg Request 376 User's Guide input files
C  Dec-1-1993 @ ARC-bsg Subtask 362 unpaved dust
C  Nov-29-1993 @ ARC-bsg Subtask 340 lead DFS dates and values
C  Nov-3-1993 @ ARC-bsg Subtask 339 Made PART5 more like MOBILE5a.
C                 LDGV, LDGT1, LDGT2 and HDGV mileage distributions.
C                    LDGT1, LDGT2, HDGV, HDDV and LDDT registration
C                                      HDGV and HDDV vehicle counts
C  Oct-29-1993 @ ARC-bsg Subtask 332 Reinstated Driver
C  Oct-20-1993 @ ARC-bsg Subtask 325 Bus labeling and calculations
C  Oct-19-1993 @ ARC-bsg Subtask 322 must make the same on all platforms
C       during the standardization caught
C       this initialization error that was
C       not identical on all platfoms. and makes idle EF incorrect
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  Oct-7-1993 @ ARC-ljn & bsg Subtask 322 standard Fortran
C       Based on release (BOR) 9-30-1993
C       fr Systems Application International (SAI)
C  PART5 is the second version of the FORTRAN program implementation of the
C  Mobile Source Emission Model.  It updates and replaces PART. The model
C  estimates particulate emission factors by motor vehicles.  For information
C  on using the program and on the differences between PART and PART5,
C  consult the User's Guide to PART5.
C
C         Office of Mobile Sources
C         Emission Control Technology Division
C         Test and Evaluation Branch
C         2565 Plymouth Road
C         Ann Arbor, Mich. 48105
C         Telephone: 313-668-4462
C                    FTS 374-8462
C
C
C  Source Code Documentation
C  -------------------------
C
C  The source code itself is commented to assist the users who require a
C  more detailed understanding of the program than provided in the Guides.
C  This section provides the following information:
C
C  0) Adherence to programming styles
C  1) Execution summary
C  2) Source code structure
C  3) Source code comments structure
C     a) Subroutines and functions header format
C     b) BLOCK DATA subprograms header format
C     c) In-line comments
C  4) Subscript dictionary
C  5) Subroutine / function parameter dictionary
C
C
C  0) Adherence to programming styles
C
C  No more than one C line in a row.  Exception two before and after
C  a notes line.  Always use one return in a function or subroutine.
C  Always use two CC prefix to a code line eligible for removal.
C
C
C  1) Execution summary
C
C  To run the program, attach the input file to logical I/O Unit 5 and the
C  output file to Logical I/O Unit 6.  You will have the option of running
C  the program interactively.  If you elect to run it interactively, you
C  will be prompted at the screen for all necessary input.  If not, the
C  program will prompt you for the name of an input file, which must have
C  all the necessary information for the run.  Refer to the User's Guide
C  to PART5 for more detail on setting up runs and check your operating
C  system documentation for the system commands for compiling and executing
C  the program.  There is discussion of running the program on the IBM PC
C  AT under DOS in the User's Guide.
C
C  For information on the source code itself, refer to the Programmer's Guide
C  to PART5
C
C
C  2) Source code structure
C
C     This section describes the layout of the code plus the numbering and
C     naming conventions.
C
C     The subprograms in the source code are listed in alphabetical order,
C     where the main program is called "part5".
C
C     Statement numbers are local.  For example, within each subprogram,
C     branch numbers start at 10, READ formats start at 100, etc.
C
C  3) Source code comments structure
C
C     Each subprogram contains a documentation header, set up in a standard
C     format as described below.  All variables and arrays used in the code
C     are defined in the comments.  The subroutine / function headers define
C     local parameters and local variables / arrays.  The BLOCK DATA headers
C     describe the COMMON storage areas.  Array subscripts and subprogram
C     parameters are specified in dictionaries following this section.  The
C     intent is to allow the user to scan the source code on-line for
C     definitions, rather than have to leaf through hard-copy documentation
C     such as the Prorammer's Guide to PART5.
C
C     a) Subroutines and functions header format
C
C        <subprogram name>
C        C
C        C  <short description of purpose>
C        C
C        C  Called by <subprogram name(s)>
C        C
C        C  Calls <subprogram name(s)>
C        C
C        C  Input on call:
C        C
C        C    parameter list: <names>
C        C    common block(s):
C        C    /<cb name>/ <names>
C        C         .         .
C        C         .         .
C        C
C        C  Output on return:
C        C
C        C    parameter list: <names>
C        C    common block(s):
C        C    /<cb name>/ <names>
C        C         .         .
C        C         .         .
C        C
C        C  Local array subscripts:
C        C
C        C  <name>(<#>,...)  -  <name>(<name>,...)
C        C         .                    .
C        C         .                    .
C        C
C        C  Local variable / array dictionary:
C        C
C        C   Name   Type              Description
C        C  ------  ----  --------------------------------------------------
C        C  <name> <type>         <short description>
C        C    .      .                     .
C        C    .      .                     .
C        C
C        C  Notes:
C        C
C        C
C        <code>
C
C        Notes on format:
C
C        A local variable is one not passed in via the parameter list
C        or a common block.  It can be used in the argument list of a
C        subprogram call made by the defining subprogram.
C
C        Also, if a section of the header is not needed, its format is
C        omitted.  For example, if no subprograms are called, then the
C        'C  Calls <names>' line is not included.
C
C        Finally, 'Output on return' includes any variable / array whose
C        contents can be modified by the subprogram.
C
C     b) BLOCK DATA subprogram header format
C
C              BLOCK DATA
C        C
C        C  BLOCK DATA subprogram <#>
C        C
C        C  <short description of data initialized in this BLOCK DATA>
C        C
C        C  Common block array subscripts:
C        C
C        C  <name>(<#>,...)  -  <name>(<name>,...)
C        C         .                    .
C        C         .                    .
C        C
C        C  Common block dictionary:
C        C
C        C   Name   Type              Description
C        C  ------  ----  --------------------------------------------------
C        C  /<cb name>/:
C        C  <name> <type>         <short description>
C        C    .      .                     .
C        C    .      .                     .
C        C
C        C  Local array subscripts:
C        C
C        C  <name>(<#>,...)  -  <name>(<name>,...)
C        C         .                    .
C        C         .                    .
C        C
C        C  Local array dictionary:
C        C
C        C   Name   Type              Description
C        C  ------  ----  --------------------------------------------------
C        C  <name> <type>         <short description>
C        C    .      .                     .
C        C    .      .                     .
C        C
C              COMMON /<name 1>/ ...
C                 .
C                 .
C                 .
C        C
C              DIMENSION (or type) <array 2>(subscript(s))
C                 .
C                 .
C        C
C              EQUIVALENCE (<array 1, subscripted>,<array 2, subscripted>)
C                 .
C                 .
C                 .
C        C
C        C  /<name 1>/: <any comments on <name 1>'s labels, purpose or data
C        C               or on the structure of the initializing DATA
C        C               statement(s)>
C        C
C              DATA <var/arr name 1>/<data>...
C                 .
C                 .
C                 .
C                 .../
C        C
C        C  /<name 2>/: ...
C                 .
C                 .
C                 .
C              END
C
C        Notes on format:
C
C        Local arrays are defined and then equivalenced to common block arrays
C        that are too large be intialized in 1 DATA statement.  Too large =
C        would require greater than 19 continuation lines, the FORTRAN limit.
C
C        The local arrays dictionary is often compressed by providing a
C        generic definition of the conventions used to construct and name the
C        set of local arrays to be equivalenced to a given common array.
C
C        "/<name #>/:" prefix is included only if a large number of common
C        blocks are being initialized in a single BLOCK DATA (see BD 23).
C
C
C     c) In-line comments
C
C        In-line comments are intended to describe the algorithm being used
C        by the code.
C
C        Particular attention is paid to the use of indices and pointers.
C
C  4) Subscript dictionary
C
C     Subscript variables used to index arrays in PART5 are globally
C     defined, not in the sense that the values are available to all
C     subprograms, but rather that the same label is used for the same
C     subscript function throughout the code.  IP is the 13 pollutants index
C     for all of PART5, although its instances are usually as a local
C     variable.  As array subscripts, all these variables must be of type
C     INTEGER. The default INTEGER typing syntax rule is employed by having
C     all subscripts begin with a letter from the range I through N.
C
C      Name    Range               Description
C     ------  -------  ----------------------------------------------------
C     ICAT      1-3    catalyst technology configurations:
C                        1 = ox catalyst / no catalyst
C                        2 = 3 way catalyst
C                        3 = 3 way + ox catalyst
C
C     ICH       1-20   character string array position index:
C                        1 = 1st 4/8 characters (CHARACTER*4/8)
C                        2 = 2nd 4/8 characters
C                                .
C                                .
C
C     ID        1-9    disablement types (1-5,9 for bag, 6-8 for evap):
C                        1 = AIRS = air pump disabled
C                        2 = CATS = catalyst removed
C                        3 = NCKS = misfueled - filler neck
C                        4 = TNKS = misfueled - tank (all but filler neck)
C                        5 = EGRS = EGR disabled
C                        6 = EVAP = evaporative system tampered - cannister only
C                        7 = PCVS = PCV disabled
C                        8 = CAPS = evaporative system tampered - cannister and
C                                   gas (fuel inlet) cap
C                        9 = MISF = misfueled - all sources = NCKS + TNKS
C
C     IDX       1-25   model year (my) window index:
C                        1 = 25+ my age group cell => tamper effect is
C                            always 0.0 => this case skipped in TAMPER (only)
C                        2 = 24th my cell
C                        3 = 23th my cell
C                          .
C                          .
C                          .
C                       24 = 2nd my cell
C                       25 = 1st my cell = calendar year (ICY)
C
C     IFAC      1-100  index into new (user supplied) emission rates arrays;
C                      the user can enter up to 100 replacement cases.
C
C     IFG       1-13   flag names for prompts (listed by common block used):
C                         /FLAGS1/      /FLAGS2/       /FLAGS3/      /FLAGS4/
C                          TAMFLG        MYMFLG         RFGFLG        SO2FLG
C                          SPDFLG        IMFLAG         OUTFMT        IDLFLG
C                          VMFLAG        MISFLG                       PRTFLG
C                                                                     BUSFLG
C                      The flags are read in the order:
C                      TAMFLG (optional tampering rates)
C                      VMFLAG (alternate VMT mixes)
C                      MYMRFG (alternate mileage accumulation rates &
C                              registration)
C                      MISFLG (User supplied misfueling rates)
C                      IMFLAG (Inspection and maintenance)
C                      RFGFLG (user supplied sulfur weight percent)
C                      OUTFMT (indicates type of output format)
C                      IDLFLG (1 to print, 0 not to print idle emission factors)
C                      SO2FLG (2 to print, 1 not to print gas SO2
C                              emissions factors
C                      PRTFLG (determines which pollutants to print out)
C                      BUSFLG (determines which of the algernative bus cycles
C                              to print)
C
C     IFUEL     1-2    fuel type category for RVP exhaust effects:
C                        1  = leaded gasoline      2 = unleaded gasoline
C
C     IG<i>     1-25   model year group (myg) pointer:
C                      <i> = null string,C,CAT,D,E,F,L,LM,S,T,U,W,1,2,3,4
C                      IG links a data array to its corresponding myg index
C                      array. These data arrays all have my as a subscript
C                      plus have cases of contiguous subsets of years with
C                      the same data point.  Core space is then saved by
C                      storing each point only once per my subset and then
C                      constructing an index array to enable the program to
C                      find the location IG<i> of the data point for a given
C                      my.
C
C     IM        1-2    I/M program flag:
C                        1 = I/M program not in effect
C                        1 = I/M program is in effect
C
C     INO       1-2    index into NOYES character string vector:
C                        1 = No     2 = Yes
C
C     IP        1-11   pollutants:
C                        1 = Lead
C                        2 = SOF         = soluable organic fraction
C                        3 = RCP         = remaining carbon portion
C                        4 = H2SO4       = sulfuric acid
C                        5 = Exhaust PM  = total exhaust particulate matter
C                        6 = Gas. SO2    = gaseous sulfur
C                        7 = (NH4)2SO4   = estimated indirect sulfate material
C                        8 = Sulfate PM  = total sulfate material (4 + 7 above)
C                        9 = Brake
C                       10 = Tire
C                       11 = Total PM    = 1 + 2 + 3 + 4 + 7 + 9 + 10 above
CC                       12 = Unpvd Dust  = dust from driving on unpaved roads
CC                       13 = Paved Dust  = dust from driving on industrial roads
C
C     IP1       1-13   lower bound of output IP loop (first pollutant to
C                      have results printed)
C
C     IP2       1-13   upper bound of output IP loop (last pollutant to
C                      have results printed)
C
C     IR        1-2    region code:
C                      IR has same value range as IREJN, but is not necessarily
C                      the scenario field's value
C                        1 = low altitude
C                        2 = high altitude
C
C     ISC       1-5    underscore string repetition counter - for example,
C                      ISC = 3 => repeat the string 3 times
C
C     ITER      1-4    unspecified string iterations counter; same usage as
C                      ISC, only with any string
C
C     IV        1-15   vehicle types evaluated by PART4:
C                        1 = LDGV  = light duty (ld) gasoline fueled vehicle
C                        2 = LDGT1 = ld gasoline fueled truck, <= 6000 lbs.
C                        3 = LDGT2 = ld gasoline fueled truck, 6001-8500 lbs.
C                        4 = HDGV  = heavy duty gasoline fueled vehicle
C                        5 = MC    = motorcycle
C                        6 = LDDV  = light duty diesel fueled vehicle
C                        7 = LDDT  = light duty diesel fueled truck
C                        8 = 2BHDDV= class 2B heavy duty diesel fueled vehicle
C                        9 = LHDDV = light heavy duty diesel fueled vehicle
C                       10 = MHDDV = medium heavy duty diesel fueled vehicle
C                       11 = HHDDV = heavy duty diesel fueled vehicle
C                       12 = BUSES = buses
C                       13 = Transit
C                       14 = CBD
C                       15 = heavy urban buses
C
C     IVIM      1-4    vehicle class types that can be included in PART5
C                      inspection / maintenance (I/M) programs:
C                        1 = LDGV    2 = LDGT1    3 = LDGT2    4 = HDGV
C
C     IVHD      1-5    vehicle class types for heavy duty only (used for
C                      units conversion of user entered hd zml & dr):
C                        1 = 2BHDDV  2 = LHDDV    3 = MHDDV    4 = HHDDV
C                        5 = BUSES
C
C     IVTAM     1-4    vehicle types impacted by tampering (gasoline fueled):
C                        1 = LDGV     2 = LDGT1    3 = LDGT2    4 = HDGV
C
C     JDX       10-1   model year window index = age of vehicle relative to
C                      ICY + 1. In detail:
C                       25 = 25+ my age group cell => tamper effect is
C                            always 0.0 => this case skipped in TAMPER (only)
C                       24 = 24th my cell
C                       23 = 23th my cell
C                          .
C                          .
C                          .
C                        2 = 2nd my cell
C                        1 = 1st my cell = calendar year (ICY)
C
C     KDX       1-21   model year window index = ICY - 1979, unless result is
C                      < 1 (=> = 1) or > 21 ( => = 21); used by HDDMYM
C
C     LIM       1-2    = IM
C
C
C
C  5) Subroutine / function parameter dictionary
C
C     Variables /arrays occurring in 1 or more of the subprogram parameter
C     lists are defined in this section, unless the variable is a subscript,
C     in which case look it up in 4)'s subscript dictionary.  The motivation
C     for defining all the parameter lists in one place is to have only one
C     instance of a definition in the code plus to encourage only one use
C     for a mnemonic in the code plus the combined lists contain only 18
C     names after subscripts have been removed.  Whether scanning on-line or
C     off a listing, the lookup will be quick.
C
C     Parameter array subscripts
C     --------------------------
C
C      Name   Type              Description
C     ------  ----  -------------------------------------------------------
C     FLGERR   I    number of flag values found to be out of range
C     ICY      I    calendar year for which emission factors are calculated
C     IOUOUT   I    unit number on which title is printed
C     IY       I    year to test and adjust to 4-digit year
C     IY1      I    lower 4-digit bound for IY
C     IY2      I    upper 4-digit bound for IY
C     MESSAG   I    MESSAG code sent by calling subprogram
C     MY       I    model year
C
C  ***************************************************************************
C
C
C  MAIN
C
C  MAIN is the PART5 driver.  It sets up the run and then loops through
C  scenarios.
C
C  Calls CONSEC, EFCALX, ONESEC, OUTPUT, PARSEC and REGMOD.
C
C  Since MAIN is not "called" and does not "return", the I/O interface
C  documentation will list the variables passed in argument lists or common
C  blocks and used in MAIN:
C
C    argument lists: ICY
C    common blocks:
C    /REGION/ IREJN
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  ICYOLD   I    calendar year from previous pass of scenario loop
C  IROLD    I    region from previous pass of scenario loop
C
C  Notes:
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'IOU.INC'
C
      INTEGER ICYOLD
C
CC    REAL ICNVRT
CC    OPEN(10,FILE='DIRSO4MF',POSITION='APPEND')
C
C  Initialize MAIN level variables.
C
      ENDMSG = ' Execution Terminated Normally'
      ICYOLD=-1
      IROLD=-1
C
C  Control and One-Time Data Sections:
C
C  Get the execution control flags and parameters, and then use them to read
C  in data, if any, that is read in once and applied to all scenarios.
C
      CALL CONSEC
      WRITE(IOUASK,*) ' Reading information'
      CALL ONESEC
C
C  Enter scenario loop.
C
C  Feb-23-1995 @ CSC-wcs Subtask 484 (PART5 Output)  Fix scenario loop so that
C  32767 scenarios can be run instead of just a hundred.
C
      DO 10 ISCENE=1,32767
C
      CALL PARSEC(ICY)
C
      IF(ICYOLD.NE.ICY.OR.IROLD.NE.IREJN) CALL REGMOD(ICY)
      ICYOLD=ICY
      IROLD=IREJN
C
      WRITE(IOUASK,*) ' Performing calculations'
      CALL EFCALX(ICY)
C
      WRITE(IOUASK,*) ' Preparing output'
      CALL OUTPUT(ICY)
 10   CONTINUE
C
      STOP
      END
C
      SUBROUTINE REGMOD(ICY)
C
C  REGMOD adjusts model year mileage/registration arrays.
C
C  Called by MAIN.
C
C  Calls CEVMPD,CEVTPD,HDDMYM, IGSFPT and TFCALX.
C
C  Input on call:
C
C    parameter list: ICY
C    common blocks:
C    /FLAGS2/ MYMRFG
C    /GSFCOM/ GSFRAC
C    /MAXIMA/ MAXVEH,MAXYRS
C    /MYRSAV/ AMAR,JULMYR
C    /REGION/ IREJN
C
C  Output on return:
C
C    parameter list:
C    common blocks:
C    /MYRCAL/ XMYM,JANMYR,TFMYM
C    /REGISF/ GSFVCT
C
C  Local array subscripts:
C
C  CUM(MAXYRS)  -  CUM ( JDX )
C  DAF(8)   -  DAF ( IV )
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  CUM      R    cumulative mileage distribution as of January 1
C  DAF      R    unnormalized sum by IV of registrations across my's
C                (acronym is from ef derivation document)
C  FRC      R    fraction of January 1 registrations in current year JDX
C                which are in their JDX'th year of operation
C  FRN      R    fraction of January 1 registrations in current year JDX
C                which are in their JDX-1'th year of operation (1 year newer)
C  GSFIDX   R    gas/diesel sales fraction (GSF) for MY IDX, given IV & IREJN;
C                used to extract IV's share of pairwise registration sum
C  AMC      R    mileage accrual rate for vehicle of type IV in its JDX'th
C                year of operation
C  AMN      R    mileage accrual rate for vehicle of type IV in its JDX-1th
C                year of operation (a vehicle in JDX-1 is 1 year "newer" than
C                a JDX year old vehicle)
C  MY       I    see parameter dictionary
C  SUMLDV   R    LDV DAF's combined (both gas & diesel registrations)
C  SUMLDT   R    LDT DAF's combined (both gas & diesel registrations)
C
C  Notes:
C  none
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'GSFCOM.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
      INCLUDE 'SCENE.INC'
C
C
      DIMENSION CUM(MAXYRS),DAF(MAXVEH)
      REAL AMC,AMN
C
C  Compute January 1 registration distributions, JANMYR.
C
      DO 20 IV=1,MAXVEH
C
C  Step 1: for each model year of each vehicle type, select and apply the
C          corresponding GSF to the (gas & diesel combined) July 1
C          registrations.
C
      DO 10 JDX=1,MAXYRS
      MY=ICY-JDX+1
      IGS=IGSFPT(MY,IV)
      GSFIDX=GSFRAC(IGS,IV,IREJN)
      JANMYR(JDX,IV)=GSFIDX*JULMYR(JDX,IV)
   10 CONTINUE
C
C
C  Step 2: backup ICY's registrations from 7/1 to 1/1 -
C          LDV/T => my starts 10/1 prior yr => 1/1 sales are 1/3 of 7/1 sales.
C          HDV & MC => my starts 1/1 => 1/1 sales are 0.
C
      JANMYR(1,IV)=JANMYR(1,IV)/3.
      IF(IV.EQ.4.OR.IV.EQ.5.OR.IV.GE.8) JANMYR(1,IV)=0.0
   20 CONTINUE
C
C  Step 3: normalize JANMYR.
C
      DO 40 IV=1,MAXVEH
      DAF(IV)=0.0
      DO 30 JDX=1,MAXYRS
      DAF(IV)=DAF(IV)+JANMYR(JDX,IV)
   30 CONTINUE
      DO 40 JDX=1,MAXYRS
      IF(DAF(IV).GT.0.0) JANMYR(JDX,IV)=JANMYR(JDX,IV)/DAF(IV)
   40 CONTINUE
C
C  Given DAF (JAN 1 unnormalized total (MAXYRS my's combined) registrations),
C  calculate the <gas | diesel> / (gas + diesel) fractions for LDV & LDT.
C  HDV & MC are assigned unity, since there is no combined gas + diesel
C  number in VCOUNT in TFCALX to split by fuel type fraction for these
C  vehicle types.  An attempt was made to model the HDV gas vs diesel sales,
C  but the results proved unsatisfactory.
C
      SUMLDV=DAF(1)+DAF(6)
      SUMLDT=DAF(2)+DAF(7)
C
      GSFVCT(1)=DAF(1)/SUMLDV
      GSFVCT(2)=DAF(2)/SUMLDT
      GSFVCT(3)=1.
      GSFVCT(4)=1.
      GSFVCT(5)=1.
      GSFVCT(6)=DAF(6)/SUMLDV
      GSFVCT(7)=DAF(7)/SUMLDT
      GSFVCT(8)=1.
      GSFVCT(9)=1.
      GSFVCT(10)=1.
      GSFVCT(11)=1.
      GSFVCT(12)=1.
CC    GSFVCT(13)=1.
C
C  Generate the mileage accrual rates.
C
C  If defaults used, determine the HDDV calendar year mileage
C  by registration weighting. Otherwise, use user input mileage.
C
      IF (MYMRFG .EQ. 1 .OR. MYMRFG .EQ. 3) THEN
	 CALL HDDMYM(ICY)
      ENDIF
C
C  Compute the annual mileage / 100,000  distributions, XMYM.
C
      DO 60 IV=1,MAXVEH
      FRC=.25
      IF(IV.EQ.4.OR.IV.EQ.5.OR.IV.GE.8) FRC=0.0
      FRN=1.-FRC
      AMN=AMAR(1,IV)
      AMC=AMAR(2,IV)
      CUM(1)=.5*FRC*AMN
      CUM(2)=FRC*(.5*FRC*AMC+AMN)+FRN*((1.+FRC)*.5*AMN)
      AMC=AMC+AMN
C
      DO 50 JDX=3,MAXYRS
      CUM(JDX)=FRC*(.5*FRC*AMAR(JDX,IV)+AMC)+FRN*(.5*(1.+FRC)
     *   *AMAR(JDX-1,IV)+AMN)
      AMN=AMC
      AMC=AMC+AMAR(JDX,IV)
   50 CONTINUE
C
C  Subroutine GETCUM produces the cumulative mileage partial sums array,
C  CUMMIL, from XMYM.
C
      XMYM(1,IV)=CUM(1)
      DO 60 JDX=2,MAXYRS
      XMYM(JDX,IV)=CUM(JDX)-CUM(JDX-1)
   60 CONTINUE
C
C  Now figure the January 1 model year mileage accumulation rates, TFMYM.
C
      DO 80 IV=1,MAXVEH
      FRC=.25
      TFMYM(1,IV)=AMAR(1,IV)
      IF(IV.NE.4.AND.IV.NE.5.AND.IV.LT.8) GOTO 70
      FRC=0.0
      TFMYM(1,IV)=0.0
   70 FRN=1.-FRC
C
      DO 80 JDX=2,MAXYRS
      TFMYM(JDX,IV)=AMAR(JDX-1,IV)*FRN+AMAR(JDX,IV)*FRC
   80 CONTINUE
C
C
C  Use JANMYR, TFMYM, and GSFVCT to generate the vmt mix and travel fractions.
C
      CALL TFCALX(ICY)
C
      RETURN
      END
      SUBROUTINE TFCALX(ICY)
C
C  TFCALX computes the travel fractions, VMT mix, and registration mix.
C
C  Called by REGMOD.
C
C  Input on call:
C
C    common blocks:
C    /MAXIMA/ MAXVEH,MAXYRS
C    /MYRCAL/ JANMYR,TFMYM
C    /REGISF/ GSFVCT
C
C  Output on return:
C
C    common blocks:
C    /MYRCAL/ TF
C    /VMXCOM/ REGMIX,TFNORM,VMTMIX
C
C  Local array subscripts:
C
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  TOTREG   R    total registrations: used to normalize the registration mix
C  TOTVMT   R    total vmt: used to normalize the default vmt mix
C  VCOUNT   R    vehicle count by IV class, scaled by / 10**5; the counts come
C                from 1986/82 (car/truck) registration data.  Note LDGV & LDDV
C                counts are the identical sum of their registrations and ditto
C                with LDGT1 & LDDT.  Hence, PART needs GSFVCT to split the
C                sums properly.  For the other IV, GSFVCT is 1.0 and has no
C                effects.
C
C  Notes:
C
C     ICY is two (4) digits, the last two of the Calender Year
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'HDFLEET.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
C
C
      REAL RHOLD
C
      dimension TFSUM(12)
      DIMENSION FRAC(4)
      DIMENSION VC(4)
C
      DATA VCOBUS/0.555/
C
C
C     Calculate VCOUNT's for the Heavy Duty Vehicles
C     VC(1)-> IV  8 = 2BHDV
C     VC(2)-> IV  9 = LDHDV
C     VC(3)-> IV 10 = MDHDV
C     VC(4)-> IV 11 = HDHDV
C
      KDX=ICY-1979
      IF(KDX .GT. 21) KDX=21
      IF(KDX .LT. 1)  KDX=1
      TOTAL=C2BDRG(KDX)+LHDRG(KDX)+MHDRG(KDX)+HHDRG(KDX)
      FRAC(1)=C2BDRG(KDX)/TOTAL
      FRAC(2)=LHDRG(KDX)/TOTAL
      FRAC(3)=MHDRG(KDX)/TOTAL
      FRAC(4)=HHDRG(KDX)/TOTAL
C
      IF(ICY.LE.1981) THEN
      RHOLD=0.0
      RHOLD=VCOUNT(1,8)
      VC(1)=RHOLD*FRAC(1)
      VC(2)=RHOLD*FRAC(2)
      VC(3)=RHOLD*FRAC(3)
      VC(4)=RHOLD*FRAC(4)
      ENDIF
C
      IF(ICY.GT.1981) THEN
      RHOLD=0.0
      RHOLD=VCOUNT(ICY-1981,8)
      VC(1)=RHOLD*FRAC(1)
      VC(2)=RHOLD*FRAC(2)
      VC(3)=RHOLD*FRAC(3)
      VC(4)=RHOLD*FRAC(4)
      ENDIF
C
      DO 20 IV=1,MAXVEH
      TFNORM(IV)=0.0
C
      DO 10 JDX=1,MAXYRS
      TFNORM(IV)=TFNORM(IV)+TFMYM(JDX,IV)*JANMYR(JDX,IV)
   10 CONTINUE
   20 CONTINUE
C
      IF (VMFLAG.GT.1) GO TO 45
C
      TOTVMT=0.0
      DO 30 IV=1,MAXVEH
      VMTMIX(IV)=0.0
      RHOLD=0.0
      IF(IV.EQ.12)RHOLD=VCOBUS
C
      IF(ICY.LE.1981) THEN
      IF(IV.LE.7) RHOLD=VCOUNT(1,IV)
      IF(IV.GT.7.AND.IV.LT.12) RHOLD=VC(IV-7)
      ENDIF
C
      IF(ICY.GT.1981) THEN
      IF(IV.LE.7) RHOLD=VCOUNT(ICY-1981,IV)
      IF(IV.GT.7.AND.IV.LT.12) RHOLD=VC(IV-7)
      ENDIF
C
      VMTMIX(IV)=RHOLD*GSFVCT(IV)*TFNORM(IV)
C
      TOTVMT=TOTVMT+VMTMIX(IV)
C
   30 CONTINUE
C
      DO 40 IV=1,MAXVEH
      VMTMIX(IV)=VMTMIX(IV)/TOTVMT
C
   40 CONTINUE
C
  45  DO 70 IV=1,MAXVEH
      IF(TFNORM(IV).LE.0.0.AND.VMTMIX(IV).GT.0.0) THEN
	 WRITE(IOUERR,300) IV,TFNORM(IV),VMTMIX(IV)
	 STOP ' Execution Terminated with Errors'
      ENDIF
      IF(TFNORM(IV).LE.0.0) TFNORM(IV)=1.
      DO 60 JDX=1,MAXYRS
      IDX=(MAXYRS+1)-JDX
      TF(IDX,IV)=(TFMYM(JDX,IV)*JANMYR(JDX,IV))/TFNORM(IV)
   60 CONTINUE
   70 CONTINUE
 300  FORMAT('ERROR:  The registrations times the mileage accrual rate',
     *      ' for vehicle class ',I2,' is ',F10.5,/,7X,' and the VMT',
     *      ' mix is ',F10.5)
C
      DO 320 IV=1,MAXVEH
      TFSUM(IV) = 0.
      DO 310 JDX=1,MAXYRS
	 TFSUM(IV) = TFSUM(IV) + TF(JDX,IV)
 310  CONTINUE
C     WRITE(IOUERR,*) ' IV ',IV,' TFSUM(IV) ',TFSUM(IV)
 320  CONTINUE
C
C  Calculate normalized REGMIX.
C
      TOTREG=0.0
C
      DO 80 IV=1,MAXVEH
      RHOLD=0.0
      IF(IV.LT.8.AND.ICY.LE.1981) RHOLD=VCOUNT(1,IV)
      IF(IV.LT.8.AND.ICY.GT.1981) RHOLD=VCOUNT(ICY-1981,IV)
      IF(IV.GT.7.AND.IV.LT.12) RHOLD=VC(IV-7)
      IF(IV.EQ.12) RHOLD=VCOBUS
C
      REGMIX(IV)=RHOLD*GSFVCT(IV)
      IF (IV.GT.7.AND.IV.LT.12) REGMIX(IV)=REGMIX(IV)*FRAC(IV-7)
      TOTREG=TOTREG+REGMIX(IV)
C
   80 CONTINUE
C
      DO 90 IV=1,MAXVEH
      REGMIX(IV)=REGMIX(IV)/TOTREG
   90 CONTINUE
C
      RETURN
      END
      SUBROUTINE USDPTR
C
C  USDPTR finds the pointers into the user supplied data name array.
C
C  Called by OUTHD3 and OUTHD4.
C
C  Input on call:
C
C    common blocks:
C    /FLAGS1/ TAMFLG
C    /FLAGS2/ MYMRFG
C
C  Output on return:
C
C    common block: /USDATA/ NUSD,IUSD
C
C
C  Notes:
C  Jan-7-1994 @ CSC-bsg Request user-supplied rates have been given
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  Apr-12-1994 @ CSC-bsg Request 419 made PART5 like MOBILE5a with respect
C  to the tampering rates of catalyst removal and misfueling removed
C  tampering and misfueling as user inputs also removed sulfur fuel
C  as a user supplied input message, this undoes most of request 380.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'FLAGS.INC'
C
C  Setup scenario header user supplied data pointer vector.
C
      NUSD=0
C
      IF(VMFLAG.NE.1) THEN
	NUSD=NUSD+1
	IUSD(NUSD)=1
      ENDIF
C
      IF(MYMRFG.EQ.2) THEN
	NUSD=NUSD+1
	IUSD(NUSD)=2
      ELSE IF(MYMRFG.EQ.3) THEN
	NUSD=NUSD+1
	IUSD(NUSD)=3
      ELSE IF(MYMRFG.EQ.4) THEN
	NUSD=NUSD+1
	IUSD(NUSD)=2
	NUSD=NUSD+1
	IUSD(NUSD)=3
      ENDIF
C
C  Mar-15-1994 @ CSC-bsg Request 407 LEDFLG removal it has been decided that
C  this should not be a user input
C  Apr-12-1994 @ CSC-bsg Request 419 made PART5 like MOBILE5a with respect
C  to the tampering rates of catalyst removal and misfueling removed
C  tampering and misfueling as user inputs also removed sulfur fuel
C  as a user supplied input message, this undoes most of request 380.
C
      RETURN
      END
