      SUBROUTINE O3P3B3(ICY)
C
C  OUTDT3 writes scenario parameters and output on unit IOUREP using output
C  format (OUTFMT) 3 with the third pollutant option (PRTFLG) 3 for the
C  default Buses emissions report (BUSFLG) 2 option
C
C  Called by OUTPUT.
C
C  Input on call:
C
C    parameter list: ICY
C    common blocks:
C     /CITPAR/ SCNAME(8)
C     /FLAGS2/ IMFLAG
C     /FLAGS3/ OUTFMT
C     /FLAGS4/ PRTFLG,SO2FLG,IDLFLG
C     /IOUCOM/ IOUREP
C     /MAXIMA/ MAXVEH
C     /NAMES1/ NAMVEH(MAXVP1)
C     /NAMES2/ NAMPOL(MAXPOL), NAMREG(3), NAMFUD(2)
C     /PSIZE/  PSZCUT
C     /REGION/ IREJN,ALT,INITPR
C     /RESUL1/ EF(MAXPOL,MAXVEH+3)
C     /RESUL3/ VEF(MAXPOL)
C     /SCENE1/ SPD,ISPDCY,UNSILT,PVSILT,INDF,NLANES,IPDAYS,USRWT
C     /STRING/ NOYES(2),COMMA,PERIOD,COLON
C     /USDATA/ USNAME(4,3),NUSD,IUSD(3)
C     /VMXCOM/ VMTMIX(MAXVEH)
C
C  Local variable / array dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  IP1      I    see parameter dictionary
C  IP2      I    see parameter dictionary
C  NWITHC   I    number of substrings to be written with a comma appended
C  USC8     C*8  8 character underscore
C  IRFG     I    index for yes or no RFG depending on ICY and RFGFLG
C  LIMFLG   I    local version of IMFLAG
C
C
C  Notes:
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  Oct-19-1993 @ ARC-bsg Subtask 325 creation of EF for other buses
C  Dec-3-1993 @ ARC-bsg Subtask 362 print driving cycle to output
C  Dec-17-1993 @ ARC-bsg Subtask 362
C  Disable Fugitive Dust All vehicle output
C  Feb-8-1994 @ CSC-bsg Request 384  Add Microns to units
C  Feb-23-1994 @ CSC-bsg Request 397 Paved Dust in All vehicle
C  Mar-3-1994 @ CSC-bsg Request 394 Add SO2FLG
C  Mar-10-1994 @ CSC-bsg Reques 403 Created this from OUTDT3 to modularize
C  BUSFLG
C  Mar-25-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Mar-23-1994 @ CSC-bsg Request 409 Add RFG output echo in header
C  May-24-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  May-24-1994 @ CSC-bsg Request 434 Integration and regression testing
C  added bounds check IMFLAG=3 for no tampering option
C  Jun-21-1994 @ CSC-bsg Request 449 silt content in the printout to have enough
C  significant digits so that 0.02 is reported instead of 0.0 in the echo.
C  Same problem with VMT mix, three significant digits printed, 4 read in.
C  Jul-20-1994 @ CSC-bsg Changed PRTFLG=3 option by making this subroutine
C  from the O3B2, and O3P3B1
C  Jul-25-1994 @ CSC-bsg Request 434 Changed the Unpaved Dust to one decimal 
C  place after the decimal point
C  Jul-29-1994 @ CSC-bsg Request 434 Modified Idle Output to include extra
C  Bus Categories with the same EF as Regular Buses
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C  Jan-26-1995 @ CSC-ked Request 484 (PART5 Output) Print fugitive dust section
C  in call to new sub. PFDUST.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'IDLE.INC'
      INCLUDE 'REGIS.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
      INCLUDE 'SCENE.INC'
      INCLUDE 'PSIZE.INC'
C
      CHARACTER*8 USC8,MISSNG
      CHARACTER*8 BUSPED(3)
C
      DATA USC8  /'  ______'/
      DATA MISSNG/'    *   '/
      DATA BUSPED/'    18.5',
     *            '    10.6',
     *            '     3.9'/
C
      LIMFLG=IMFLAG
      IF(IMFLAG.EQ.3) LIMFLG=1
C
      IF(ICY.LE.1994.OR.RFGFLG.EQ.1) THEN
        IRFG=1
      ELSEIF(ICY.GE.1995) THEN
        IRFG=2
      ENDIF
C
C  If BYMY run, start each scenario after 1st on new page.
C
      IF(OUTFMT.EQ.5.AND.INITPR.EQ.1) CALL OUTHDR
C
      IF(NUSD.EQ.0) GOTO 10
      IF(NUSD.EQ.1) WRITE(IOUREP,200)(USNAME(ICH,IUSD(1)),ICH=1,4),
     *                               PERIOD
      NWITHC=NUSD-1
      IF(NWITHC.GT.0) WRITE(IOUREP,200)
     *  ((USNAME(ICH,IUSD(ICT)),ICH=1,4),COMMA,ICT=1,NWITHC),
     *  (USNAME(ICH,IUSD(NUSD)),ICH=1,4),PERIOD
C
 200  FORMAT(' ','User supplied',4A8,T46,A1,4A8,T78,A1,4A8,T110,A1/
     *       ' ',T15,4A8,T46,A1,4A8,T78,A1,4A8,T110,A1/
     *       ' ',T15,4A8,A1/)
C
C  Used for ISPDCY=1
C
 10   IF(ISPDCY.EQ.1) THEN
        WRITE(IOUREP,221) SCNAME,PSZCUT,ALT,NOYES(IRFG),NAMBUS(1,3)
C
C  Feb-8-1994 @ CSC-bsg Request 384  Add Microns to units
C
 221  FORMAT(' ',8A4,/,1X,'Particle Size Cutoff ',F5.2,' Microns',
     *    T50,'Altitude:',F6.0,' Ft.',T85,'Driving:  Transient',
     *' ','RFG:',A4,T119,A8)
C
C  Used for ISPDCY=2
C
      ELSE
        WRITE(IOUREP,220) SCNAME,PSZCUT,ALT,NOYES(IRFG),NAMBUS(1,3)
      ENDIF
C
C  Feb-8-1994 @ CSC-bsg Request 384  Add Microns to units
C
 220  FORMAT(' ',8A4,/,1X,'Particle Size Cutoff ',F5.2,' Microns',
     *    T50,'Altitude:',F6.0,' Ft.',T85,'Driving:  Cruise',
     *' ','RFG:',A4,T119,A8)
C
      WRITE(IOUREP,210) ICY,NOYES(LIMFLG),
     *                 NAMREG(IREJN),NAMBUS(2,3)
C
 210  FORMAT(' ', T2,'Cal. Year:',I5, T50,'I/M Program: ',A4,
     *    T85,'Region:',3X,A4,T113,'All',T119,A8)
C
C  Oct-20-1994 @ CSC-ked Request 474 PART5 Fugitive Dust Reformatting.
C  Replaced SPD(12) with SPD because they were all the same.
C
      WRITE(IOUREP,230) (NAMVEH(IV),IV=1,MAXVEH),NAMVEH(MAXVP1),
     *      NAMBUS(3,3),
     *      (USC8,ITER=1,14), SPD,SPD,SPD,SPD,SPD,SPD,SPD,SPD,SPD,SPD,
     *      SPD,SPD,SPD,BUSPED(3),(VMTMIX(IV),IV=1,MAXVEH)
C
C  Jun-21-1994 @ CSC-bsg Request 449 silt content in the printout to have enough
C  significant digits so that 0.02 is reported instead of 0.0 in the echo.
C  Same problem with VMT mix, three significant digits printed, 4 read in.
C
 230  FORMAT(
     *'   Veh. Type: ',13A8,T119,A8,/,' ',T13,14A8/
     *' Veh. Speeds: ',F5.1,12F8.1,A8,/,'     VMT Mix:',
     *  F7.4,12F8.4)
C
      WRITE(IOUREP,240)
 240  FORMAT(
     *' ','Composite Emission Factors (g/mi)')
C
C  May-24-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  except for Fugitive Dust (Paved and Unpaved Roads)
C
      IP=5
      WRITE(IOUREP,260) NAMPOL(IP),
     *(EF(IP,IV),IV=1,MAXVEH),VEF(IP),EF(IP,15)
      IP=9
      WRITE(IOUREP,260) NAMPOL(IP),
     *(EF(IP,IV),IV=1,MAXVEH),VEF(IP),EF(IP,15)
      IP=10
      WRITE(IOUREP,260) NAMPOL(IP),
     *(EF(IP,IV),IV=1,MAXVEH),VEF(IP),EF(IP,15)
      IP=11
      WRITE(IOUREP,260) NAMPOL(IP),
     *(EF(IP,IV),IV=1,MAXVEH),VEF(IP),EF(IP,15)
C
C  Dec-17-1993 @ ARC-bsg Subtask 362
C  Disable Fugitive Dust All vehicle output
C  Feb-15-1994 @ CSC-bsg Request 394 SO2FLG Disable Exhaust SO2 output
C  Feb-23-1994 @ CSC-bsg Request 397 Paved Dust in All vehicle
C  May-24-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  except for Fugitive Dust (Paved and Unpaved Roads)
C  Jul-25-1994 @ CSC-bsg Request 434 Changed the Unpaved Dust to one decimal 
C  place after the decimal point
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C
CC      IP=12
CC      WRITE(IOUREP,264) NAMPOL(IP),(EF(IP,IV),IV=1,MAXVEH),
CC     *EF(IP,15)
CC      IP=13
CC      WRITE(IOUREP,266) NAMPOL(IP),(EF(IP,IV),IV=1,MAXVEH),VEF(IP),
CC     *EF(IP,15)
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-24-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
 260  FORMAT(' ',1X,A11,F6.3,14F8.3)
C
C  Dec-17-1993 @ ARC-bsg Subtask 362
C  Disable Fugitive Dust All vehicle output
C  Jul-25-1994 @ CSC-bsg Request 434 Changed the Unpaved Dust to one decimal 
C  place after the decimal point
C
CC 264  FORMAT(' ',1X,A11,F6.1,11F8.1,8X,2F8.1)
CC 266  FORMAT(' ',1X,A11,F6.2,15F8.2)
C
C  Oct-28-1994 @ CSC-ked Subtask 474 PART5 Fugitive Dust Reformatting
C
C   Print Fugitive Dust Section
C
      CALL PFDUST
C
      IF(IDLFLG.GT.1.OR.SO2FLG.EQ.2) THEN
 304    FORMAT(/T119,A8/T113,'All',T119,A8/
     *     '   Veh. Type: ',13A8,T119,A8)
        WRITE(IOUREP,302)
        WRITE(IOUREP,352) NAMBUS(1,3),NAMBUS(2,3),
     *  (NAMVEH(IV),IV=1,MAXVEH),NAMVEH(MAXVP1),
     *  NAMBUS(3,3)
 352    FORMAT(/T119,A8/T113,'All',T119,A8/
     *  '   Veh. Type: ',13A8,T119,A8/)
C
C  Jul-29-1994 @ CSC-bsg Request 434 Modified Idle Output to include extra
C  Bus Categories with the same EF as Regular Buses
C
        IF(IDLFLG.GT.1) THEN
          WRITE(IOUREP,305)
          WRITE(IOUREP,310) MISSNG,MISSNG,MISSNG,MISSNG,MISSNG,
     *    MISSNG,MISSNG,(EMSIDL(IV),IV=8,MAXVEH),MISSNG,EMSIDL(MAXVEH)
        ENDIF
      ENDIF
 305  FORMAT(' Total Idle')
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-24-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  Jul-29-1994 @ CSC-bsg Request 434 Modified Idle Output to include extra
C  Bus Categories with the same EF as Regular Buses
C
 310  FORMAT('    (g/hr) : ',A8,6A8,F6.3,4F8.3,2X,A8,F6.3)
C
C  Mar-3-1994 @ CSC-bsg Request 394 Gas. SO2 Flag
C  May-24-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
 311  FORMAT('    (g/mi) : ',F6.3,14F8.3)
C
      IF(SO2FLG.EQ.2) THEN
        IP=6
        WRITE(IOUREP,313) NAMPOL(IP)
 313  FORMAT(' ',A11)
        WRITE(IOUREP,311) (EF(IP,IV),IV=1,MAXVEH),VEF(IP),
     *  EF(IP,15)
      ENDIF
      WRITE(IOUREP,302)
 302  FORMAT(' ',124('_'))
C
      IF (IDLFLG.GT.1) WRITE(IOUREP,290)
 290  FORMAT(' * Missing Data')
C
      WRITE(IOUREP,291)
 291  FORMAT(' ** Not Included in All Veh.')
      RETURN
      END
