      SUBROUTINE O5P1(ICY)
C
C  OUTDT5 writes scenario emission factor results by model year for selected
C  vehicle types on unit IOUREP using output format (OUTFMT) 5.
C
C  Called by OUTPUT.
C
C  Calls OBYHDR, and OUTPOL.
C
C  Input on call:
C
C    parameter list: ICY
C    common blocks:
C     /BYMYC1/ IVPICK(MAXVEH),BYCUM(MAXYRS,MAXVEH)
C     /BYMYC2/ BYFER(MAXPOL,MAXYRS,MAXVEH)
C     /IOUCOM/ IOUREP
C     /MAXIMA/ MAXVEH,MAXYRS
C     /MYRCAL/ TF(MAXYRS,MAXVEH)
C     /NAMES2/ NAMPOL(MAXPOL),NAMREG(3)
C     /RESUL1/ EF(MAXPOL,MAXVEH+3)
C
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  BYVTN    C    Vehicle class descriptions
C  YFM      C    character string = 'Year   TF   Miles'
C  PN       C    character string = 'Emiss Rate'
C  U7       C    character string = '___________'
C  VB       C    character string = '|'
C  NTABLE   I    number of the table.  This variable is necessary because
C                all emission factors for all species can not be printed
C                in one table.
C
C  Notes:
C
C  (1) OUTDT5 prints by model year results only for those pollutants picked
C      by the user via PRTFLG.
C
C  (2) OUTDT5 is called after the OUTFMT=3 output (scenario header + output
C      in 112 column report format) is printed.  Starting on a new page, two
C      By Model Year tables will now be printed on each page thereafter, until
C      all picked vehicle types' results are written.  The maximum space
C      required by OUTFMT = 5 for a scenario is thus 5 pages (OUTFMT = 3
C      output plus eight By Model Year tables).
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  Jan-6-1994 @ CSC-bsg  Request 377 Expansion of by-model year to include 
C  transit and CBD or heavy urban when applicable.  The application
C  criteria is determined with the BUSFLG.
C  Mar-4-1994 @ CSC-bsg Request 394 SO2FLG Disable Exhaust SO2 output
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-10-1994 @ CSC-bsg Request 394 fix bug PRTFLG=3, SO2FLG=2
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
      INCLUDE 'BYMYM.INC'
C
      CHARACTER*36 BYVTN(MAXVEH+3)
      CHARACTER*17 YFM
      CHARACTER*11 U7
      CHARACTER*10 PN
      CHARACTER*1 VB
C
      DATA BYVTN/
     1            '      Light Duty Gas Vehicles       ',
     2            '      Light Duty Gas Trucks 1       ',
     3            '      Light Duty Gas Trucks 2       ',
     4            '      Heavy Duty Gas Vehicles       ',
     5            '            Motorcycles             ',
     6            '     Light Duty Diesel Vehicles     ',
     7            '      Light Duty Diesel Trucks      ',
     8            'Class 2B Heavy Duty Diesel Vehicles ',
     9            '  Light Heavy Duty Diesel Vehicles  ',
     *            '  Medium Heavy Duty Diesel Vehicles ',
     1            '  Heavy Heavy Duty Diesel Vehicles  ',
     2            '      Heavy Duty Diesel Buses       ',
     3            '            Transit                 ',
     4            '               CBD                  ',
     5            '          Heavy Urban               '/
C
      DATA YFM/'Year   TF   Miles'/
      DATA PN/'Emiss Rate'/
      DATA U7/'___________'/
      DATA VB/'|'/
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C
      IF(SO2FLG.EQ.1) GOTO 78
c        NTMP=NAMPOL(6)
c        DO 17 IPS=6,MAXPOL-1
c          NAMPOL(IPS)=NAMPOL(IPS+1)
c   17   CONTINUE
c        NAMPOL(MAXPOL)=NTMP
C
        DO 70 IV=1,MAXVEH+3
          IVV=IV
          IF(IVV.GT.12) IVV=12
          IF(IVPICK(IV).EQ.1) GOTO 70
          CALL OBYHDR
          WRITE(IOUREP,340)
     *    BYVTN(IV),ICY,(VB,NAMPOL(IP),IP=1,5),VB,NAMPOL(7),VB,NAMPOL(8)
          WRITE(IOUREP,345) YFM,(VB,PN,IP=1,7)
          WRITE(IOUREP,350) (U7,ICH=1,7)
  340     FORMAT(
     1    ' ',T39,A36/
     2    ' ',T49,'January 1, ', I4/
     3    ' ',T2,'Model',T21,7(A1,1X,A11,1X))
  345     FORMAT(
     4    ' ',T2,A17,T21,7(A1,1X,A10,2X))
  350     FORMAT(
     4    ' ',T2,'____',T7,'_____',T13,'_______',T21,1X,14(1X,A11,2X))
C
          DO 53 JDX=1,MAXYRS
            IDX=(MAXYRS+1)-JDX
            MY=ICY-JDX+1
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C
            IF(IV.GE.6) THEN
               WRITE(IOUREP,360) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *         (BYFER(IP,JDX,IV),IP=1,5),BYFER(7,JDX,IV),BYFER(8,JDX,IV)
            ELSE IF(IV.LT.6) THEN
               WRITE(IOUREP,362) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *         BYFER(1,JDX,IV),BYFER(4,JDX,IV),BYFER(5,JDX,IV),
     *         BYFER(7,JDX,IV),BYFER(8,JDX,IV)
            ENDIF
   53     CONTINUE
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-17-1994 @ CSC-bsg Request 434 Integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
  360     FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,14(3X,F8.3,3X))
  362     FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,3X,F8.3,3X,
     *2(9X,'-',3X),2X,
     *14(3X,F8.3,3X))
C
C  Write column sums for TF weighted components, to check for 
C  identity with the same sums written out in the OUTFMT = 3 table.
C
          WRITE(IOUREP,370) (U7,ICH=1,7)
C
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C
            IF(IV.GE.6) THEN
               WRITE(IOUREP,375) (EF(IP,IV),IP=1,5),EF(7,IV),EF(8,IV)
            ELSE IF(IV.LT.6) THEN
               WRITE(IOUREP,376) EF(1,IV),EF(4,IV),EF(5,IV),EF(7,IV),
     *         EF(8,IV)
            ENDIF
  370     FORMAT(' ',T21,1X,7(1X,A11,2X))
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-24-1994 @ CSC-bsg Request 434 integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  except for fugitive dust (paved and unpaved)
C
  375     FORMAT(' ','Composite:',T19,3(3X,F8.3,3X),2(3X,F8.2,3X),
     *    3(3X,F8.2,3X))
  376     FORMAT(' ','Composite:',T19,3X,F8.3,3X,
     *    2(9X,'-',3X),2X,
     *    7(3X,F8.3,3X))
          WRITE(IOUREP,230) 
          CALL OBYHDR
 230      FORMAT(1X,'...Continued')
C
C  Feb-17-1994 @ CSC-bsg Request 394 SO2FLG Disable Exhaust SO2 output
C
          WRITE(IOUREP,342)
     *    BYVTN(IV),ICY,(VB,NAMPOL(IP),IP=9,11),VB,NAMPOL(6)
  342     FORMAT(
     1    ' ',T39,A36/
     2    ' ',T49,'January 1, ', I4/
     3    ' ',T2,'Model',T21,5(A1,1X,A11,1X))
          WRITE(IOUREP,346) YFM,(VB,PN,IP=1,4)
  346     FORMAT(
     4    ' ',T2,A17,T21,5(A1,1X,A10,2X))
          WRITE(IOUREP,351) (U7,ICH=1,4)
  351     FORMAT(
     4    ' ',T2,'____',T7,'_____',T13,'_______',T21,1X,12(1X,A11,2X))
C
          DO 54 JDX=1,MAXYRS
            IDX=(MAXYRS+1)-JDX
            MY=ICY-JDX+1
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C
            WRITE(IOUREP,363) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *      (BYFER(IP,JDX,IV),IP=9,11),BYFER(6,JDX,IV)
   54     CONTINUE
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-17-1994 @ CSC-bsg Request 434 Integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
  363     FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,3(3X,F8.3,3X),
     *           3X,3F8.3)
CC     *3X,F8.2,3X,3X,F8.2,3X,3X,3F8.3)
C
C  Write column sums for TF weighted components, to check for 
C  identity with the same sums written out in the OUTFMT = 3 table.
C
          WRITE(IOUREP,370) (U7,ICH=1,4)
C
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Oct-28-1994 @ CSC-ked  Request 474  PART5 Fugitive Dust Reformatting
C
          WRITE(IOUREP,377) (EF(IP,IV),IP=9,11),EF(6,IV)
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-24-1994 @ CSC-bsg Request 434 integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  except for fugitive dust (paved and unpaved)
C  Oct-28-1994 @ CSC-ked Request 474 PART5 Fugitive Dust Reformatting
C
  377     FORMAT(' ','Composite:',T19,3(3X,F8.3,3X),3X,F8.3,3X)
CC     *    2(3X,F8.3,3X))
   70   CONTINUE
      GOTO 99
C
 78   ICHMAX=6
      DO 73 IV=1,MAXVEH+3
          IVV=IV
          IF(IVV.GT.12) IVV=12
          IF(IVPICK(IV).EQ.1) GOTO 73
           WRITE(IOUREP,240)
     *     BYVTN(IV),ICY,(VB,NAMPOL(IP),IP=1,5),VB,NAMPOL(7)
           WRITE(IOUREP,245) YFM,(VB,PN,ICH=1,ICHMAX)
           WRITE(IOUREP,250) (U7,ICH=1,ICHMAX)
 240       FORMAT(
     1      ' ',T39,A36/
     2      ' ',T49,'January 1, ', I4/
     3      ' ',T2,'Model',T21,6(A1,1X,A11,1X))
  245       FORMAT(
     4      ' ',T2,A17,T21,6(A1,1X,A10,2X))
  250       FORMAT(
     4      ' ',T2,'____',T7,'_____',T13,'_______',T21,1X,12(1X,A11,2X))
C
            DO 50 JDX=1,MAXYRS
              IDX=(MAXYRS+1)-JDX
              MY=ICY-JDX+1
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C
            IF(IV.GE.6) THEN
               WRITE(IOUREP,260) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *         (BYFER(IP,JDX,IV),IP=1,6)
            ELSE
               WRITE(IOUREP,262) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *         BYFER(1,JDX,IV),(BYFER(IP,JDX,IV),IP=4,6)
            ENDIF
   50       CONTINUE
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-24-1994 @ CSC-bsg Request 434 integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
  260       FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,12(3X,F8.3,3X))
  261       FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,4(3X,F8.3,3X))
CC     *2X,F9.2,5X,F9.2)
  262     FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,3X,F8.3,3X,
     *2(9X,'-',3X),2X,
     *14(3X,F8.3,3X))
C
C  Write column sums for TF weighted components, to check for 
C  identity with the same sums written out in the OUTFMT = 3 table.
C
            WRITE(IOUREP,270) (U7,ICH=1,ICHMAX)
C
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C
            IF(IV.GE.6) THEN
              WRITE(IOUREP,274) (EF(IP,IV),IP=1,5),EF(7,IV)
            ELSE
              WRITE(IOUREP,276) EF(1,IV),(EF(IP,IV),IP=4,5),EF(7,IV)
            ENDIF
  270       FORMAT(' ',T21,1X,6(1X,A11,2X))
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-24-1994 @ CSC-bsg Request 434 integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  except for fugitive dust (paved and unpaved)
C
  274     FORMAT(' ','Composite:',T19,6(3X,F8.3,3X))
C
C  Oct-28-1994 @ CSC-ked  Request 474  PART5 Fugitive Dust Reformatting
C
  275     FORMAT(' ','Composite:',T19,4(3X,F8.3,3X))
  276     FORMAT(' ','Composite:',T19,3X,F8.3,3X,
     *    2(9X,'-',3X),2X,
     *    7(3X,F8.3,3X))
          CALL OUTHDR
          WRITE(IOUREP,230) 
           WRITE(IOUREP,242)
     *     BYVTN(IV),ICY,(VB,NAMPOL(IP),IP=8,MAXPOL)
 242       FORMAT(
     1      ' ',T39,A36/
     2      ' ',T49,'January 1, ', I4/
     3      ' ',T2,'Model',T21,4(A1,1X,A11,1X))

           WRITE(IOUREP,245) YFM,(VB,PN,ICH=1,ICHMAX-2)
           WRITE(IOUREP,250) (U7,ICH=1,ICHMAX-2)
C
            DO 51 JDX=1,MAXYRS
              IDX=(MAXYRS+1)-JDX
              MY=ICY-JDX+1
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C
              WRITE(IOUREP,261) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *        (BYFER(IP,JDX,IV),IP=8,MAXPOL)
   51       CONTINUE
C
C  Write column sums for TF weighted components, to check for 
C  identity with the same sums written out in the OUTFMT = 3 table.
C
            WRITE(IOUREP,270) (U7,ICH=1,ICHMAX-2)
            WRITE(IOUREP,275) (EF(IP,IV),IP=8,MAXPOL)
   73 CONTINUE
   99 RETURN
      END
