      SUBROUTINE O5P2(ICY)
C
C  OUTDT5 writes scenario emission factor results by model year for selected
C  vehicle types on unit IOUREP using output format (OUTFMT) 5.
C
C  Called by OUTPUT.
C
C  Calls OBYHDR, and OUTPOL.
C
C  Input on call:
C
C    parameter list: ICY
C    common blocks:
C     /BYMYC1/ IVPICK(MAXVEH),BYCUM(MAXYRS,MAXVEH)
C     /BYMYC2/ BYFER(MAXPOL,MAXYRS,MAXVEH)
C     /IOUCOM/ IOUREP
C     /MAXIMA/ MAXVEH,MAXYRS
C     /MYRCAL/ TF(MAXYRS,MAXVEH)
C     /NAMES2/ NAMPOL(MAXPOL),NAMREG(3)
C     /RESUL1/ EF(MAXPOL,MAXVEH+3)
C
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  BYVTN    C    Vehicle class descriptions
C  YFM      C    character string = 'Year   TF   Miles'
C  PN       C    character string = 'Emiss Rate'
C  U7       C    character string = '___________'
C  VB       C    character string = '|'
C  TMP      R    temporary stroage of Fugitive Dust emission factors
C  CTMP     R    temporary sotrage of Fugitive Dust emission factors (comp)
C
C  Notes:
C
C  (1) OUTDT5 prints by model year results only for those pollutants picked
C      by the user via PRTFLG.
C
C  (2) OUTDT5 is called after the OUTFMT=3 output (scenario header + output
C      in 112 column report format) is printed.  Starting on a new page, two
C      By Model Year tables will now be printed on each page thereafter, until
C      all picked vehicle types' results are written.  The maximum space
C      required by OUTFMT = 5 for a scenario is thus 5 pages (OUTFMT = 3
C      output plus eight By Model Year tables).
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  Jan-6-1994 @ CSC-bsg  Request 377 Expansion of by-model year to include 
C  transit and CBD or heavy urban when applicable.  The application
C  criteria is determined with the BUSFLG.
C  Mar-4-1994 @ CSC-bsg Request 394 SO2FLG Disable Exhaust SO2 output
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-11-1994 @ CSC-bsg Request 394 fix bug PRTFLG=2, OUTFMT=5
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  May-24-1994 @ CSC-bsg Request 434 integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C  Feb-16-1995 @ CSC-wcs Request 4-484 (PART5 Output) Change from three to
C  five horizontal dashed line segments over the column sums.
C
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
      INCLUDE 'BYMYM.INC'
C
      CHARACTER*36 BYVTN(MAXVEH+3)
      CHARACTER*17 YFM
      CHARACTER*11 U7
      CHARACTER*10 PN
      CHARACTER*1 VB
C
      DATA BYVTN/
     1            '      Light Duty Gas Vehicles       ',
     2            '      Light Duty Gas Trucks 1       ',
     3            '      Light Duty Gas Trucks 2       ',
     4            '      Heavy Duty Gas Vehicles       ',
     5            '            Motorcycles             ',
     6            '     Light Duty Diesel Vehicles     ',
     7            '      Light Duty Diesel Trucks      ',
     8            'Class 2B Heavy Duty Diesel Vehicles ',
     9            '  Light Heavy Duty Diesel Vehicles  ',
     *            '  Medium Heavy Duty Diesel Vehicles ',
     1            '  Heavy Heavy Duty Diesel Vehicles  ',
     2            '      Heavy Duty Diesel Buses       ',
     3            '            Transit                 ',
     4            '               CBD                  ',
     5            '          Heavy Urban               '/
C
      DATA YFM/'Year   TF   Miles'/
      DATA PN/'Emiss Rate'/
      DATA U7/'___________'/
      DATA VB/'|'/
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C
      ICHMAX=5
      DO 73 IV=1,MAXVEH+3
          IVV=IV
          IF(IVV.GT.12) IVV=12
          IF(IVPICK(IV).EQ.1) GOTO 73
           CALL OBYHDR
           WRITE(IOUREP,240)
     *     BYVTN(IV),ICY,(VB,NAMPOL(IP),IP=1,ICHMAX)
           WRITE(IOUREP,245) YFM,(VB,PN,ICH=1,ICHMAX)
           WRITE(IOUREP,250) (U7,ICH=1,ICHMAX)
 240       FORMAT(
     1      ' ',T39,A36/
     2      ' ',T49,'January 1, ', I4/
     3      ' ',T2,'Model',T21,5(A1,1X,A11,1X))
  245       FORMAT(
     4      ' ',T2,A17,T21,5(A1,1X,A10,2X))
  250       FORMAT(
     4      ' ',T2,'____',T7,'_____',T13,'_______',T21,1X,12(1X,A11,2X))
C
            DO 50 JDX=1,MAXYRS
              IDX=(MAXYRS+1)-JDX
              MY=ICY-JDX+1
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  May-17-1994 @ CSC-bsg Request 434 Integration and regression testing
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C
            IF(IV.GE.6) THEN
               WRITE(IOUREP,260) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *         (BYFER(IP,JDX,IV),IP=1,ICHMAX)
            ELSE 
               WRITE(IOUREP,262) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *         BYFER(1,JDX,IV),(BYFER(IP,JDX,IV),IP=4,ICHMAX)
            ENDIF
C
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
  262     FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,3X,F8.3,3X,
     *2(9X,'-',3X),2X,
     *14(3X,F8.3,3X))
   50       CONTINUE
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
  260       FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,5(3X,F8.3,3X))
C
C  Write column sums for TF weighted components, to check for 
C  identity with the same sums written out in the OUTFMT = 3 table.
C
C  Feb-16-1995 @ CSC-wcs Request 4-484 (PART5 Output) Change from three to
C  five horizontal dashed line segments over the column sums.
C
            WRITE(IOUREP,270) (U7,ICH=1,ICHMAX)
C
C  Mar-21-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C
            IF(IV.GE.6) THEN
               WRITE(IOUREP,275) (EF(IP,IV),IP=1,ICHMAX)
            ELSE 
               WRITE(IOUREP,276) EF(1,IV),(EF(IP,IV),IP=4,ICHMAX)
            ENDIF
  270       FORMAT(' ',T21,1X,5(1X,A11,2X))
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-17-1994 @ CSC-bsg Request 434 Integration and regression testing
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
  275       FORMAT(' ','Composite:',T19,5(3X,F8.3,3X))
  276     FORMAT(' ','Composite:',T19,3X,F8.3,3X,
     *    2(9X,'-',3X),2X,
     *    7(3X,F8.3,3X))
   73 CONTINUE
   99 RETURN
      END
