      SUBROUTINE O5P3S2(ICY)
C
C  OUTDT5 writes scenario emission factor results by model year for selected
C  vehicle types on unit IOUREP using output format (OUTFMT) 5, PRTFLG 3
C  and SO2FLG 2
C
C  Called by OUTPUT.
C
C  Calls OBYHDR, and OUTPOL.
C
C  Input on call:
C
C    parameter list: ICY
C    common blocks:
C     /BYMYC1/ IVPICK(MAXVEH),BYCUM(MAXYRS,MAXVEH)
C     /BYMYC2/ BYFER(MAXPOL,MAXYRS,MAXVEH)
C     /IOUCOM/ IOUREP
C     /MAXIMA/ MAXVEH,MAXYRS
C     /MYRCAL/ TF(MAXYRS,MAXVEH)
C     /NAMES2/ NAMPOL(MAXPOL),NAMREG(3)
C     /RESUL1/ EF(MAXPOL,MAXVEH+3)
C
C
C  Local variable dictionary:
C
C   Name   Type              Description
C  ------  ----  -------------------------------------------------------
C  BYVTN    C    Vehicle class descriptions
C  YFM      C    character string = 'Year   TF   Miles'
C  PN       C    character string = 'Emiss Rate'
C  U7       C    character string = '___________'
C  VB       C    character string = '|'
C  NTABLE   I    number of the table.  This variable is necessary because
C                all emission factors for all species can not be printed
C                in one table.
C  TMP      R    temporary storage of Fugitive Dust emission factors
C  CTMP     R    temporary storage of Fugitive Dust emission factors (comp)
C
C  Notes:
C
C  (1) OUTDT5 prints by model year results only for those pollutants picked
C      by the user via PRTFLG.
C
C  (2) OUTDT5 is called after the OUTFMT=3 output (scenario header + output
C      in 112 column report format) is printed.  Starting on a new page, two
C      By Model Year tables will now be printed on each page thereafter, until
C      all picked vehicle types' results are written.  The maximum space
C      required by OUTFMT = 5 for a scenario is thus 5 pages (OUTFMT = 3
C      output plus eight By Model Year tables).
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  Jan-6-1994 @ CSC-bsg  Request 377 Expansion of by-model year to include
C  transit and CBD or heavy urban when applicable.  The application
C  criteria is determined with the BUSFLG.
C  Mar-4-1994 @ CSC-bsg Request 394 SO2FLG Disable Exhaust SO2 output
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-11-1994 @ CSC-bsg Request 394 fix bug PRTFLG=3, OUTFMT=5
C  Mar-22-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C  Jul-22-1994 @ CSC-tmm Request 434 Added PRTFLG=3 with new pollutants printed
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'IOU.INC'
      INCLUDE 'NAMES.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
      INCLUDE 'BYMYM.INC'
C
      CHARACTER*36 BYVTN(MAXVEH+3)
      CHARACTER*17 YFM
      CHARACTER*11 U7
      CHARACTER*10 PN
      CHARACTER*1 VB
C
      DATA BYVTN/
     1            '      Light Duty Gas Vehicles       ',
     2            '      Light Duty Gas Trucks 1       ',
     3            '      Light Duty Gas Trucks 2       ',
     4            '      Heavy Duty Gas Vehicles       ',
     5            '            Motorcycles             ',
     6            '     Light Duty Diesel Vehicles     ',
     7            '      Light Duty Diesel Trucks      ',
     8            'Class 2B Heavy Duty Diesel Vehicles ',
     9            '  Light Heavy Duty Diesel Vehicles  ',
     *            '  Medium Heavy Duty Diesel Vehicles ',
     1            '  Heavy Heavy Duty Diesel Vehicles  ',
     2            '      Heavy Duty Diesel Buses       ',
     3            '            Transit                 ',
     4            '               CBD                  ',
     5            '          Heavy Urban               '/
C
      DATA YFM/'Year   TF   Miles'/
      DATA PN/'Emiss Rate'/
      DATA U7/'___________'/
      DATA VB/'|'/
C
      NTABLE=0
C
        DO 70 IV=1,MAXVEH+3
          IVV=IV
          IF(IVV.GT.12) IVV=12
          IF(IVPICK(IV).EQ.1) GOTO 70
C
   10     NTABLE=NTABLE+1
          IF(MOD(NTABLE,2).EQ.1) THEN
            CALL OBYHDR
          ELSE
            WRITE(IOUREP,230)
            CALL OBYHDR
          ENDIF
 230      FORMAT(1X,'...Continued')
C
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C
          IF(MOD(NTABLE,2).EQ.1) THEN
            WRITE(IOUREP,340)
     *      BYVTN(IV),ICY,VB,NAMPOL(5),
     *                    VB,NAMPOL(9),
     *                    VB,NAMPOL(10)
            WRITE(IOUREP,345) YFM,(VB,PN,IP=1,3)
            WRITE(IOUREP,350) (U7,ICH=1,3)
          ELSE
            WRITE(IOUREP,341)
     *      BYVTN(IV),ICY,VB,NAMPOL(11),
CC     *                    VB,NAMPOL(12),
CC     *                    VB,NAMPOL(13),
     *                    VB,NAMPOL(6)
            WRITE(IOUREP,345) YFM,(VB,PN,IP=1,2)
            WRITE(IOUREP,350) (U7,ICH=1,2)
          ENDIF
C
  340     FORMAT(
     1    ' ',T29,A36/
     2    ' ',T39,'January 1, ', I4/
     3    ' ',T2,'Model',T21,7(A1,1X,A11,1X))
  341     FORMAT(
     1    ' ',T29,A36/
     2    ' ',T39,'January 1, ', I4/
     3    ' ',T2,'Model',T21,5(A1,1X,A11,1X))
  345     FORMAT(
     4    ' ',T2,A17,T21,7(A1,1X,A10,2X))
  350     FORMAT(
     4    ' ',T2,'____',T7,'_____',T13,'_______',T21,1X,14(1X,A11,2X))
C
          DO 53 JDX=1,MAXYRS
            IDX=(MAXYRS+1)-JDX
            MY=ICY-JDX+1
C
C  Mar-4-1994 @ CSC-bsg Request 377 fix by model year mileage for bus
C  Mar-22-1994 @ CSC-bsg  Request 410 There is no reliable data to support
C  a soluble organic fraction for gasoline vehicles at this date.
C  Jun-2-1994 @ CSC-bsg Request 443 Fixed TF array subscript out of bounds
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C
            IF(MOD(NTABLE,2).EQ.1) THEN
              WRITE(IOUREP,360) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *           BYFER(5,JDX,IV),
     *           BYFER(9,JDX,IV),
     *           BYFER(10,JDX,IV)
            ELSE
              WRITE(IOUREP,362) MY,TF(IDX,IVV),BYCUM(JDX,IVV),
     *           BYFER(11,JDX,IV),
CC     *           BYFER(12,JDX,IV),
CC     *           BYFER(13,JDX,IV),
     *           BYFER(6,JDX,IV)
            ENDIF
C
   53     CONTINUE
C
C  Write column sums for TF weighted components, to check for
C  identity with the same sums written out in the OUTFMT = 3 table.
C
C  Oct-28-1994 @ CSC-ked Request 474  PART5 Fugitive Dust Reformatting
C
          IF(MOD(NTABLE,2).EQ.1) THEN
            WRITE(IOUREP,370) (U7,ICH=1,3)
            WRITE(IOUREP,375) EF(5,IV),EF(9,IV),EF(10,IV)
          ELSE
            WRITE(IOUREP,370) (U7,ICH=1,2)
            WRITE(IOUREP,376) EF(11,IV),EF(6,IV)
          ENDIF
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-26-1994 @ CSC-bsg Request 435 changes from two decimal to three decimal
C
  360     FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,14(3X,F8.3,3X))
  362     FORMAT(' ',T2,I4,T7,F5.2,F8.0,T19,3X,F8.3,3X,
     *           3X,F8.3,3X)
  370     FORMAT(' ',T21,1X,7(1X,A11,2X))
C
C  Oct-12-1993 @ ARC-bsg Subtask 325 changes from four decimal to two decimal
C  May-17-1994 @ CSC-bsg Request 434 Integration and regression testing
C
  375     FORMAT(' ','Composite:',T19,7(3X,F8.3,3X))
  376     FORMAT(' ','Composite:',T19,3X,F8.3,3X,
     *           3X,F8.3,3X)
C
          IF(MOD(NTABLE,2).EQ.1) GO TO 10
C
   70   CONTINUE
C
      RETURN
      END
