      SUBROUTINE TAMPER(ICY, MY, IV, TAMFRC, RMIS)
C
C     This subroutine finds the proper misfueling rate for vehicle
C     class IV, age IAGE, and whether or not there is an IM program, 
C     determined by IMFLAG.   
C
C     This subroutine also finds the catalyst removal rate 
C
C     Called by: UNLDED, LEADED, EFCALX, GASSLF
C
C     Calls: none
C
C     Input on call:
C     /TAMBLK/ TAMRAT(2,3,3,2,2)
C     /FLAGS2/ IMFLAG
C     /CUMCOM/ CUMMIL(12,25)
C
C     Output on return: TAMFRC, RMIS
C
      INCLUDE 'PARAM.INC'
      INCLUDE 'LEAD.INC'
      INCLUDE 'FLAGS.INC'
      INCLUDE 'RESULT.INC'
C
      TAMFRC = 0.0
      RMIS = 0.0
C
C  Special cases return 0.0
C
      IF (IMFLAG.EQ.3) RETURN
      IF (IV .GT. 4) RETURN
      IF (MY .LT. 1975) RETURN
      IF (IV .EQ. 4 .AND. MY .LT. 1982) RETURN
C
C  Need to calculate age to index into mileage array
C
      IAGE = ICY - MY + 1
C
C  Mileage is measure in terms of 10,000 miles
C
      XMILE = CUMMIL(IAGE,IV)/10000
C
C  XXMILE is the above 50,000 miles amount
C
      XXMILE = XMILE - 5.0
C
C  Set the second mileage to zero when the mileage is less than 50,000 miles
C
      IF(XXMILE.LT.0.0) THEN 
        XXMILE=0.0
C
C  Capping the mileage at 130,000 miles
C
      ELSEIF(XXMILE.GT.8.0) THEN
        XXMILE=8.0
      ENDIF
      IF(XXMILE.GT.0.0) XMILE=5.0
C
C  Discover the model year group and set the IG pointer
C
      IF(MY.LE.1980) THEN
        IG=1
      ELSEIF(MY.GE.1984) THEN
        IG=3
      ELSE
        IG=2
      ENDIF
C
C  Choose the vehicle class cars or trucks
C
      IVA=IV
      IF(IVA.NE.1) IVA=2
C
C  Calculate the tampering rates
C
      TAMFRC = TAMRAT(IMFLAG,1,IG,IVA,1) + 
     2         TAMRAT(IMFLAG,2,IG,IVA,1) * XMILE +
C
C  Multiple the second rate times the first rate
C
     3   TAMRAT(IMFLAG,2,IG,IVA,1) * TAMRAT(IMFLAG,3,IG,IVA,1) * XXMILE
C
C  Calculate the misfueling rates
C
      RMIS =   TAMRAT(IMFLAG,1,IG,IVA,2) + 
     2         TAMRAT(IMFLAG,2,IG,IVA,2) * XMILE +
C
C  Multiple the second rate times the first rate
C
     3   TAMRAT(IMFLAG,2,IG,IVA,2) * TAMRAT(IMFLAG,3,IG,IVA,2) * XXMILE
C
C  If rates are less than zero reset the rates to 0.0
C
      IF (RMIS .LT. 0.0) RMIS = 0.0
      IF (TAMFRC .LT. 0.0) TAMFRC = 0.0
C
C  If rates are greater than one reset the rates to 1.0
C
      IF (RMIS .GT. 1.0) RMIS = 1.0
      IF (TAMFRC .GT. 1.0) TAMFRC = 1.0
C
C  Only need to make this check once here in TAMPER
C
      IF(RMIS-TAMFRC .LT. 0.0) RMIS=TAMFRC
      RETURN 
      END 
